@@ -28,8 +28,12 @@
 #include <botan/internal/loadstor.h>
 #include <botan/internal/parsing.h>
 #include <botan/internal/stl_util.h>
+#include <botan/internal/target_info.h>
 
+#include <cstring>
 #include <ctime>
+#include <fstream>
+#include <iomanip>
 #include <iostream>
 #include <map>
 #include <memory>
@@ -56,35 +60,38 @@ int shim_output(const std::string& s, int rc = 0) {
    return rc;
 }
 
-void shim_log(const std::string& s) {
-   if(::getenv("BOTAN_BOGO_SHIM_LOG")) {
-      /*
-      FIXMEs:
-       - Rewrite this to use a std::ostream instead
-       - Allow using the env variable to point to where the log is written
-       - Avoid rechecking the env variable with each call (!)
-      */
+void shim_log(std::string_view s) {
+   static const auto log_path = []() -> std::string {
+      const char* env = ::getenv("BOTAN_BOGO_SHIM_LOG");
+      if(env == nullptr) {
+         return {};
+      }
 
-      // NOLINTNEXTLINE(*-avoid-non-const-global-variables)
-      static FILE* g_log = std::fopen("/tmp/bogo_shim.log", "w");
-      struct timeval tv;
-      ::gettimeofday(&tv, nullptr);
-      static_cast<void>(std::fprintf(g_log,
-                                     "%lld.%lu: %s\n",
-                                     static_cast<unsigned long long>(tv.tv_sec),
-                                     static_cast<unsigned long>(tv.tv_usec),
-                                     s.c_str()));
-      static_cast<void>(std::fflush(g_log));
+      auto log_file_path = std::string(env);
+      if(log_file_path.empty() || log_file_path == "1") {
+         return "/tmp/bogo_shim.log";
+      }
+      return env;
+   }();
+
+   if(!log_path.empty()) {
+      static std::ofstream g_log(log_path, std::ios::out | std::ios::trunc);
+      if(g_log.is_open() && g_log.good()) {
+         const auto duration = std::chrono::system_clock::now().time_since_epoch();
+         const auto seconds = std::chrono::duration_cast<std::chrono::duration<double>>(duration);
+
+         g_log << std::fixed << std::setprecision(6) << seconds.count() << ": " << s << std::endl;
+      }
    }
 }
 
-[[noreturn]] void shim_exit_with_error(const std::string& s, int rc = 1) {
+[[noreturn]] void shim_exit_with_error(const std::string& s, int rc = 1) noexcept {
    shim_log("Exiting with " + s);
    std::cerr << s << "\n";
    std::exit(rc);
 }
 
-std::string map_to_bogo_error(const std::string& e) {
+std::string map_to_bogo_error(const std::string& e) noexcept {
    shim_log("Original error " + e);
 
    static const std::unordered_map<std::string, std::string> err_map{
@@ -343,7 +350,7 @@ std::string map_to_bogo_error(const std::string& e) {
 
 class Shim_Exception final : public std::exception {
    public:
-      Shim_Exception(std::string_view msg, int rc = 1) : m_msg(msg), m_rc(rc) {}
+      explicit Shim_Exception(std::string_view msg, int rc = 1) : m_msg(msg), m_rc(rc) {}
 
       const char* what() const noexcept override { return m_msg.c_str(); }
 
@@ -369,7 +376,7 @@ class Shim_Socket final {
 
    public:
       Shim_Socket(const std::string& hostname, int port, const bool ipv6) : m_socket(-1) {
-         addrinfo hints;
+         addrinfo hints{};
          std::memset(&hints, 0, sizeof(hints));
          hints.ai_family = AF_UNSPEC;
          hints.ai_socktype = SOCK_STREAM;
@@ -380,7 +387,7 @@ class Shim_Socket final {
          // TODO: C++23 will introduce std::out_ptr() that should replace the
          //       temporary variable for the call to ::getaddrinfo() and
          //       std::unique_ptr<>::reset().
-         unique_addrinfo_t::pointer res_tmp;
+         unique_addrinfo_t::pointer res_tmp = nullptr;
          int rc = ::getaddrinfo(hostname.c_str(), service.c_str(), &hints, &res_tmp);
          unique_addrinfo_t res(res_tmp, &::freeaddrinfo);
 
@@ -606,10 +613,10 @@ class Shim_Arguments final {
          if(!m_all_options.contains(key)) {
             throw Shim_Exception("Invalid option " + key);
          }
-         if(m_parsed_opts.find(key) != m_parsed_opts.end()) {
+         if(m_parsed_opts.contains(key)) {
             return true;
          }
-         if(m_parsed_int_vec_opts.find(key) != m_parsed_int_vec_opts.end()) {
+         if(m_parsed_int_vec_opts.contains(key)) {
             return true;
          }
          return false;
@@ -862,7 +869,7 @@ std::unique_ptr<Shim_Arguments> parse_options(char* argv[]) {
 
 class Shim_Policy final : public Botan::TLS::Policy {
    public:
-      Shim_Policy(const Shim_Arguments& args) : m_args(args), m_sessions(0) {}
+      explicit Shim_Policy(const Shim_Arguments& args) : m_args(args), m_sessions(0) {}
 
       void incr_session_established() { m_sessions += 1; }
 
@@ -1033,13 +1040,7 @@ class Shim_Policy final : public Botan::TLS::Policy {
                 require_client_certificate_authentication();
       }
 
-      bool allow_insecure_renegotiation() const override {
-         if(m_args.flag_set("expect-no-secure-renegotiation")) {
-            return true;
-         } else {
-            return false;
-         }
-      }
+      bool allow_insecure_renegotiation() const override { return m_args.flag_set("expect-no-secure-renegotiation"); }
 
       //bool include_time_in_hello_random() const override;
 
@@ -1162,11 +1163,7 @@ class Shim_Policy final : public Botan::TLS::Policy {
       //size_t dtls_maximum_timeout() const override;
 
       bool abort_connection_on_undesired_renegotiation() const override {
-         if(m_args.flag_set("renegotiate-ignore")) {
-            return false;
-         } else {
-            return true;
-         }
+         return !m_args.flag_set("renegotiate-ignore");
       }
 
       size_t maximum_certificate_chain_size() const override { return m_args.get_int_opt_or_else("max-cert-list", 0); }
@@ -1185,11 +1182,7 @@ class Shim_Policy final : public Botan::TLS::Policy {
             "MinimumVersion-Client-TLS13-TLS12-TLS",
             "MinimumVersion-Client2-TLS13-TLS12-TLS",
          };
-         if(Botan::value_exists(alert_after_server_hello, m_args.test_name())) {
-            return false;
-         }
-
-         return true;
+         return !Botan::value_exists(alert_after_server_hello, m_args.test_name());
       }
 
    private:
@@ -1222,16 +1215,17 @@ std::vector<uint16_t> Shim_Policy::ciphersuite_list(Botan::TLS::Protocol_Version
    } else {
       // Hack: go in reverse order to avoid preferring 3DES
       auto ciphersuites = Botan::TLS::Ciphersuite::all_known_ciphersuites();
+      // TODO(Botan4) use std::ranges::reverse_view here once available (need newer Clang)
+      // NOLINTNEXTLINE(modernize-loop-convert)
       for(auto i = ciphersuites.rbegin(); i != ciphersuites.rend(); ++i) {
          const auto suite = *i;
 
-         // Can we use it?
-         if(suite.valid() == false || !suite.usable_in_version(version) ||
-            !Botan::value_exists(allowed_ciphers(), suite.cipher_algo())) {
-            continue;
-         }
+         const bool usable = suite.valid() && suite.usable_in_version(version) &&
+                             Botan::value_exists(allowed_ciphers(), suite.cipher_algo());
 
-         ciphersuite_codes.push_back(suite.ciphersuite_code());
+         if(usable) {
+            ciphersuite_codes.push_back(suite.ciphersuite_code());
+         }
       }
    }
 
@@ -1240,7 +1234,7 @@ std::vector<uint16_t> Shim_Policy::ciphersuite_list(Botan::TLS::Protocol_Version
 
 class Shim_Credentials final : public Botan::Credentials_Manager {
    public:
-      Shim_Credentials(const Shim_Arguments& args) : m_args(args) {
+      explicit Shim_Credentials(const Shim_Arguments& args) : m_args(args) {
          const auto psk_identity = m_args.get_string_opt_or_else("psk-identity", "");
          const auto psk_str = m_args.get_string_opt_or_else("psk", "");
 
@@ -1426,8 +1420,8 @@ class Shim_Callbacks final : public Botan::TLS::Callbacks {
          }
       }
 
-      std::vector<uint8_t> tls_provide_cert_status(const std::vector<Botan::X509_Certificate>&,
-                                                   const Botan::TLS::Certificate_Status_Request&) override {
+      std::vector<uint8_t> tls_provide_cert_status(const std::vector<Botan::X509_Certificate>& /*certs*/,
+                                                   const Botan::TLS::Certificate_Status_Request& /*status*/) override {
          if(m_args.flag_set("use-ocsp-callback") && m_args.flag_set("fail-ocsp-callback")) {
             throw std::runtime_error("Simulating failure from OCSP response callback");
          }
@@ -1508,7 +1502,7 @@ class Shim_Callbacks final : public Botan::TLS::Callbacks {
          }
 
          if(!cert_chain.empty() && cert_chain.front().is_self_signed()) {
-            for(const auto roots : trusted_roots) {
+            for(auto* const roots : trusted_roots) {
                if(roots->certificate_known(cert_chain.front())) {
                   shim_log("Trusting self-signed certificate");
                   return;
@@ -1607,7 +1601,7 @@ class Shim_Callbacks final : public Botan::TLS::Callbacks {
          }
 
          if(alert.type() == Botan::TLS::Alert::CloseNotify) {
-            if(m_got_close == false && !m_args.flag_set("shim-shuts-down")) {
+            if(!m_got_close && !m_args.flag_set("shim-shuts-down")) {
                shim_log("Sending return close notify");
                m_channel->send_alert(alert);
             }
@@ -1619,8 +1613,8 @@ class Shim_Callbacks final : public Botan::TLS::Callbacks {
 
       void tls_session_established(const Botan::TLS::Session_Summary& session) override {
          shim_log("Session established: " + Botan::hex_encode(session.session_id().get()) + " version " +
-                  session.version().to_string() + " cipher " + session.ciphersuite().to_string() + " EMS " +
-                  std::to_string(session.supports_extended_master_secret()));
+                  session.version().to_string() + " cipher " + session.ciphersuite().to_string() + " " +
+                  std::string((session.supports_extended_master_secret() ? "with EMS" : "without EMS")));
          // probably need tests here?
 
          m_policy.incr_session_established();
@@ -1642,17 +1636,17 @@ class Shim_Callbacks final : public Botan::TLS::Callbacks {
          }
 
          if(m_args.flag_set("expect-secure-renegotiation")) {
-            if(m_channel->secure_renegotiation_supported() == false) {
+            if(!m_channel->secure_renegotiation_supported()) {
                shim_exit_with_error("Expected secure renegotiation");
             }
          } else if(m_args.flag_set("expect-no-secure-renegotiation")) {
-            if(m_channel->secure_renegotiation_supported() == true) {
-               shim_exit_with_error("Expected no secure renegotation");
+            if(m_channel->secure_renegotiation_supported()) {
+               shim_exit_with_error("Expected no secure renegotiation");
             }
          }
 
          if(m_args.flag_set("expect-extended-master-secret")) {
-            if(session.supports_extended_master_secret() == false) {
+            if(!session.supports_extended_master_secret()) {
                shim_exit_with_error("Expected extended maseter secret");
             }
          }
@@ -1790,7 +1784,7 @@ int main(int /*argc*/, char* argv[]) {
             // *before* any test data is transferred
             // See: https://github.com/google/boringssl/commit/50ee09552cde1c2019bef24520848d041920cfd4
             shim_log("Sending ShimID: " + std::to_string(args->get_int_opt("shim-id")));
-            std::array<uint8_t, 8> shim_id;
+            std::array<uint8_t, 8> shim_id{};
             Botan::store_le(static_cast<uint64_t>(args->get_int_opt("shim-id")), shim_id.data());
             socket.write(shim_id.data(), shim_id.size());
 
@@ -1827,7 +1821,7 @@ int main(int /*argc*/, char* argv[]) {
 
             for(;;) {
                if(is_datagram) {
-                  uint8_t opcode;
+                  uint8_t opcode = 0;
                   size_t got = socket.read(&opcode, 1);
                   if(got == 0) {
                      shim_log("EOF on socket");
@@ -1883,7 +1877,7 @@ int main(int /*argc*/, char* argv[]) {
                   }
                   const size_t needed = chan->received_data(buf.data(), got);
 
-                  if(needed) {
+                  if(needed > 0) {
                      shim_log("Short read still need " + std::to_string(needed));
                   }
                }
