@@ -10,6 +10,8 @@
 #include "cli.h"
 #include "sandbox.h"
 
+#include <botan/internal/target_info.h>
+
 #if defined(BOTAN_TARGET_OS_HAS_SOCKETS)
    #include <sys/socket.h>
 #endif
@@ -49,7 +51,7 @@ namespace {
 
 class Callbacks : public Botan::TLS::Callbacks {
    public:
-      Callbacks(TLS_Server& server_command) : m_server_command(server_command) {}
+      explicit Callbacks(TLS_Server& server_command) : m_server_command(server_command) {}
 
       std::ostream& output();
       void send(std::span<const uint8_t> buffer);
@@ -75,8 +77,8 @@ class Callbacks : public Botan::TLS::Callbacks {
       }
 
       void tls_record_received(uint64_t /*seq_no*/, std::span<const uint8_t> input) override {
-         for(size_t i = 0; i != input.size(); ++i) {
-            const char c = static_cast<char>(input[i]);
+         for(auto uc : input) {
+            const char c = static_cast<char>(uc);
             m_line_buf += c;
             if(c == '\n') {
                push_pending_output(std::exchange(m_line_buf, {}));
@@ -187,7 +189,8 @@ class TLS_Server final : public Command {
             if(m_is_tcp) {
                m_socket = ::accept(server_fd, nullptr, nullptr);
             } else {
-               struct sockaddr_in from;
+               struct sockaddr_in from {};
+
                socklen_t from_len = sizeof(sockaddr_in);
 
                void* peek_buf = nullptr;
@@ -291,7 +294,7 @@ class TLS_Server final : public Command {
 
             if(sent == -1) {
                error_output() << "Error writing to socket - " << err_to_string(errno) << std::endl;
-            } else if(sent != static_cast<ssize_t>(buf.size())) {
+            } else if(sent >= 0 && static_cast<size_t>(sent) != buf.size()) {
                error_output() << "Packet of length " << buf.size() << " truncated to " << sent << std::endl;
             }
          } else {
@@ -322,7 +325,7 @@ class TLS_Server final : public Command {
             throw CLI_Error("Unable to acquire socket");
          }
 
-         sockaddr_in socket_info;
+         sockaddr_in socket_info{};
          Botan::clear_mem(&socket_info, 1);
          socket_info.sin_family = AF_INET;
          socket_info.sin_port = htons(port);
