@@ -10,7 +10,6 @@
 
    #include <botan/hex.h>
    #include <botan/tls_messages.h>
-   #include <botan/tls_policy.h>
    #include <botan/tls_version.h>
    #include <botan/internal/fmt.h>
    #include <botan/internal/loadstor.h>
@@ -46,7 +45,7 @@ class TLS_Ciphersuites final : public Command {
 
          auto policy = load_tls_policy(policy_type);
 
-         if(policy->acceptable_protocol_version(version) == false) {
+         if(!policy->acceptable_protocol_version(version)) {
             error_output() << "Error: the policy specified does not allow the given TLS version\n";
             return;
          }
@@ -126,11 +125,11 @@ class TLS_Client_Hello_Reader final : public Command {
          const auto* hello_base =
             std::visit([](const auto& ch) -> const Botan::TLS::Client_Hello* { return &ch; }, hello);
 
-         const auto version = std::visit(Botan::overloaded{
-                                            [](const Botan::TLS::Client_Hello_12&) { return "1.2"; },
-                                            [](const Botan::TLS::Client_Hello_13&) { return "1.3"; },
-                                         },
-                                         hello);
+         const std::string version = std::visit(Botan::overloaded{
+                                                   [](const Botan::TLS::Client_Hello_12&) { return "1.2"; },
+                                                   [](const Botan::TLS::Client_Hello_13&) { return "1.3"; },
+                                                },
+                                                hello);
 
          oss << "Version: " << version << "\n"
              << "Random: " << Botan::hex_encode(hello_base->random()) << "\n";
@@ -165,7 +164,7 @@ class TLS_Client_Hello_Reader final : public Command {
             oss << "\n";
          }
 
-         if(auto sg = hello_base->extensions().get<Botan::TLS::Supported_Groups>()) {
+         if(auto* sg = hello_base->extensions().get<Botan::TLS::Supported_Groups>()) {
             oss << "Supported Groups: ";
             for(const auto group : sg->groups()) {
                oss << group.to_string().value_or(Botan::fmt("Unknown group: {}", group.wire_code())) << " ";
@@ -183,7 +182,7 @@ class TLS_Client_Hello_Reader final : public Command {
                           hello_flags["Session Ticket"] = ch12.supports_session_ticket();
                        },
                        [&](const Botan::TLS::Client_Hello_13& ch13) {
-                          if(auto ks = ch13.extensions().get<Botan::TLS::Key_Share>()) {
+                          if(auto* ks = ch13.extensions().get<Botan::TLS::Key_Share>()) {
                              oss << "Key Shares: ";
                              for(const auto group : ks->offered_groups()) {
                                 oss << group.to_string().value_or(Botan::fmt("Unknown group: {}", group.wire_code()))
