@@ -8,11 +8,14 @@
 #include "cli.h"
 
 #include <botan/version.h>
-#include <botan/internal/cpuid.h>
-#include <botan/internal/stl_util.h>
+#include <botan/internal/target_info.h>
 #include <iomanip>
 #include <sstream>
 
+#if defined(BOTAN_HAS_CPUID)
+   #include <botan/internal/cpuid.h>
+#endif
+
 #if defined(BOTAN_HAS_HTTP_UTIL)
    #include <botan/internal/http_util.h>
 #endif
@@ -126,7 +129,7 @@ class Has_Command final : public Command {
             output() << "Command '" << cmd << "' is " << (exists ? "" : "not ") << "available\n";
          }
 
-         if(exists == false) {
+         if(!exists) {
             this->set_return_code(1);
          }
       }
@@ -158,7 +161,7 @@ class Config_Info final : public Command {
          } else if(arg == "cflags") {
             output() << "-I" << BOTAN_INSTALL_PREFIX << "/" << BOTAN_INSTALL_HEADER_DIR << "\n";
          } else if(arg == "ldflags") {
-            if(*BOTAN_LINK_FLAGS) {
+            if(*BOTAN_LINK_FLAGS != 0) {
                output() << BOTAN_LINK_FLAGS << ' ';
             }
             output() << "-L" << BOTAN_INSTALL_LIB_DIR << "\n";
@@ -191,6 +194,8 @@ class Version_Info final : public Command {
 
 BOTAN_REGISTER_COMMAND("version", Version_Info);
 
+#if defined(BOTAN_HAS_CPUID)
+
 class Print_Cpuid final : public Command {
    public:
       Print_Cpuid() : Command("cpuid") {}
@@ -206,6 +211,8 @@ class Print_Cpuid final : public Command {
 
 BOTAN_REGISTER_COMMAND("cpuid", Print_Cpuid);
 
+#endif
+
 #if defined(BOTAN_HAS_OS_UTILS)
 
 class Cycle_Counter final : public Command {
