@@ -101,7 +101,7 @@ highlight_language = 'cpp'
 
 try:
     # On Arch this is python-sphinx-furo
-    import furo
+    import furo # noqa: F401
     html_theme = "furo"
 
     # Add a small edit button to each document to allow visitors to easily
@@ -111,7 +111,7 @@ try:
         'source_branch': 'master',
         'source_directory': 'doc/',
     }
-except ImportError as e:
+except ImportError:
     print("Could not import furo theme; falling back to agago")
     html_theme = 'agogo'
     html_theme_path = []
@@ -234,3 +234,9 @@ extensions = [
 
 # Make sure the target is unique
 autosectionlabel_prefix_document = True
+
+# -- Options for texinfo output --------------------------------------------------
+authors = 'The Botan Authors'
+
+# Show URL addresses after external links, options are 'inline', 'footnote' and 'no'
+texinfo_show_urls = 'inline'
