@@ -7,6 +7,7 @@
 #include "fuzzers.h"
 
 #include <botan/asn1_print.h>
+#include <botan/assert.h>
 #include <fstream>
 
 class ASN1_Parser final : public Botan::ASN1_Formatter {
@@ -14,15 +15,26 @@ class ASN1_Parser final : public Botan::ASN1_Formatter {
       ASN1_Parser() : Botan::ASN1_Formatter(true, 64) {}
 
    protected:
-      std::string format(Botan::ASN1_Type, Botan::ASN1_Class, size_t, size_t, std::string_view) const override {
+      std::string format(Botan::ASN1_Type type,
+                         Botan::ASN1_Class klass,
+                         size_t level,
+                         size_t length,
+                         std::string_view value) const override {
+         BOTAN_UNUSED(type, klass, level, length, value);
          return "";
       }
 
-      std::string format_bin(Botan::ASN1_Type, Botan::ASN1_Class, const std::vector<uint8_t>&) const override {
+      std::string format_bin(Botan::ASN1_Type type,
+                             Botan::ASN1_Class klass,
+                             const std::vector<uint8_t>& value) const override {
+         BOTAN_UNUSED(type, klass, value);
          return "";
       }
 
-      std::string format_bn(const Botan::BigInt&) const override { return ""; }
+      std::string format_bn(const Botan::BigInt& bn) const override {
+         BOTAN_UNUSED(bn);
+         return "";
+      }
 };
 
 void fuzz(std::span<const uint8_t> in) {
