@@ -16,11 +16,11 @@
 namespace Botan {
 
 //static
-PSS_Params PSS_Params::from_emsa_name(std::string_view emsa_name) {
-   SCAN_Name scanner(emsa_name);
+PSS_Params PSS_Params::from_padding_name(std::string_view padding_name) {
+   SCAN_Name scanner(padding_name);
 
    if((scanner.algo_name() != "PSS" && scanner.algo_name() != "PSS_Raw") || scanner.arg_count() != 3) {
-      throw Invalid_Argument(fmt("PSS_Params::from_emsa_name unexpected param '{}'", emsa_name));
+      throw Invalid_Argument(fmt("PSS_Params::from_padding_name unexpected param '{}'", padding_name));
    }
 
    const std::string hash_fn = scanner.arg(0);
@@ -33,9 +33,10 @@ PSS_Params::PSS_Params(std::string_view hash_fn, size_t salt_len) :
       m_hash(hash_fn, AlgorithmIdentifier::USE_NULL_PARAM),
       m_mgf("MGF1", m_hash.BER_encode()),
       m_mgf_hash(m_hash),
-      m_salt_len(salt_len) {}
+      m_salt_len(salt_len),
+      m_trailer_field(1) {}
 
-PSS_Params::PSS_Params(std::span<const uint8_t> der) {
+PSS_Params::PSS_Params(std::span<const uint8_t> der) : m_salt_len(0), m_trailer_field(1) {
    BER_Decoder decoder(der);
    this->decode_from(decoder);
 }
