@@ -7,10 +7,13 @@
 
 #include <botan/internal/noekeon.h>
 
-#include <botan/internal/cpuid.h>
 #include <botan/internal/loadstor.h>
 #include <botan/internal/rotate.h>
 
+#if defined(BOTAN_HAS_CPUID)
+   #include <botan/internal/cpuid.h>
+#endif
+
 namespace Botan {
 
 namespace {
@@ -71,7 +74,7 @@ inline void gamma(uint32_t& A0, uint32_t& A1, uint32_t& A2, uint32_t& A3) {
 
 size_t Noekeon::parallelism() const {
 #if defined(BOTAN_HAS_NOEKEON_SIMD)
-   if(CPUID::has_simd_32()) {
+   if(CPUID::has(CPUID::Feature::SIMD_4X32)) {
       return 4;
    }
 #endif
@@ -81,8 +84,8 @@ size_t Noekeon::parallelism() const {
 
 std::string Noekeon::provider() const {
 #if defined(BOTAN_HAS_NOEKEON_SIMD)
-   if(CPUID::has_simd_32()) {
-      return "simd";
+   if(auto feat = CPUID::check(CPUID::Feature::SIMD_4X32)) {
+      return *feat;
    }
 #endif
 
@@ -102,7 +105,7 @@ void Noekeon::encrypt_n(const uint8_t in[], uint8_t out[], size_t blocks) const
    assert_key_material_set();
 
 #if defined(BOTAN_HAS_NOEKEON_SIMD)
-   if(CPUID::has_simd_32()) {
+   if(CPUID::has(CPUID::Feature::SIMD_4X32)) {
       while(blocks >= 4) {
          simd_encrypt_4(in, out);
          in += 4 * BLOCK_SIZE;
@@ -150,7 +153,7 @@ void Noekeon::decrypt_n(const uint8_t in[], uint8_t out[], size_t blocks) const
    assert_key_material_set();
 
 #if defined(BOTAN_HAS_NOEKEON_SIMD)
-   if(CPUID::has_simd_32()) {
+   if(CPUID::has(CPUID::Feature::SIMD_4X32)) {
       while(blocks >= 4) {
          simd_decrypt_4(in, out);
          in += 4 * BLOCK_SIZE;
