@@ -8,10 +8,13 @@
 #include <botan/internal/shacal2.h>
 
 #include <botan/internal/bit_ops.h>
-#include <botan/internal/cpuid.h>
 #include <botan/internal/loadstor.h>
 #include <botan/internal/rotate.h>
 
+#if defined(BOTAN_HAS_CPUID)
+   #include <botan/internal/cpuid.h>
+#endif
+
 namespace Botan {
 
 namespace {
@@ -44,20 +47,29 @@ inline void SHACAL2_Rev(
 void SHACAL2::encrypt_n(const uint8_t in[], uint8_t out[], size_t blocks) const {
    assert_key_material_set();
 
+#if defined(BOTAN_HAS_SHACAL2_AVX512)
+   if(CPUID::has(CPUID::Feature::AVX512)) {
+      size_t consumed = avx512_encrypt_blocks(in, out, blocks);
+      in += consumed * BLOCK_SIZE;
+      out += consumed * BLOCK_SIZE;
+      blocks -= consumed;
+   }
+#endif
+
 #if defined(BOTAN_HAS_SHACAL2_X86)
-   if(CPUID::has_intel_sha()) {
+   if(CPUID::has(CPUID::Feature::SHA)) {
       return x86_encrypt_blocks(in, out, blocks);
    }
 #endif
 
 #if defined(BOTAN_HAS_SHACAL2_ARMV8)
-   if(CPUID::has_arm_sha2()) {
+   if(CPUID::has(CPUID::Feature::SHA2)) {
       return armv8_encrypt_blocks(in, out, blocks);
    }
 #endif
 
 #if defined(BOTAN_HAS_SHACAL2_AVX2)
-   if(CPUID::has_avx2()) {
+   if(CPUID::has(CPUID::Feature::AVX2)) {
       while(blocks >= 8) {
          avx2_encrypt_8(in, out);
          in += 8 * BLOCK_SIZE;
@@ -68,7 +80,7 @@ void SHACAL2::encrypt_n(const uint8_t in[], uint8_t out[], size_t blocks) const
 #endif
 
 #if defined(BOTAN_HAS_SHACAL2_SIMD)
-   if(CPUID::has_simd_32()) {
+   if(CPUID::has(CPUID::Feature::SIMD_4X32)) {
       while(blocks >= 4) {
          simd_encrypt_4(in, out);
          in += 4 * BLOCK_SIZE;
@@ -112,8 +124,17 @@ void SHACAL2::encrypt_n(const uint8_t in[], uint8_t out[], size_t blocks) const
 void SHACAL2::decrypt_n(const uint8_t in[], uint8_t out[], size_t blocks) const {
    assert_key_material_set();
 
+#if defined(BOTAN_HAS_SHACAL2_AVX512)
+   if(CPUID::has(CPUID::Feature::AVX512)) {
+      size_t consumed = avx512_decrypt_blocks(in, out, blocks);
+      in += consumed * BLOCK_SIZE;
+      out += consumed * BLOCK_SIZE;
+      blocks -= consumed;
+   }
+#endif
+
 #if defined(BOTAN_HAS_SHACAL2_AVX2)
-   if(CPUID::has_avx2()) {
+   if(CPUID::has(CPUID::Feature::AVX2)) {
       while(blocks >= 8) {
          avx2_decrypt_8(in, out);
          in += 8 * BLOCK_SIZE;
@@ -124,7 +145,7 @@ void SHACAL2::decrypt_n(const uint8_t in[], uint8_t out[], size_t blocks) const
 #endif
 
 #if defined(BOTAN_HAS_SHACAL2_SIMD)
-   if(CPUID::has_simd_32()) {
+   if(CPUID::has(CPUID::Feature::SIMD_4X32)) {
       while(blocks >= 4) {
          simd_decrypt_4(in, out);
          in += 4 * BLOCK_SIZE;
@@ -200,26 +221,32 @@ void SHACAL2::key_schedule(std::span<const uint8_t> key) {
 }
 
 size_t SHACAL2::parallelism() const {
+#if defined(BOTAN_HAS_SHACAL2_AVX512)
+   if(CPUID::has(CPUID::Feature::AVX512)) {
+      return 16;
+   }
+#endif
+
 #if defined(BOTAN_HAS_SHACAL2_X86)
-   if(CPUID::has_intel_sha()) {
+   if(CPUID::has(CPUID::Feature::SHA)) {
       return 2;
    }
 #endif
 
 #if defined(BOTAN_HAS_SHACAL2_ARMV8)
-   if(CPUID::has_arm_sha2()) {
+   if(CPUID::has(CPUID::Feature::SHA2)) {
       return 2;
    }
 #endif
 
 #if defined(BOTAN_HAS_SHACAL2_AVX2)
-   if(CPUID::has_avx2()) {
+   if(CPUID::has(CPUID::Feature::AVX2)) {
       return 8;
    }
 #endif
 
 #if defined(BOTAN_HAS_SHACAL2_SIMD)
-   if(CPUID::has_simd_32()) {
+   if(CPUID::has(CPUID::Feature::SIMD_4X32)) {
       return 4;
    }
 #endif
@@ -228,27 +255,33 @@ size_t SHACAL2::parallelism() const {
 }
 
 std::string SHACAL2::provider() const {
+#if defined(BOTAN_HAS_SHACAL2_AVX512)
+   if(auto feat = CPUID::check(CPUID::Feature::AVX512)) {
+      return *feat;
+   }
+#endif
+
 #if defined(BOTAN_HAS_SHACAL2_X86)
-   if(CPUID::has_intel_sha()) {
-      return "intel_sha";
+   if(auto feat = CPUID::check(CPUID::Feature::SHA)) {
+      return *feat;
    }
 #endif
 
 #if defined(BOTAN_HAS_SHACAL2_ARMV8)
-   if(CPUID::has_arm_sha2()) {
-      return "armv8_sha2";
+   if(auto feat = CPUID::check(CPUID::Feature::SHA2)) {
+      return *feat;
    }
 #endif
 
 #if defined(BOTAN_HAS_SHACAL2_AVX2)
-   if(CPUID::has_avx2()) {
-      return "avx2";
+   if(auto feat = CPUID::check(CPUID::Feature::AVX2)) {
+      return *feat;
    }
 #endif
 
 #if defined(BOTAN_HAS_SHACAL2_SIMD)
-   if(CPUID::has_simd_32()) {
-      return "simd";
+   if(auto feat = CPUID::check(CPUID::Feature::SIMD_4X32)) {
+      return *feat;
    }
 #endif
 
