@@ -31,7 +31,7 @@ class Zlib_Stream : public Zlib_Style_Stream<z_stream, Bytef, unsigned int> {
 
       uint32_t finish_flag() const override { return Z_FINISH; }
 
-      int compute_window_bits(int wbits, int wbits_offset) const {
+      static int compute_window_bits(int wbits, int wbits_offset) {
          if(wbits_offset == -1) {
             return -wbits;
          } else {
@@ -78,7 +78,7 @@ class Zlib_Compression_Stream : public Zlib_Stream {
 
 class Zlib_Decompression_Stream : public Zlib_Stream {
    public:
-      Zlib_Decompression_Stream(int wbits, int wbits_offset = 0) {
+      explicit Zlib_Decompression_Stream(int wbits, int wbits_offset = 0) {
          int rc = ::inflateInit2(streamp(), compute_window_bits(wbits, wbits_offset));
 
          if(rc != Z_OK) {
@@ -129,7 +129,7 @@ class Gzip_Compression_Stream final : public Zlib_Compression_Stream {
       }
 
    private:
-      ::gz_header m_header;
+      ::gz_header m_header{};
 };
 
 class Gzip_Decompression_Stream final : public Zlib_Decompression_Stream {
