@@ -27,7 +27,7 @@ StreamCipher_Filter::StreamCipher_Filter(std::string_view sc_name, const Symmetr
 }
 
 void StreamCipher_Filter::write(const uint8_t input[], size_t length) {
-   while(length) {
+   while(length > 0) {
       size_t copied = std::min<size_t>(length, m_buffer.size());
       m_cipher->cipher(input, m_buffer.data(), copied);
       send(m_buffer, copied);
@@ -45,7 +45,7 @@ Hash_Filter::Hash_Filter(std::string_view hash_name, size_t len) :
 
 void Hash_Filter::end_msg() {
    secure_vector<uint8_t> output = m_hash->final();
-   if(m_out_len) {
+   if(m_out_len != 0) {
       send(output, std::min<size_t>(m_out_len, output.size()));
    } else {
       send(output);
@@ -64,7 +64,7 @@ MAC_Filter::MAC_Filter(std::string_view mac_name, const SymmetricKey& key, size_
 
 void MAC_Filter::end_msg() {
    secure_vector<uint8_t> output = m_mac->final();
-   if(m_out_len) {
+   if(m_out_len != 0) {
       send(output, std::min<size_t>(m_out_len, output.size()));
    } else {
       send(output);
