@@ -6,9 +6,7 @@
 
 #include <botan/internal/sha2_64.h>
 
-#include <botan/internal/bit_ops.h>
 #include <botan/internal/isa_extn.h>
-#include <botan/internal/rotate.h>
 #include <botan/internal/sha2_64_f.h>
 #include <botan/internal/simd_2x64.h>
 #include <botan/internal/simd_4x64.h>
