@@ -12,7 +12,8 @@
 
 namespace Botan {
 
-SHAKE_128::SHAKE_128(size_t output_bits) : m_keccak(256, 0xF, 4), m_output_bits(output_bits) {
+SHAKE_128::SHAKE_128(size_t output_bits) :
+      m_keccak({.capacity_bits = 256, .padding = KeccakPadding::shake()}), m_output_bits(output_bits) {
    if(output_bits % 8 != 0) {
       throw Invalid_Argument(fmt("SHAKE_128: Invalid output length {}", output_bits));
    }
@@ -40,7 +41,8 @@ void SHAKE_128::final_result(std::span<uint8_t> output) {
    clear();
 }
 
-SHAKE_256::SHAKE_256(size_t output_bits) : m_keccak(512, 0xF, 4), m_output_bits(output_bits) {
+SHAKE_256::SHAKE_256(size_t output_bits) :
+      m_keccak({.capacity_bits = 512, .padding = KeccakPadding::shake()}), m_output_bits(output_bits) {
    if(output_bits % 8 != 0) {
       throw Invalid_Argument(fmt("SHAKE_256: Invalid output length {}", output_bits));
    }
