@@ -9,9 +9,9 @@
 
 #include <botan/internal/hkdf.h>
 
-#include <botan/exceptn.h>
 #include <botan/internal/fmt.h>
 #include <botan/internal/loadstor.h>
+#include <botan/internal/mem_utils.h>
 #include <botan/internal/stl_util.h>
 
 namespace Botan {
@@ -49,7 +49,7 @@ void HKDF_Extract::perform_kdf(std::span<uint8_t> key,
                                std::span<const uint8_t> salt,
                                std::span<const uint8_t> label) const {
    const size_t prf_output_len = m_prf->output_length();
-   BOTAN_ARG_CHECK(key.size() <= prf_output_len, "HKDF-Extract maximum output length exceeeded");
+   BOTAN_ARG_CHECK(key.size() <= prf_output_len, "HKDF-Extract maximum output length exceeded");
    BOTAN_ARG_CHECK(label.empty(), "HKDF-Extract does not support a label input");
 
    if(key.empty()) {
@@ -85,7 +85,7 @@ void HKDF_Expand::perform_kdf(std::span<uint8_t> key,
                               std::span<const uint8_t> salt,
                               std::span<const uint8_t> label) const {
    const auto prf_output_length = m_prf->output_length();
-   BOTAN_ARG_CHECK(key.size() <= prf_output_length * 255, "HKDF-Expand maximum output length exceeeded");
+   BOTAN_ARG_CHECK(key.size() <= prf_output_length * 255, "HKDF-Expand maximum output length exceeded");
 
    if(key.empty()) {
       return;
@@ -128,7 +128,7 @@ secure_vector<uint8_t> hkdf_expand_label(std::string_view hash_fn,
 
    const auto prefix = concat<std::vector<uint8_t>>(store_be(static_cast<uint16_t>(length)),
                                                     store_be(static_cast<uint8_t>(label.size())),
-                                                    std::span{cast_char_ptr_to_uint8(label.data()), label.size()},
+                                                    as_span_of_bytes(label),
                                                     store_be(static_cast<uint8_t>(hash_val.size())));
 
    /*
