@@ -7,10 +7,12 @@
 
 #include <botan/kdf.h>
 
+#include <botan/assert.h>
 #include <botan/exceptn.h>
 #include <botan/hash.h>
 #include <botan/mac.h>
 #include <botan/internal/fmt.h>
+#include <botan/internal/mem_utils.h>
 #include <botan/internal/scan_name.h>
 
 #if defined(BOTAN_HAS_HKDF)
@@ -210,4 +212,9 @@ std::vector<std::string> KDF::providers(std::string_view algo_spec) {
    return probe_providers_of<KDF>(algo_spec);
 }
 
+//static
+std::span<const uint8_t> KDF::_as_span(std::string_view s) {
+   return as_span_of_bytes(s);
+}
+
 }  // namespace Botan
