@@ -13,7 +13,6 @@
 #include <botan/internal/ct_utils.h>
 #include <botan/internal/donna128.h>
 #include <botan/internal/loadstor.h>
-#include <botan/internal/mul128.h>
 #include <botan/internal/stl_util.h>
 
 namespace Botan {
@@ -82,7 +81,7 @@ void poly1305_blocks(secure_vector<uint64_t>& X, const uint8_t* m, size_t blocks
       h2 = d2 & M42;
 
       h0 += c2 * 5;
-      h1 += carry_shift(h0, 44);
+      h1 += h0 >> 44;
       h0 = h0 & M44;
 
       m += 16;
@@ -102,8 +101,7 @@ void poly1305_finish(secure_vector<uint64_t>& X, uint8_t mac[16]) {
    uint64_t h1 = X[3 + 1];
    uint64_t h2 = X[3 + 2];
 
-   uint64_t c;
-   c = (h1 >> 44);
+   uint64_t c = (h1 >> 44);
    h1 &= M44;
    h2 += c;
    c = (h2 >> 42);
