@@ -120,11 +120,11 @@ BigInt random_prime(
       }
 
       if(bits == 2) {
-         return BigInt::from_word(((rng.next_byte() % 2) ? 2 : 3));
+         return BigInt::from_word(((rng.next_byte() % 2) == 0 ? 2 : 3));
       } else if(bits == 3) {
-         return BigInt::from_word(((rng.next_byte() % 2) ? 5 : 7));
+         return BigInt::from_word(((rng.next_byte() % 2) == 0 ? 5 : 7));
       } else if(bits == 4) {
-         return BigInt::from_word(((rng.next_byte() % 2) ? 11 : 13));
+         return BigInt::from_word(((rng.next_byte() % 2) == 0 ? 11 : 13));
       } else {
          for(;;) {
             // This is slightly biased, but for small primes it does not seem to matter
@@ -175,10 +175,10 @@ BigInt random_prime(
 
          if(coprime > 1) {
             /*
-            First do a single M-R iteration to quickly elimate most non-primes,
+            First do a single M-R iteration to quickly eliminate most non-primes,
             before doing the coprimality check which is expensive
             */
-            if(is_miller_rabin_probable_prime(p, mod_p, rng, 1) == false) {
+            if(!is_miller_rabin_probable_prime(p, mod_p, rng, 1)) {
                continue;
             }
 
@@ -195,7 +195,7 @@ BigInt random_prime(
             break;
          }
 
-         if(is_miller_rabin_probable_prime(p, mod_p, rng, mr_trials) == false) {
+         if(!is_miller_rabin_probable_prime(p, mod_p, rng, mr_trials)) {
             continue;
          }
 
@@ -266,7 +266,7 @@ BigInt generate_rsa_prime(RandomNumberGenerator& keygen_rng,
          * currently a single Miller-Rabin test is faster than computing gcd,
          * and this eliminates almost all wasted gcd computations.
          */
-         if(is_miller_rabin_probable_prime(p, mod_p, prime_test_rng, 1) == false) {
+         if(!is_miller_rabin_probable_prime(p, mod_p, prime_test_rng, 1)) {
             continue;
          }
 
@@ -281,7 +281,7 @@ BigInt generate_rsa_prime(RandomNumberGenerator& keygen_rng,
             break;
          }
 
-         if(is_miller_rabin_probable_prime(p, mod_p, prime_test_rng, mr_trials) == true) {
+         if(is_miller_rabin_probable_prime(p, mod_p, prime_test_rng, mr_trials)) {
             return p;
          }
       }
@@ -298,7 +298,8 @@ BigInt random_safe_prime(RandomNumberGenerator& rng, size_t bits) {
 
    const size_t error_bound = 128;
 
-   BigInt q, p;
+   BigInt q;
+   BigInt p;
    for(;;) {
       /*
       Generate q == 2 (mod 3), since otherwise [in the case of q == 1 (mod 3)],
