@@ -20,7 +20,7 @@ namespace Botan {
 class Cipher_Mode;
 class BlockCipher;
 class HashFunction;
-enum class Cipher_Dir : int;
+enum class Cipher_Dir : uint8_t;
 typedef int32_t CCCryptorStatus;
 
 class BOTAN_PUBLIC_API(2, 0) CommonCrypto_Error final : public Exception {
