@@ -36,8 +36,8 @@ constexpr TPM2_HANDLE storage_root_key_handle = TPM2_HR_PERSISTENT + 1;
 }  // namespace
 
 struct Context::Impl {
-      ESYS_CONTEXT* m_ctx;  /// m_ctx may be owned by the library user (see m_external)
-      bool m_external;
+      ESYS_CONTEXT* m_ctx{};  /// m_ctx may be owned by the library user (see m_external)
+      bool m_external{};
 
 #if defined(BOTAN_HAS_TPM2_CRYPTO_BACKEND)
       std::unique_ptr<CryptoCallbackState> m_crypto_callback_state;
@@ -53,11 +53,9 @@ bool Context::supports_botan_crypto_backend() noexcept {
 }
 
 std::shared_ptr<Context> Context::create(const std::string& tcti_nameconf) {
-   const auto nameconf_ptr = tcti_nameconf.c_str();
-
    TSS2_TCTI_CONTEXT* tcti_ctx = nullptr;
    ESYS_CONTEXT* esys_ctx = nullptr;
-   check_rc("TCTI Initialization", Tss2_TctiLdr_Initialize(nameconf_ptr, &tcti_ctx));
+   check_rc("TCTI Initialization", Tss2_TctiLdr_Initialize(tcti_nameconf.c_str(), &tcti_ctx));
    BOTAN_ASSERT_NONNULL(tcti_ctx);
    check_rc("TPM2 Initialization", Esys_Initialize(&esys_ctx, tcti_ctx, nullptr /* ABI version */));
    BOTAN_ASSERT_NONNULL(esys_ctx);
@@ -67,8 +65,8 @@ std::shared_ptr<Context> Context::create(const std::string& tcti_nameconf) {
 }
 
 std::shared_ptr<Context> Context::create(std::optional<std::string> tcti, std::optional<std::string> conf) {
-   const auto tcti_ptr = tcti.has_value() ? tcti->c_str() : nullptr;
-   const auto conf_ptr = conf.has_value() ? conf->c_str() : nullptr;
+   const char* const tcti_ptr = tcti.has_value() ? tcti->c_str() : nullptr;
+   const char* const conf_ptr = conf.has_value() ? conf->c_str() : nullptr;
 
    TSS2_TCTI_CONTEXT* tcti_ctx = nullptr;
    ESYS_CONTEXT* esys_ctx = nullptr;
@@ -345,15 +343,10 @@ TPM2_HANDLE Context::persist(TPM2::PrivateKey& key,
 
    // 1. Decide on the location to persist the key to.
    //    This uses either the handle provided by the caller or a free handle.
-   const TPMI_DH_PERSISTENT new_persistent_handle = [&] {
-      if(persistent_handle.has_value()) {
-         return persistent_handle.value();
-      } else {
-         const auto free_persistent_handle = find_free_persistent_handle();
-         BOTAN_STATE_CHECK(free_persistent_handle.has_value());
-         return free_persistent_handle.value();
-      }
-   }();
+   const std::optional<TPMI_DH_PERSISTENT> new_persistent_handle =
+      persistent_handle.has_value() ? persistent_handle : find_free_persistent_handle();
+
+   BOTAN_STATE_CHECK(new_persistent_handle.has_value());
 
    // 2. Persist the transient key in the TPM's NV storage
    //    This will flush the transient key handle and replace it with a new
@@ -365,7 +358,7 @@ TPM2_HANDLE Context::persist(TPM2::PrivateKey& key,
                               sessions[0],
                               sessions[1],
                               sessions[2],
-                              new_persistent_handle,
+                              *new_persistent_handle,
                               out_transient_handle(handles)));
    BOTAN_ASSERT_NOMSG(handles.has_transient_handle());
 
@@ -384,9 +377,9 @@ TPM2_HANDLE Context::persist(TPM2::PrivateKey& key,
             Esys_TR_GetTpmHandle(m_impl->m_ctx, handles.transient_handle(), out_persistent_handle(handles)));
 
    BOTAN_ASSERT_NOMSG(handles.has_persistent_handle());
-   BOTAN_ASSERT_EQUAL(new_persistent_handle, handles.persistent_handle(), "key was persisted at the correct location");
+   BOTAN_ASSERT_EQUAL(*new_persistent_handle, handles.persistent_handle(), "key was persisted at the correct location");
 
-   return new_persistent_handle;
+   return *new_persistent_handle;
 }
 
 void Context::evict(std::unique_ptr<TPM2::PrivateKey> key, const SessionBundle& sessions) {
