@@ -13,9 +13,9 @@
 #include <botan/rsa.h>
 
 #include <botan/internal/ct_utils.h>
-#include <botan/internal/emsa.h>
 #include <botan/internal/fmt.h>
 #include <botan/internal/scan_name.h>
+#include <botan/internal/sig_padding.h>
 #include <botan/internal/stl_util.h>
 #include <botan/internal/tpm2_algo_mappings.h>
 #include <botan/internal/tpm2_hash.h>
@@ -26,17 +26,6 @@
 
 namespace Botan::TPM2 {
 
-std::pair<BigInt, BigInt> rsa_pubkey_components_from_tss2_public(const TPM2B_PUBLIC* public_area) {
-   BOTAN_ASSERT_NONNULL(public_area);
-   const auto& pub = public_area->publicArea;
-   BOTAN_ARG_CHECK(pub.type == TPM2_ALG_RSA, "Public key is not an RSA key");
-
-   // TPM2 may report 0 when the exponent is 'the default' (2^16 + 1)
-   const auto exponent = (pub.parameters.rsaDetail.exponent == 0) ? 65537 : pub.parameters.rsaDetail.exponent;
-
-   return {BigInt(as_span(pub.unique.rsa)), exponent};
-}
-
 RSA_PublicKey::RSA_PublicKey(Object handle, SessionBundle session_bundle, const TPM2B_PUBLIC* public_blob) :
       Botan::TPM2::RSA_PublicKey(
          std::move(handle), std::move(session_bundle), rsa_pubkey_components_from_tss2_public(public_blob)) {}
@@ -171,7 +160,7 @@ SignatureAlgorithmSelection select_signature_algorithms(std::string_view padding
    };
 }
 
-size_t signature_length_for_key_handle(const SessionBundle& sessions, const Object& key_handle) {
+size_t signature_length_for_rsa_key_handle(const SessionBundle& sessions, const Object& key_handle) {
    return key_handle._public_info(sessions, TPM2_ALG_RSA).pub->publicArea.parameters.rsaDetail.keyBits / 8;
 }
 
@@ -180,7 +169,7 @@ class RSA_Signature_Operation final : public Signature_Operation {
       RSA_Signature_Operation(const Object& object, const SessionBundle& sessions, std::string_view padding) :
             Signature_Operation(object, sessions, select_signature_algorithms(padding)) {}
 
-      size_t signature_length() const override { return signature_length_for_key_handle(sessions(), key_handle()); }
+      size_t signature_length() const override { return signature_length_for_rsa_key_handle(sessions(), key_handle()); }
 
       AlgorithmIdentifier algorithm_identifier() const override {
          // TODO: This is essentially a copy of the ::algorithm_identifier()
@@ -192,21 +181,20 @@ class RSA_Signature_Operation final : public Signature_Operation {
          //
          // TODO: This is a hack, and we should clean this up.
          BOTAN_STATE_CHECK(padding().has_value());
-         const auto emsa = EMSA::create_or_throw(padding().value());
-         const std::string emsa_name = emsa->name();
+         const std::string padding_name = SignaturePaddingScheme::create_or_throw(padding().value())->name();
 
          try {
-            const std::string full_name = "RSA/" + emsa_name;
+            const std::string full_name = "RSA/" + padding_name;
             const OID oid = OID::from_string(full_name);
             return AlgorithmIdentifier(oid, AlgorithmIdentifier::USE_EMPTY_PARAM);
          } catch(Lookup_Error&) {}
 
-         if(emsa_name.starts_with("PSS(")) {
-            auto parameters = PSS_Params::from_emsa_name(emsa_name).serialize();
+         if(padding_name.starts_with("PSS(")) {
+            auto parameters = PSS_Params::from_padding_name(padding_name).serialize();
             return AlgorithmIdentifier("RSA/PSS", parameters);
          }
 
-         throw Invalid_Argument(fmt("Signatures using RSA/{} are not supported", emsa_name));
+         throw Invalid_Argument(fmt("Signatures using RSA/{} are not supported", padding_name));
       }
 
    private:
@@ -232,7 +220,7 @@ class RSA_Verification_Operation final : public Verification_Operation {
 
    private:
       TPMT_SIGNATURE unmarshal_signature(std::span<const uint8_t> signature) const override {
-         BOTAN_ARG_CHECK(signature.size() == signature_length_for_key_handle(sessions(), key_handle()),
+         BOTAN_ARG_CHECK(signature.size() == signature_length_for_rsa_key_handle(sessions(), key_handle()),
                          "Unexpected signature byte length");
 
          TPMT_SIGNATURE sig;
@@ -279,7 +267,7 @@ class RSA_Encryption_Operation final : public PK_Ops::Encryption {
 
          unique_esys_ptr<TPM2B_PUBLIC_KEY_RSA> ciphertext;
          check_rc("Esys_RSA_Encrypt",
-                  Esys_RSA_Encrypt(*m_key_handle.context(),
+                  Esys_RSA_Encrypt(m_key_handle.context()->esys_context(),
                                    m_key_handle.transient_handle(),
                                    m_sessions[0],
                                    m_sessions[1],
@@ -358,7 +346,7 @@ class RSA_Decryption_Operation final : public PK_Ops::Decryption {
          //       all cases here. It passed the test (with a faulty ciphertext),
          //       but I didn't find this to be clearly documented. :-(
          auto rc = check_rc_expecting<TPM2_RC_FAILURE>("Esys_RSA_Decrypt",
-                                                       Esys_RSA_Decrypt(*m_key_handle.context(),
+                                                       Esys_RSA_Decrypt(m_key_handle.context()->esys_context(),
                                                                         m_key_handle.transient_handle(),
                                                                         m_sessions[0],
                                                                         m_sessions[1],
