@@ -17,7 +17,7 @@ namespace Botan {
 
 class Dilithium_Symmetric_Primitives final : public Dilithium_Round3_Symmetric_Primitives {
    public:
-      Dilithium_Symmetric_Primitives(const DilithiumConstants& mode) :
+      explicit Dilithium_Symmetric_Primitives(const DilithiumConstants& mode) :
             Dilithium_Round3_Symmetric_Primitives(mode, std::make_unique<DilithiumShakeXOF>()) {}
 };
 
