@@ -11,7 +11,7 @@
 #include <botan/der_enc.h>
 #include <botan/numthry.h>
 #include <botan/pem.h>
-#include <botan/reducer.h>
+#include <botan/internal/barrett.h>
 #include <botan/internal/divide.h>
 #include <botan/internal/fmt.h>
 #include <botan/internal/mod_inv.h>
@@ -29,9 +29,9 @@ class DL_Group_Data final {
             m_p(p),
             m_q(q),
             m_g(g),
-            m_mod_p(Modular_Reducer::for_public_modulus(p)),
-            m_mod_q(Modular_Reducer::for_public_modulus(q)),
-            m_monty_params(std::make_shared<Montgomery_Params>(m_p, m_mod_p)),
+            m_mod_p(Barrett_Reduction::for_public_modulus(p)),
+            m_mod_q(Barrett_Reduction::for_public_modulus(q)),
+            m_monty_params(m_p, m_mod_p),
             m_monty(monty_precompute(m_monty_params, m_g, /*window bits=*/4)),
             m_p_bits(p.bits()),
             m_q_bits(q.bits()),
@@ -42,8 +42,8 @@ class DL_Group_Data final {
       DL_Group_Data(const BigInt& p, const BigInt& g, DL_Group_Source source) :
             m_p(p),
             m_g(g),
-            m_mod_p(Modular_Reducer::for_public_modulus(p)),
-            m_monty_params(std::make_shared<Montgomery_Params>(m_p, m_mod_p)),
+            m_mod_p(Barrett_Reduction::for_public_modulus(p)),
+            m_monty_params(m_p, m_mod_p),
             m_monty(monty_precompute(m_monty_params, m_g, /*window bits=*/4)),
             m_p_bits(p.bits()),
             m_q_bits(0),
@@ -64,14 +64,14 @@ class DL_Group_Data final {
 
       const BigInt& g() const { return m_g; }
 
-      const Modular_Reducer& reducer_mod_p() const { return m_mod_p; }
+      const Barrett_Reduction& reducer_mod_p() const { return m_mod_p; }
 
-      const Modular_Reducer& reducer_mod_q() const {
+      const Barrett_Reduction& reducer_mod_q() const {
          BOTAN_STATE_CHECK(m_mod_q);
          return *m_mod_q;
       }
 
-      std::shared_ptr<const Montgomery_Params> monty_params_p() const { return m_monty_params; }
+      const Montgomery_Params& monty_params_p() const { return m_monty_params; }
 
       size_t p_bits() const { return m_p_bits; }
 
@@ -102,7 +102,7 @@ class DL_Group_Data final {
       bool q_is_set() const { return m_q_bits > 0; }
 
       void assert_q_is_set(std::string_view function) const {
-         if(q_is_set() == false) {
+         if(!q_is_set()) {
             throw Invalid_State(fmt("DL_Group::{}: q is not set for this group", function));
          }
       }
@@ -113,10 +113,10 @@ class DL_Group_Data final {
       BigInt m_p;
       BigInt m_q;  // zero if no q set
       BigInt m_g;
-      Modular_Reducer m_mod_p;
-      std::optional<Modular_Reducer> m_mod_q;
-      std::shared_ptr<const Montgomery_Params> m_monty_params;
-      std::shared_ptr<const Montgomery_Exponentation_State> m_monty;
+      Barrett_Reduction m_mod_p;
+      std::optional<Barrett_Reduction> m_mod_q;
+      Montgomery_Params m_monty_params;
+      std::shared_ptr<const Montgomery_Exponentiation_State> m_monty;
       size_t m_p_bits;
       size_t m_q_bits;
       size_t m_estimated_strength;
@@ -133,15 +133,20 @@ std::shared_ptr<DL_Group_Data> DL_Group::BER_decode_DL_group(const uint8_t data[
    BER_Decoder ber = decoder.start_sequence();
 
    if(format == DL_Group_Format::ANSI_X9_57) {
-      BigInt p, q, g;
+      BigInt p;
+      BigInt q;
+      BigInt g;
       ber.decode(p).decode(q).decode(g).verify_end();
       return std::make_shared<DL_Group_Data>(p, q, g, source);
    } else if(format == DL_Group_Format::ANSI_X9_42) {
-      BigInt p, g, q;
+      BigInt p;
+      BigInt g;
+      BigInt q;
       ber.decode(p).decode(g).decode(q).discard_remaining();
       return std::make_shared<DL_Group_Data>(p, q, g, source);
    } else if(format == DL_Group_Format::PKCS_3) {
-      BigInt p, g;
+      BigInt p;
+      BigInt g;
       ber.decode(p).decode(g).discard_remaining();
       return std::make_shared<DL_Group_Data>(p, g, source);
    } else {
@@ -233,16 +238,20 @@ namespace {
 * Create generator of the q-sized subgroup (DSA style generator)
 */
 BigInt make_dsa_generator(const BigInt& p, const BigInt& q) {
-   BigInt e, r;
+   BigInt e;
+   BigInt r;
    vartime_divide(p - 1, q, e, r);
 
    if(e == 0 || r > 0) {
       throw Invalid_Argument("make_dsa_generator q does not divide p-1");
    }
 
+   // TODO we compute these, then throw them away and recompute in DL_Group_Data
+   auto mod_p = Barrett_Reduction::for_public_modulus(p);
+   Montgomery_Params params(p, mod_p);
+
    for(size_t i = 0; i != PRIME_TABLE_SIZE; ++i) {
-      // TODO precompute!
-      BigInt g = power_mod(BigInt::from_word(PRIMES[i]), e, p);
+      BigInt g = monty_exp_vartime(params, BigInt::from_word(PRIMES[i]), e).value();
       if(g > 1) {
          return g;
       }
@@ -274,18 +283,15 @@ DL_Group::DL_Group(RandomNumberGenerator& rng, PrimeType type, size_t pbits, siz
       const BigInt q = (p - 1) / 2;
 
       /*
-      Always choose a generator that is quadratic reside mod p,
-      this forces g to be a generator of the subgroup of size q.
+      Always choose a generator that is quadratic reside mod p, this forces g to
+      be a generator of the subgroup of size q.
+
+      We use 2 by default, but if 2 is not a quadratic reside then use 4 which
+      is always a quadratic reside, being the square of 2 (or p - 2)
       */
       BigInt g = BigInt::from_word(2);
       if(jacobi(g, p) != 1) {
-         // prime table does not contain 2
-         for(size_t i = 0; i < PRIME_TABLE_SIZE; ++i) {
-            g = BigInt::from_word(PRIMES[i]);
-            if(jacobi(g, p) == 1) {
-               break;
-            }
-         }
+         g = BigInt::from_word(4);
       }
 
       m_data = std::make_shared<DL_Group_Data>(p, q, g, DL_Group_Source::RandomlyGenerated);
@@ -295,12 +301,13 @@ DL_Group::DL_Group(RandomNumberGenerator& rng, PrimeType type, size_t pbits, siz
       }
 
       const BigInt q = random_prime(rng, qbits);
-      auto mod_2q = Modular_Reducer::for_public_modulus(2 * q);
+      const BigInt q2 = q * 2;
       BigInt X;
       BigInt p;
       while(p.bits() != pbits || !is_prime(p, rng, 128, true)) {
          X.randomize(rng, pbits);
-         p = X - mod_2q.reduce(X) + 1;
+         // Variable time division is OK here since DH groups are public anyway
+         p = X - (X % q2) + 1;
       }
 
       const BigInt g = make_dsa_generator(p, q);
@@ -310,7 +317,8 @@ DL_Group::DL_Group(RandomNumberGenerator& rng, PrimeType type, size_t pbits, siz
          qbits = ((pbits <= 1024) ? 160 : 256);
       }
 
-      BigInt p, q;
+      BigInt p;
+      BigInt q;
       generate_dsa_primes(rng, p, q, pbits, qbits);
       const BigInt g = make_dsa_generator(p, q);
       m_data = std::make_shared<DL_Group_Data>(p, q, g, DL_Group_Source::RandomlyGenerated);
@@ -323,7 +331,8 @@ DL_Group::DL_Group(RandomNumberGenerator& rng, PrimeType type, size_t pbits, siz
 * DL_Group Constructor
 */
 DL_Group::DL_Group(RandomNumberGenerator& rng, const std::vector<uint8_t>& seed, size_t pbits, size_t qbits) {
-   BigInt p, q;
+   BigInt p;
+   BigInt q;
 
    if(!generate_dsa_primes(rng, p, q, pbits, qbits, seed)) {
       throw Invalid_Argument("DL_Group: The seed given does not generate a DSA group");
@@ -368,7 +377,7 @@ bool DL_Group::verify_public_element(const BigInt& y) const {
       return false;
    }
 
-   if(q.is_zero() == false) {
+   if(!q.is_zero()) {
       if(data().power_b_p_vartime(y, q) != 1) {
          return false;
       }
@@ -480,7 +489,7 @@ const BigInt& DL_Group::get_q() const {
    return data().q();
 }
 
-std::shared_ptr<const Montgomery_Params> DL_Group::monty_params_p() const {
+const Montgomery_Params& DL_Group::_monty_params_p() const {
    return data().monty_params_p();
 }
 
@@ -527,7 +536,7 @@ BigInt DL_Group::multiply_mod_p(const BigInt& x, const BigInt& y) const {
    return data().reducer_mod_p().multiply(x, y);
 }
 
-const Modular_Reducer& DL_Group::_reducer_mod_p() const {
+const Barrett_Reduction& DL_Group::_reducer_mod_p() const {
    return data().reducer_mod_p();
 }
 
