@@ -10,7 +10,7 @@
 #include <botan/mem_ops.h>
 #include <botan/internal/ct_utils.h>
 #include <botan/internal/stl_util.h>
-#include <limits>
+#include <span>
 
 namespace Botan {
 
@@ -28,15 +28,14 @@ DLIES_Encryptor::DLIES_Encryptor(const DH_PrivateKey& own_priv_key,
                                  size_t cipher_key_len,
                                  std::unique_ptr<MessageAuthenticationCode> mac,
                                  size_t mac_key_length) :
-      m_other_pub_key(),
+
       m_own_pub_key(own_priv_key.public_value()),
       m_ka(own_priv_key, rng, "Raw"),
       m_kdf(std::move(kdf)),
       m_cipher(std::move(cipher)),
       m_cipher_key_len(cipher_key_len),
       m_mac(std::move(mac)),
-      m_mac_keylen(mac_key_length),
-      m_iv() {
+      m_mac_keylen(mac_key_length) {
    BOTAN_ASSERT_NONNULL(m_kdf);
    BOTAN_ASSERT_NONNULL(m_mac);
 }
@@ -107,8 +106,7 @@ DLIES_Decryptor::DLIES_Decryptor(const DH_PrivateKey& own_priv_key,
       m_cipher(std::move(cipher)),
       m_cipher_key_len(cipher_key_len),
       m_mac(std::move(mac)),
-      m_mac_keylen(mac_key_length),
-      m_iv() {
+      m_mac_keylen(mac_key_length) {
    BOTAN_ASSERT_NONNULL(m_kdf);
    BOTAN_ASSERT_NONNULL(m_mac);
 }
@@ -155,14 +153,14 @@ secure_vector<uint8_t> DLIES_Decryptor::do_decrypt(uint8_t& valid_mask, const ui
    secure_vector<uint8_t> calculated_tag = m_mac->process(ciphertext);
 
    // calculated tag == received tag ?
-   secure_vector<uint8_t> tag(msg + m_pub_key_size + ciphertext_len,
-                              msg + m_pub_key_size + ciphertext_len + m_mac->output_length());
+
+   std::span<const uint8_t> tag(msg + m_pub_key_size + ciphertext_len, m_mac->output_length());
 
    valid_mask = CT::is_equal(tag.data(), calculated_tag.data(), tag.size()).value();
 
    // decrypt
    if(m_cipher) {
-      if(valid_mask) {
+      if(valid_mask == 0xFF) {
          SymmetricKey dec_key(secret_keys.data(), cipher_key_len);
          m_cipher->set_key(dec_key);
 
