@@ -27,10 +27,13 @@ class Atomic final {
 
       Atomic(const Atomic& data) : m_data(data.m_data.load()) {}
 
-      Atomic(const std::atomic<T>& data) : m_data(data.load()) {}
+      explicit Atomic(const std::atomic<T>& data) : m_data(data.load()) {}
 
       ~Atomic() = default;
 
+      Atomic(Atomic&& other) = default;
+      Atomic& operator=(Atomic&& other) = default;
+
       Atomic& operator=(const Atomic& other) {
          if(this != &other) {
             m_data.store(other.m_data.load());
@@ -43,8 +46,9 @@ class Atomic final {
          return *this;
       }
 
-      operator std::atomic<T>&() { return m_data; }
+      explicit operator std::atomic<T>&() { return m_data; }
 
+      // NOLINTNEXTLINE(*-explicit-conversions) FIXME
       operator T() { return m_data.load(); }
 
    private:
