@@ -18,12 +18,15 @@ namespace Botan {
 
 /**
  * A registry for XMSS private keys, keeps track of the leaf index for
- * independend copies of the same key.
+ * independent copies of the same key.
  **/
 class XMSS_Index_Registry final {
    public:
       XMSS_Index_Registry(const XMSS_Index_Registry&) = delete;
+      XMSS_Index_Registry(XMSS_Index_Registry&&) = delete;
       XMSS_Index_Registry& operator=(const XMSS_Index_Registry&) = delete;
+      XMSS_Index_Registry& operator=(XMSS_Index_Registry&&) = delete;
+      ~XMSS_Index_Registry() = default;
 
       /**
        * Retrieves a handle to the process-wide unique XMSS index registry.
@@ -52,8 +55,6 @@ class XMSS_Index_Registry final {
    private:
       XMSS_Index_Registry() = default;
 
-      static const std::string m_index_hash_function;
-
       /**
        * Creates a unique 64-bit id for an XMSS_Private key, by interpreting
        * the first 64-bit of HASH(PRIVATE_SEED || PRF) as 64 bit integer
@@ -78,13 +79,13 @@ class XMSS_Index_Registry final {
        * position of the according registry entry is returned. If last_unused
        * is bigger than the last unused index stored for the key identified by
        * id the unused leaf index for this key is set to last_unused. If no key
-       * matching id is registed yet, an entry of id is added, with the last
+       * matching id is registered yet, an entry of id is added, with the last
        * unused leaf index initialized to the value of last_unused.
        *
        * @last_unused Initial value for the last unused leaf index of the
        *              registered key.
        *
-       * @return positon of leaf index registry entry for key identified
+       * @return position of leaf index registry entry for key identified
        *         by id.
        **/
       size_t add(uint64_t id, size_t last_unused = 0);
