@@ -29,7 +29,7 @@ namespace {
  * the input x using the outputs of the PRNG "G".
  *
  * This overload is used in multithreaded scenarios, where it is
- * required to provide seperate instances of XMSS_Hash to each
+ * required to provide separate instances of XMSS_Hash to each
  * thread.
  *
  * @param params      The WOTS parameters to use
@@ -155,7 +155,7 @@ XMSS_WOTS_PrivateKey::XMSS_WOTS_PrivateKey(XMSS_WOTS_Parameters params,
    hash.prf(r, private_seed, adrs.bytes());
 
    for(size_t i = 0; i < m_params.len(); ++i) {
-      XMSS_Tools::concat<size_t>(m_key_data[i], i, 32);
+      xmss_concat<size_t>(m_key_data[i], i, 32);
       hash.prf(m_key_data[i], r, m_key_data[i]);
    }
 }
