@@ -7,7 +7,6 @@
 #include <botan/auto_rng.h>
 
 #include <botan/hmac_drbg.h>
-#include <botan/internal/loadstor.h>
 
 #if defined(BOTAN_HAS_ENTROPY_SOURCE)
    #include <botan/entropy_src.h>
@@ -39,6 +38,8 @@ std::unique_ptr<MessageAuthenticationCode> auto_rng_hmac() {
 
 }  // namespace
 
+AutoSeeded_RNG::AutoSeeded_RNG(AutoSeeded_RNG&& other) noexcept = default;
+
 AutoSeeded_RNG::~AutoSeeded_RNG() = default;
 
 AutoSeeded_RNG::AutoSeeded_RNG(RandomNumberGenerator& underlying_rng, size_t reseed_interval) {
