@@ -8,8 +8,9 @@
 
 #include <botan/internal/cpuid.h>
 #include <botan/internal/loadstor.h>
+#include <botan/internal/target_info.h>
 
-#if defined(BOTAN_TARGET_CPU_IS_X86_FAMILY)
+#if defined(BOTAN_TARGET_ARCH_IS_X86_FAMILY) && !defined(BOTAN_USE_GCC_INLINE_ASM)
    #include <immintrin.h>
 #endif
 
@@ -17,14 +18,14 @@ namespace Botan {
 
 namespace {
 
-#if defined(BOTAN_TARGET_CPU_IS_X86_FAMILY)
+#if defined(BOTAN_TARGET_ARCH_IS_X86_FAMILY)
 /*
    * According to Intel, RDRAND is guaranteed to generate a random
    * number within 10 retries on a working CPU
    */
 const size_t HWRNG_RETRIES = 10;
 
-#elif defined(BOTAN_TARGET_CPU_IS_PPC_FAMILY)
+#elif defined(BOTAN_TARGET_ARCH_IS_PPC_FAMILY)
 /**
     * PowerISA 3.0 p.78:
     *    When the error value is obtained, software is expected to repeat the
@@ -51,10 +52,11 @@ hwrng_output read_hwrng(bool& success) {
    hwrng_output output = 0;
    success = false;
 
-#if defined(BOTAN_TARGET_CPU_IS_X86_FAMILY)
+#if defined(BOTAN_TARGET_ARCH_IS_X86_FAMILY)
    int cf = 0;
    #if defined(BOTAN_USE_GCC_INLINE_ASM)
    // same asm seq works for 32 and 64 bit
+   // NOLINTNEXTLINE(*-no-assembler)
    asm volatile("rdrand %0; adcl $0,%1" : "=r"(output), "=r"(cf) : "0"(output), "1"(cf) : "cc");
    #elif defined(BOTAN_TARGET_ARCH_IS_X86_32)
    cf = _rdrand32_step(&output);
@@ -63,7 +65,7 @@ hwrng_output read_hwrng(bool& success) {
    #endif
    success = (1 == cf);
 
-#elif defined(BOTAN_TARGET_CPU_IS_PPC_FAMILY)
+#elif defined(BOTAN_TARGET_ARCH_IS_PPC_FAMILY)
 
    /*
    DARN indicates error by returning 0xFF..FF, ie is biased. Which is crazy.
@@ -72,8 +74,8 @@ hwrng_output read_hwrng(bool& success) {
    */
    uint64_t output2 = 0;
    // DARN codes are 0: 32-bit conditioned, 1: 64-bit conditioned, 2: 64-bit raw (ala RDSEED)
-   asm volatile("darn %0, 1" : "=r"(output));
-   asm volatile("darn %0, 1" : "=r"(output2));
+   asm volatile("darn %0, 1" : "=r"(output));   // NOLINT(*-no-assembler)
+   asm volatile("darn %0, 1" : "=r"(output2));  // NOLINT(*-no-assembler)
 
    if((~output) != 0 && (~output2) != 0) {
       output ^= output2;
@@ -106,19 +108,19 @@ hwrng_output read_hwrng() {
 
 //static
 bool Processor_RNG::available() {
-#if defined(BOTAN_TARGET_CPU_IS_X86_FAMILY)
-   return CPUID::has_rdrand();
-#elif defined(BOTAN_TARGET_CPU_IS_PPC_FAMILY)
-   return CPUID::has_darn_rng();
+#if defined(BOTAN_TARGET_ARCH_IS_X86_FAMILY)
+   return CPUID::has(CPUID::Feature::RDRAND);
+#elif defined(BOTAN_TARGET_ARCH_IS_PPC_FAMILY)
+   return CPUID::has(CPUID::Feature::DARN);
 #else
    return false;
 #endif
 }
 
 std::string Processor_RNG::name() const {
-#if defined(BOTAN_TARGET_CPU_IS_X86_FAMILY)
+#if defined(BOTAN_TARGET_ARCH_IS_X86_FAMILY)
    return "rdrand";
-#elif defined(BOTAN_TARGET_CPU_IS_PPC_FAMILY)
+#elif defined(BOTAN_TARGET_ARCH_IS_PPC_FAMILY)
    return "darn";
 #else
    return "hwrng";
