@@ -11,7 +11,6 @@
 
 #include <botan/tls_messages.h>
 
-#include <botan/credentials_manager.h>
 #include <botan/hash.h>
 #include <botan/rng.h>
 #include <botan/tls_callbacks.h>
@@ -23,7 +22,6 @@
 #include <botan/internal/tls_handshake_hash.h>
 #include <botan/internal/tls_handshake_io.h>
 #include <botan/internal/tls_reader.h>
-#include <botan/internal/tls_session_key.h>
 
 #ifdef BOTAN_HAS_TLS_13
    #include <botan/internal/tls_handshake_layer_13.h>
@@ -65,7 +63,7 @@ class Client_Hello_Internal {
    public:
       Client_Hello_Internal() : m_comp_methods({0}) {}
 
-      Client_Hello_Internal(const std::vector<uint8_t>& buf) {
+      explicit Client_Hello_Internal(const std::vector<uint8_t>& buf) {
          if(buf.size() < 41) {
             throw Decoding_Error("Client_Hello: Packet corrupted");
          }
@@ -151,16 +149,16 @@ class Client_Hello_Internal {
       Extensions& extensions() { return m_extensions; }
 
    public:
-      Protocol_Version m_legacy_version;    // NOLINT(*-non-private-member-variables-in-classes)
-      Session_ID m_session_id;              // NOLINT(*-non-private-member-variables-in-classes)
-      std::vector<uint8_t> m_random;        // NOLINT(*-non-private-member-variables-in-classes)
-      std::vector<uint16_t> m_suites;       // NOLINT(*-non-private-member-variables-in-classes)
-      std::vector<uint8_t> m_comp_methods;  // NOLINT(*-non-private-member-variables-in-classes)
-      Extensions m_extensions;              // NOLINT(*-non-private-member-variables-in-classes)
+      Protocol_Version m_legacy_version;    // NOLINT(*-non-private-member-variable*)
+      Session_ID m_session_id;              // NOLINT(*-non-private-member-variable*)
+      std::vector<uint8_t> m_random;        // NOLINT(*-non-private-member-variable*)
+      std::vector<uint16_t> m_suites;       // NOLINT(*-non-private-member-variable*)
+      std::vector<uint8_t> m_comp_methods;  // NOLINT(*-non-private-member-variable*)
+      Extensions m_extensions;              // NOLINT(*-non-private-member-variable*)
 
       // These fields are only for DTLS:
-      std::vector<uint8_t> m_hello_cookie;       // NOLINT(*-non-private-member-variables-in-classes)
-      std::vector<uint8_t> m_cookie_input_bits;  // NOLINT(*-non-private-member-variables-in-classes)
+      std::vector<uint8_t> m_hello_cookie;       // NOLINT(*-non-private-member-variable*)
+      std::vector<uint8_t> m_cookie_input_bits;  // NOLINT(*-non-private-member-variable*)
 };
 
 Client_Hello::Client_Hello(Client_Hello&&) noexcept = default;
@@ -342,9 +340,9 @@ std::optional<Session_Handle> Client_Hello_12::session_handle() const {
    //    to use the Session ID in the ClientHello for stateful session
    //    resumption.
    if(auto ticket = session_ticket(); !ticket.empty()) {
-      return ticket;
+      return Session_Handle(ticket);
    } else if(const auto& id = session_id(); !id.empty()) {
-      return id;
+      return Session_Handle(id);
    } else {
       return std::nullopt;
    }
@@ -371,7 +369,7 @@ bool Client_Hello::sent_signature_algorithms() const {
 }
 
 std::vector<std::string> Client_Hello::next_protocols() const {
-   if(auto alpn = m_data->extensions().get<Application_Layer_Protocol_Notification>()) {
+   if(auto* alpn = m_data->extensions().get<Application_Layer_Protocol_Notification>()) {
       return alpn->protocols();
    }
    return {};
@@ -426,6 +424,7 @@ void Client_Hello_12::add_tls12_supported_groups_extensions(const Policy& policy
    auto supported_groups = std::make_unique<Supported_Groups>(std::move(compatible_kex_groups));
 
    if(!supported_groups->ec_groups().empty()) {
+      // NOLINTNEXTLINE(*-owning-memory)
       m_data->extensions().add(new Supported_Point_Formats(policy.use_ecc_point_compression()));
    }
 
@@ -442,14 +441,14 @@ Client_Hello_12::Client_Hello_12(std::unique_ptr<Client_Hello_Internal> data) :
          }
       } else {
          // add fake extension
-         m_data->extensions().add(new Renegotiation_Extension());
+         m_data->extensions().add(new Renegotiation_Extension());  // NOLINT(*-owning-memory)
       }
    }
 }
 
 namespace {
 
-// Avoid sending an IPv4/IPv6 address in SNI as this is prohibitied
+// Avoid sending an IPv4/IPv6 address in SNI as this is prohibited
 bool hostname_acceptable_for_sni(std::string_view hostname) {
    if(hostname.empty()) {
       return false;
@@ -499,7 +498,10 @@ Client_Hello_12::Client_Hello_12(Handshake_IO& io,
    * which reject hellos when the last extension in the list is empty.
    */
 
+   // NOLINTBEGIN(*-owning-memory)
+
    // EMS must always be used with TLS 1.2, regardless of the policy used.
+
    m_data->extensions().add(new Extended_Master_Secret);
 
    if(policy.negotiate_encrypt_then_mac()) {
@@ -539,6 +541,8 @@ Client_Hello_12::Client_Hello_12(Handshake_IO& io,
       m_data->extensions().add(new SRTP_Protection_Profiles(policy.srtp_profiles()));
    }
 
+   // NOLINTEND(*-owning-memory)
+
    cb.tls_modify_extensions(m_data->extensions(), Connection_Side::Client, type());
 
    hash.update(io.send(*this));
@@ -581,6 +585,7 @@ Client_Hello_12::Client_Hello_12(Handshake_IO& io,
    * RFC it should reject our resume attempt and upgrade us to a new session
    * with the EMS protection.
    */
+   // NOLINTBEGIN(*-owning-memory)
    m_data->extensions().add(new Extended_Master_Secret);
 
    if(session.session.supports_encrypt_then_mac()) {
@@ -617,6 +622,7 @@ Client_Hello_12::Client_Hello_12(Handshake_IO& io,
    if(reneg_info.empty() && !next_protocols.empty()) {
       m_data->extensions().add(new Application_Layer_Protocol_Notification(next_protocols));
    }
+   // NOLINTEND(*-owning-memory)
 
    cb.tls_modify_extensions(m_data->extensions(), Connection_Side::Client, type());
 
@@ -700,7 +706,7 @@ Client_Hello_13::Client_Hello_13(std::unique_ptr<Client_Hello_Internal> data) :
    }
 
    if(exts.has<Key_Share>()) {
-      const auto supported_ext = exts.get<Supported_Groups>();
+      auto* const supported_ext = exts.get<Supported_Groups>();
       BOTAN_ASSERT_NONNULL(supported_ext);
       const auto supports = supported_ext->groups();
       const auto offers = exts.get<Key_Share>()->offered_groups();
@@ -783,6 +789,7 @@ Client_Hello_13::Client_Hello_13(const Policy& policy,
       m_data->m_session_id = Session_ID(make_hello_random(rng, cb, policy));
    }
 
+   // NOLINTBEGIN(*-owning-memory)
    if(hostname_acceptable_for_sni(hostname)) {
       m_data->extensions().add(new Server_Name_Indicator(hostname));
    }
@@ -848,6 +855,7 @@ Client_Hello_13::Client_Hello_13(const Policy& policy,
    if(session.has_value() || !psks.empty()) {
       m_data->extensions().add(new PSK(session, std::move(psks), cb));
    }
+   // NOLINTEND(*-owning-memory)
 
    cb.tls_modify_extensions(m_data->extensions(), Connection_Side::Client, type());
 
@@ -881,7 +889,7 @@ void Client_Hello_13::retry(const Hello_Retry_Request& hrr,
    BOTAN_STATE_CHECK(m_data->extensions().has<Supported_Groups>());
    BOTAN_STATE_CHECK(m_data->extensions().has<Key_Share>());
 
-   auto hrr_ks = hrr.extensions().get<Key_Share>();
+   auto* hrr_ks = hrr.extensions().get<Key_Share>();
    const auto& supported_groups = m_data->extensions().get<Supported_Groups>()->groups();
 
    if(hrr.extensions().has<Key_Share>()) {
@@ -898,7 +906,7 @@ void Client_Hello_13::retry(const Hello_Retry_Request& hrr,
    //    connections.
    if(hrr.extensions().has<Cookie>()) {
       BOTAN_STATE_CHECK(!m_data->extensions().has<Cookie>());
-      m_data->extensions().add(new Cookie(hrr.extensions().get<Cookie>()->get_cookie()));
+      m_data->extensions().add(new Cookie(hrr.extensions().get<Cookie>()->get_cookie()));  // NOLINT(*-owning-memory)
    }
 
    // Note: the consumer of the TLS implementation won't be able to distinguish
@@ -907,8 +915,8 @@ void Client_Hello_13::retry(const Hello_Retry_Request& hrr,
    //       that the user keeps and detects this state themselves.
    cb.tls_modify_extensions(m_data->extensions(), Connection_Side::Client, type());
 
-   auto psk = m_data->extensions().get<PSK>();
-   if(psk) {
+   auto* psk = m_data->extensions().get<PSK>();
+   if(psk != nullptr) {
       // Cipher suite should always be a known suite as this is checked upstream
       const auto cipher = Ciphersuite::by_id(hrr.ciphersuite());
       BOTAN_ASSERT_NOMSG(cipher.has_value());
@@ -944,7 +952,7 @@ void Client_Hello_13::validate_updates(const Client_Hello_13& new_ch) {
    // Check that extension omissions are justified
    for(const auto oldext : oldexts) {
       if(!newexts.contains(oldext)) {
-         const auto ext = extensions().get(oldext);
+         auto* const ext = extensions().get(oldext);
 
          // We don't make any assumptions about unimplemented extensions.
          if(!ext->is_implemented()) {
@@ -973,7 +981,7 @@ void Client_Hello_13::validate_updates(const Client_Hello_13& new_ch) {
    // Check that extension additions are justified
    for(const auto newext : newexts) {
       if(!oldexts.contains(newext)) {
-         const auto ext = new_ch.extensions().get(newext);
+         auto* const ext = new_ch.extensions().get(newext);
 
          // We don't make any assumptions about unimplemented extensions.
          if(!ext->is_implemented()) {
@@ -1022,9 +1030,9 @@ void Client_Hello_13::validate_updates(const Client_Hello_13& new_ch) {
    //    "padding" extension.
 }
 
-void Client_Hello_13::calculate_psk_binders(Transcript_Hash_State ths) {
-   auto psk = m_data->extensions().get<PSK>();
-   if(!psk || psk->empty()) {
+void Client_Hello_13::calculate_psk_binders(Transcript_Hash_State transcript_hash) {
+   auto* psk = m_data->extensions().get<PSK>();
+   if(psk == nullptr || psk->empty()) {
       return;
    }
 
@@ -1037,8 +1045,8 @@ void Client_Hello_13::calculate_psk_binders(Transcript_Hash_State ths) {
    // (truncated) transcript hash, calculate the PSK binders with it, update
    // the Client Hello thus finalizing the message. Down the road, it will be
    // re-marshalled with the correct binders and sent over the wire.
-   Handshake_Layer::prepare_message(*this, ths);
-   psk->calculate_binders(ths);
+   Handshake_Layer::prepare_message(*this, transcript_hash);
+   psk->calculate_binders(transcript_hash);
 }
 
 std::optional<Protocol_Version> Client_Hello_13::highest_supported_version(const Policy& policy) const {
@@ -1047,7 +1055,7 @@ std::optional<Protocol_Version> Client_Hello_13::highest_supported_version(const
    //    which versions of TLS it supports and by the server to indicate which
    //    version it is using. The extension contains a list of supported
    //    versions in preference order, with the most preferred version first.
-   const auto supvers = m_data->extensions().get<Supported_Versions>();
+   auto* const supvers = m_data->extensions().get<Supported_Versions>();
    BOTAN_ASSERT_NONNULL(supvers);
 
    std::optional<Protocol_Version> result;
