@@ -9,13 +9,11 @@
 
 #include <botan/internal/tls_channel_impl_13.h>
 
-#include <botan/hash.h>
 #include <botan/tls_messages.h>
 #include <botan/internal/stl_util.h>
 #include <botan/internal/tls_cipher_state.h>
 #include <botan/internal/tls_handshake_state.h>
 #include <botan/internal/tls_record.h>
-#include <botan/internal/tls_seq_numbers.h>
 
 #include <array>
 
