@@ -122,10 +122,10 @@ std::unique_ptr<Cipher_State> Cipher_State::init_with_server_hello(const Connect
                                                                    secure_vector<uint8_t>&& shared_secret,
                                                                    const Ciphersuite& cipher,
                                                                    const Transcript_Hash& transcript_hash,
-                                                                   const Secret_Logger& loggger) {
+                                                                   const Secret_Logger& logger) {
    auto cs = std::unique_ptr<Cipher_State>(new Cipher_State(side, cipher.prf_algo()));
    cs->advance_without_psk();
-   cs->advance_with_server_hello(cipher, std::move(shared_secret), transcript_hash, loggger);
+   cs->advance_with_server_hello(cipher, std::move(shared_secret), transcript_hash, logger);
    return cs;
 }
 
@@ -138,7 +138,7 @@ std::unique_ptr<Cipher_State> Cipher_State::init_with_psk(const Connection_Side
    return cs;
 }
 
-void Cipher_State::advance_with_client_hello(const Transcript_Hash& transcript_hash, const Secret_Logger& loggger) {
+void Cipher_State::advance_with_client_hello(const Transcript_Hash& transcript_hash, const Secret_Logger& logger) {
    BOTAN_ASSERT_NOMSG(m_state == State::PskBinder);
 
    zap(m_binder_key);
@@ -155,7 +155,7 @@ void Cipher_State::advance_with_client_hello(const Transcript_Hash& transcript_h
    //    An implementation of TLS 1.3 use the label
    //    "EARLY_EXPORTER_MASTER_SECRET" to identify the secret that is using for
    //    early exporters
-   loggger.maybe_log_secret("EARLY_EXPORTER_MASTER_SECRET", m_exporter_master_secret);
+   logger.maybe_log_secret("EARLY_EXPORTER_MASTER_SECRET", m_exporter_master_secret);
 
    m_salt = derive_secret(m_early_secret, "derived", empty_hash());
    zap(m_early_secret);
@@ -163,7 +163,7 @@ void Cipher_State::advance_with_client_hello(const Transcript_Hash& transcript_h
    m_state = State::EarlyTraffic;
 }
 
-void Cipher_State::advance_with_server_finished(const Transcript_Hash& transcript_hash, const Secret_Logger& loggger) {
+void Cipher_State::advance_with_server_finished(const Transcript_Hash& transcript_hash, const Secret_Logger& logger) {
    BOTAN_ASSERT_NOMSG(m_state == State::HandshakeTraffic);
 
    const auto master_secret = hkdf_extract(secure_vector<uint8_t>(m_hash->output_length(), 0x00));
@@ -175,8 +175,8 @@ void Cipher_State::advance_with_server_finished(const Transcript_Hash& transcrip
    //    An implementation of TLS 1.3 use the label "CLIENT_TRAFFIC_SECRET_0"
    //    and "SERVER_TRAFFIC_SECRET_0" to identify the secrets are using to
    //    protect the connection.
-   loggger.maybe_log_secret("CLIENT_TRAFFIC_SECRET_0", client_application_traffic_secret);
-   loggger.maybe_log_secret("SERVER_TRAFFIC_SECRET_0", server_application_traffic_secret);
+   logger.maybe_log_secret("CLIENT_TRAFFIC_SECRET_0", client_application_traffic_secret);
+   logger.maybe_log_secret("SERVER_TRAFFIC_SECRET_0", server_application_traffic_secret);
 
    // Note: the secrets for processing client's application data
    //       are not derived before the client's Finished message
@@ -197,7 +197,7 @@ void Cipher_State::advance_with_server_finished(const Transcript_Hash& transcrip
    //    An implementation of TLS 1.3 use the label "EXPORTER_SECRET" to
    //    identify the secret that is used in generating exporters(rfc8446
    //    Section 7.5).
-   loggger.maybe_log_secret("EXPORTER_SECRET", m_exporter_master_secret);
+   logger.maybe_log_secret("EXPORTER_SECRET", m_exporter_master_secret);
 
    m_state = State::ServerApplicationTraffic;
 }
@@ -485,7 +485,7 @@ void Cipher_State::advance_with_psk(PSK_Type type, secure_vector<uint8_t>&& psk)
 void Cipher_State::advance_with_server_hello(const Ciphersuite& cipher,
                                              secure_vector<uint8_t>&& shared_secret,
                                              const Transcript_Hash& transcript_hash,
-                                             const Secret_Logger& loggger) {
+                                             const Secret_Logger& logger) {
    BOTAN_ASSERT_NOMSG(m_state == State::EarlyTraffic);
    BOTAN_ASSERT_NOMSG(!m_encrypt);
    BOTAN_ASSERT_NOMSG(!m_decrypt);
@@ -503,8 +503,8 @@ void Cipher_State::advance_with_server_hello(const Ciphersuite& cipher,
    //    An implementation of TLS 1.3 use the label
    //    "CLIENT_HANDSHAKE_TRAFFIC_SECRET" and "SERVER_HANDSHAKE_TRAFFIC_SECRET"
    //    to identify the secrets are using to protect handshake messages.
-   loggger.maybe_log_secret("CLIENT_HANDSHAKE_TRAFFIC_SECRET", client_handshake_traffic_secret);
-   loggger.maybe_log_secret("SERVER_HANDSHAKE_TRAFFIC_SECRET", server_handshake_traffic_secret);
+   logger.maybe_log_secret("CLIENT_HANDSHAKE_TRAFFIC_SECRET", client_handshake_traffic_secret);
+   logger.maybe_log_secret("SERVER_HANDSHAKE_TRAFFIC_SECRET", server_handshake_traffic_secret);
 
    if(m_connection_side == Connection_Side::Server) {
       derive_read_traffic_key(client_handshake_traffic_secret, true);
