@@ -9,15 +9,12 @@
 #include <botan/internal/tls_client_impl_13.h>
 
 #include <botan/credentials_manager.h>
-#include <botan/hash.h>
-#include <botan/tls_client.h>
 #include <botan/tls_messages.h>
 #include <botan/types.h>
 #include <botan/internal/stl_util.h>
 #include <botan/internal/tls_channel_impl_13.h>
 #include <botan/internal/tls_cipher_state.h>
 
-#include <iterator>
 #include <utility>
 
 namespace Botan::TLS {
@@ -179,7 +176,7 @@ void Client_Impl_13::handle(const Server_Hello_12& server_hello_msg) {
    //    MUST NOT send the "supported_versions" extension.
    //
    // Note that this condition should never happen, as the Server_Hello parsing
-   // code decides to create a Server_Hello_12 based on the absense of this extension.
+   // code decides to create a Server_Hello_12 based on the absence of this extension.
    if(server_hello_msg.extensions().has<Supported_Versions>()) {
       throw TLS_Exception(Alert::IllegalParameter, "Unexpected extension received");
    }
