@@ -12,12 +12,10 @@
 
 #include <botan/ec_group.h>
 #include <botan/pk_algs.h>
-
-#include <botan/internal/fmt.h>
 #include <botan/internal/hybrid_kem_ops.h>
 #include <botan/internal/kex_to_kem_adapter.h>
-#include <botan/internal/pk_ops_impl.h>
 #include <botan/internal/stl_util.h>
+#include <sstream>
 
 namespace Botan::TLS {
 
