@@ -51,9 +51,9 @@ std::optional<std::vector<Signature_Scheme>> Policy::acceptable_certificate_sign
 std::vector<std::string> Policy::allowed_ciphers() const {
    return {
       //"AES-256/OCB(12)",
-      "ChaCha20Poly1305",
       "AES-256/GCM",
       "AES-128/GCM",
+      "ChaCha20Poly1305",
       //"AES-256/CCM",
       //"AES-128/CCM",
       //"AES-256/CCM(8)",
@@ -182,10 +182,16 @@ std::vector<Group_Params> Policy::key_exchange_groups() const {
 
       Group_Params::SECP256R1,
 
-#if defined(BOTAN_HAS_X25519) && defined(BOTAN_HAS_ML_KEM) && defined(BOTAN_HAS_TLS_13_PQC)
+#if defined(BOTAN_HAS_ML_KEM) && defined(BOTAN_HAS_TLS_13_PQC)
+
+#if defined(BOTAN_HAS_X25519)
       Group_Params_Code::HYBRID_X25519_ML_KEM_768,
 #endif
 
+      Group_Params_Code::HYBRID_SECP256R1_ML_KEM_768,
+      Group_Params_Code::HYBRID_SECP384R1_ML_KEM_1024,
+#endif
+
 #if defined(BOTAN_HAS_X448)
       Group_Params::X448,
 #endif
@@ -224,7 +230,7 @@ std::vector<Group_Params> Policy::key_exchange_groups_to_offer() const {
 
    /*
    * If for some reason no pure ECC groups are enabled then simply
-   * send a share of whatever the policys top preference is.
+   * send a share of whatever the policy's top preference is.
    */
    if(groups_to_offer.empty()) {
       groups_to_offer.push_back(supported_groups.front());
@@ -711,7 +717,7 @@ std::string Policy::to_string() const {
 }
 
 std::vector<std::string> Strict_Policy::allowed_ciphers() const {
-   return {"ChaCha20Poly1305", "AES-256/GCM", "AES-128/GCM"};
+   return {"AES-256/GCM", "AES-128/GCM", "ChaCha20Poly1305"};
 }
 
 std::vector<std::string> Strict_Policy::allowed_signature_hashes() const {
