@@ -18,6 +18,7 @@
 #include <botan/secmem.h>
 #include <botan/internal/bit_ops.h>
 #include <botan/internal/stl_util.h>
+#include <botan/internal/target_info.h>
 
 #include <optional>
 #include <span>
@@ -92,16 +93,21 @@ inline bool poison_has_effect() {
 /// @name Constant Time Check Annotation Convenience overloads
 /// @{
 
+template <typename T>
+concept custom_poisonable = requires(const T& v) { v._const_time_poison(); };
+template <typename T>
+concept custom_unpoisonable = requires(const T& v) { v._const_time_unpoison(); };
+
 /**
  * Poison a single integral object
  */
 template <std::integral T>
-constexpr void poison(T& p) {
+constexpr void poison(const T& p) {
    poison(&p, 1);
 }
 
 template <std::integral T>
-constexpr void unpoison(T& p) {
+constexpr void unpoison(const T& p) {
    unpoison(&p, 1);
 }
 
@@ -109,15 +115,15 @@ constexpr void unpoison(T& p) {
  * Poison a contiguous buffer of trivial objects (e.g. integers and such)
  */
 template <ranges::spanable_range R>
-   requires std::is_trivially_copyable_v<std::ranges::range_value_t<R>>
-constexpr void poison(R&& r) {
+   requires std::is_trivially_copyable_v<std::ranges::range_value_t<R>> && (!custom_poisonable<R>)
+constexpr void poison(const R& r) {
    std::span s{r};
    poison(s.data(), s.size());
 }
 
 template <ranges::spanable_range R>
-   requires std::is_trivially_copyable_v<std::ranges::range_value_t<R>>
-constexpr void unpoison(R&& r) {
+   requires std::is_trivially_copyable_v<std::ranges::range_value_t<R>> && (!custom_unpoisonable<R>)
+constexpr void unpoison(const R& r) {
    std::span s{r};
    unpoison(s.data(), s.size());
 }
@@ -126,14 +132,12 @@ constexpr void unpoison(R&& r) {
  * Poison a class type that provides a public `_const_time_poison()` method
  * For instance: BigInt, CT::Mask<>, FrodoMatrix, ...
  */
-template <typename T>
-   requires requires(const T& x) { x._const_time_poison(); }
+template <custom_poisonable T>
 constexpr void poison(const T& x) {
    x._const_time_poison();
 }
 
-template <typename T>
-   requires requires(const T& x) { x._const_time_unpoison(); }
+template <custom_unpoisonable T>
 constexpr void unpoison(const T& x) {
    x._const_time_unpoison();
 }
@@ -172,7 +176,7 @@ concept unpoisonable = requires(const T& v) { ::Botan::CT::unpoison(v); };
  */
 template <std::ranges::range R>
    requires poisonable<std::ranges::range_value_t<R>>
-constexpr void poison_range(R&& r) {
+constexpr void poison_range(const R& r) {
    for(const auto& v : r) {
       poison(v);
    }
@@ -180,7 +184,7 @@ constexpr void poison_range(R&& r) {
 
 template <std::ranges::range R>
    requires unpoisonable<std::ranges::range_value_t<R>>
-constexpr void unpoison_range(R&& r) {
+constexpr void unpoison_range(const R& r) {
    for(const auto& v : r) {
       unpoison(v);
    }
@@ -192,13 +196,13 @@ constexpr void unpoison_range(R&& r) {
  */
 template <poisonable... Ts>
    requires(sizeof...(Ts) > 0)
-constexpr void poison_all(Ts&&... ts) {
+constexpr void poison_all(const Ts&... ts) {
    (poison(ts), ...);
 }
 
 template <unpoisonable... Ts>
    requires(sizeof...(Ts) > 0)
-constexpr void unpoison_all(Ts&&... ts) {
+constexpr void unpoison_all(const Ts&... ts) {
    (unpoison(ts), ...);
 }
 
@@ -268,10 +272,9 @@ template <unpoisonable T>
 *    constant time code and which does not support GCC-style inline asm.
 *
 */
-template <typename T>
-constexpr inline T value_barrier(T x)
-   requires std::unsigned_integral<T> && (!std::same_as<bool, T>)
-{
+template <std::unsigned_integral T>
+   requires(!std::same_as<bool, T>)
+constexpr inline T value_barrier(T x) {
    if(std::is_constant_evaluated()) {
       return x;
    } else {
@@ -283,7 +286,7 @@ constexpr inline T value_barrier(T x)
       * however the current approach seems sufficient with current compilers,
       * and is minimally damaging with regards to degrading code generation.
       */
-      asm("" : "+r"(x) : /* no input */);
+      asm("" : "+r"(x) : /* no input */);  // NOLINT(*-no-assembler)
       return x;
 #elif defined(BOTAN_CT_VALUE_BARRIER_USE_VOLATILE)
       volatile T vx = x;
@@ -322,6 +325,11 @@ class Choice final {
          return Choice(ct_is_zero<uint32_t>(static_cast<uint32_t>(v_is_0)));
       }
 
+      /**
+      * Create a Choice directly from a mask value - this assumes v is either |0| or |1|
+      */
+      constexpr static Choice from_mask(uint32_t v) { return Choice(v); }
+
       constexpr static Choice yes() { return Choice(static_cast<uint32_t>(-1)); }
 
       constexpr static Choice no() { return Choice(0); }
@@ -355,6 +363,7 @@ class Choice final {
       constexpr Choice(Choice&& other) = default;
       constexpr Choice& operator=(const Choice& other) noexcept = default;
       constexpr Choice& operator=(Choice&& other) noexcept = default;
+      constexpr ~Choice() = default;
 
    private:
       constexpr explicit Choice(uint32_t v) : m_value(v) {}
@@ -378,17 +387,20 @@ concept ct_conditional_assignable = requires(T lhs, const T& rhs, Choice c) { lh
 template <typename T>
 class Mask final {
    public:
-      static_assert(std::is_unsigned<T>::value && !std::is_same<bool, T>::value,
+      static_assert(std::is_unsigned_v<T> && !std::is_same_v<bool, T>,
                     "Only unsigned integer types are supported by CT::Mask");
 
       Mask(const Mask<T>& other) = default;
+      Mask(Mask<T>&& other) = default;
       Mask<T>& operator=(const Mask<T>& other) = default;
+      Mask<T>& operator=(Mask<T>&& other) = default;
+      ~Mask() = default;
 
       /**
       * Derive a Mask from a Mask of a larger type
       */
       template <typename U>
-      constexpr Mask(Mask<U> o) : m_mask(static_cast<T>(o.value())) {
+      constexpr explicit Mask(Mask<U> o) : m_mask(static_cast<T>(o.value())) {
          static_assert(sizeof(U) > sizeof(T), "sizes ok");
       }
 
@@ -407,6 +419,11 @@ class Mask final {
       */
       static constexpr Mask<T> expand(T v) { return ~Mask<T>::is_zero(value_barrier<T>(v)); }
 
+      /**
+      * Return a Mask<T> which is set if v is true
+      */
+      static constexpr Mask<T> expand_bool(bool v) { return Mask<T>::expand(static_cast<T>(v)); }
+
       /**
       * Return a Mask<T> which is set if choice is set
       */
@@ -627,7 +644,13 @@ class Mask final {
       /**
       * Return a Choice based on this mask
       */
-      constexpr CT::Choice as_choice() const { return CT::Choice::from_int(unpoisoned_value()); }
+      constexpr CT::Choice as_choice() const {
+         if constexpr(sizeof(T) >= sizeof(uint32_t)) {
+            return CT::Choice::from_mask(static_cast<uint32_t>(unpoisoned_value()));
+         } else {
+            return CT::Choice::from_int(unpoisoned_value());
+         }
+      }
 
       /**
       * Return the underlying value of the mask
@@ -639,7 +662,7 @@ class Mask final {
       constexpr void _const_time_unpoison() const { CT::unpoison(m_mask); }
 
    private:
-      constexpr Mask(T m) : m_mask(m) {}
+      constexpr explicit Mask(T m) : m_mask(m) {}
 
       T m_mask;
 };
@@ -658,7 +681,7 @@ class Option final {
       constexpr Option(T v, Choice valid) : m_has_value(valid), m_value(std::move(v)) {}
 
       /// Construct a set option with the provided value
-      constexpr Option(T v) : Option(std::move(v), Choice::yes()) {}
+      constexpr explicit Option(T v) : Option(std::move(v), Choice::yes()) {}
 
       /// Construct an unset option with a default inner value
       constexpr Option()
@@ -728,29 +751,44 @@ class Option final {
       T m_value;
 };
 
+/**
+* Conditional memory copy (constant time)
+*
+* If mask is set, then sets dest to if_set, otherwise sets dest to if_unset
+*/
 template <typename T>
-constexpr inline Mask<T> conditional_copy_mem(Mask<T> mask, T* to, const T* from0, const T* from1, size_t elems) {
-   mask.select_n(to, from0, from1, elems);
+constexpr inline Mask<T> conditional_copy_mem(Mask<T> mask, T* dest, const T* if_set, const T* if_unset, size_t elems) {
+   mask.select_n(dest, if_set, if_unset, elems);
    return mask;
 }
 
 template <typename T>
-constexpr inline Mask<T> conditional_copy_mem(T cnd, T* to, const T* from0, const T* from1, size_t elems) {
+constexpr inline Mask<T> conditional_copy_mem(T cnd, T* dest, const T* if_set, const T* if_unset, size_t elems) {
    const auto mask = CT::Mask<T>::expand(cnd);
-   return CT::conditional_copy_mem(mask, to, from0, from1, elems);
+   return CT::conditional_copy_mem(mask, dest, if_set, if_unset, elems);
 }
 
+/**
+* Conditional memory assignment (constant time)
+*
+* If mask is set overwrites dest with src
+*/
 template <typename T>
-constexpr inline Mask<T> conditional_assign_mem(T cnd, T* sink, const T* src, size_t elems) {
+constexpr inline Mask<T> conditional_assign_mem(T cnd, T* dest, const T* src, size_t elems) {
    const auto mask = CT::Mask<T>::expand(cnd);
-   mask.select_n(sink, src, sink, elems);
+   mask.select_n(dest, src, dest, elems);
    return mask;
 }
 
+/**
+* Conditional memory assignment (constant time)
+*
+* If mask is set overwrites dest with src
+*/
 template <typename T>
-constexpr inline Mask<T> conditional_assign_mem(Choice cnd, T* sink, const T* src, size_t elems) {
+constexpr inline Mask<T> conditional_assign_mem(Choice cnd, T* dest, const T* src, size_t elems) {
    const auto mask = CT::Mask<T>::from_choice(cnd);
-   mask.select_n(sink, src, sink, elems);
+   mask.select_n(dest, src, dest, elems);
    return mask;
 }
 
@@ -767,8 +805,8 @@ constexpr inline void conditional_swap_ptr(bool cnd, T& x, T& y) {
 
    conditional_swap<uintptr_t>(cnd, xp, yp);
 
-   x = reinterpret_cast<T>(xp);
-   y = reinterpret_cast<T>(yp);
+   x = reinterpret_cast<T>(xp);  // NOLINT(*-no-int-to-ptr)
+   y = reinterpret_cast<T>(yp);  // NOLINT(*-no-int-to-ptr)
 }
 
 template <typename T>
@@ -805,6 +843,21 @@ constexpr inline CT::Mask<T> is_equal(const T x[], const T y[], size_t len) {
    }
 }
 
+/**
+* Compare two spans and return a Mask which is set iff they were identical.
+*
+* If the spans are of different length then the function returns early without
+* looking at either span
+*/
+template <typename T>
+constexpr inline CT::Mask<T> is_equal(std::span<const T> x, std::span<const T> y) {
+   if(x.size() != y.size()) {
+      return CT::Mask<T>::cleared();
+   }
+
+   return is_equal(x.data(), y.data(), x.size());
+}
+
 /**
 * Compare two arrays of equal size and return a Mask indicating if
 * they are equal or not. The mask is set if they differ.
