@@ -1,111 +1,107 @@
 /*
-* A minimal 128-bit integer type for curve25519-donna
+* A minimal 128-bit integer type
 * (C) 2014 Jack Lloyd
 *
 * Botan is released under the Simplified BSD License (see license.txt)
 */
 
-#ifndef BOTAN_CURVE25519_DONNA128_H_
-#define BOTAN_CURVE25519_DONNA128_H_
+#ifndef BOTAN_DONNA128_H_
+#define BOTAN_DONNA128_H_
 
 #include <botan/internal/ct_utils.h>
 #include <botan/internal/mul128.h>
-#include <type_traits>
+#include <concepts>
 
 namespace Botan {
 
 class donna128 final {
    public:
-      constexpr donna128(uint64_t ll = 0, uint64_t hh = 0) {
-         l = ll;
-         h = hh;
-      }
+      constexpr explicit donna128(uint64_t l = 0, uint64_t h = 0) : m_lo(l), m_hi(h) {}
 
-      donna128(const donna128&) = default;
-      donna128& operator=(const donna128&) = default;
-
-      template <typename T>
+      template <std::unsigned_integral T>
       constexpr friend donna128 operator>>(const donna128& x, T shift) {
          donna128 z = x;
 
          if(shift > 64) {
-            z.l = z.h >> (shift - 64);
-            z.h = 0;
+            z.m_lo = z.m_hi >> (shift - 64);
+            z.m_hi = 0;
          } else if(shift == 64) {
-            z.l = z.h;
-            z.h = 0;
+            z.m_lo = z.m_hi;
+            z.m_hi = 0;
          } else if(shift > 0) {
-            const uint64_t carry = z.h << static_cast<size_t>(64 - shift);
-            z.h >>= shift;
-            z.l >>= shift;
-            z.l |= carry;
+            const uint64_t carry = z.m_hi << static_cast<size_t>(64 - shift);
+            z.m_hi >>= shift;
+            z.m_lo >>= shift;
+            z.m_lo |= carry;
          }
 
          return z;
       }
 
-      template <typename T>
+      template <std::unsigned_integral T>
       constexpr friend donna128 operator<<(const donna128& x, T shift) {
          donna128 z = x;
          if(shift > 64) {
-            z.h = z.l << (shift - 64);
-            z.l = 0;
+            z.m_hi = z.m_lo << (shift - 64);
+            z.m_lo = 0;
          } else if(shift == 64) {
-            z.h = z.l;
-            z.l = 0;
+            z.m_hi = z.m_lo;
+            z.m_lo = 0;
          } else if(shift > 0) {
-            const uint64_t carry = z.l >> static_cast<size_t>(64 - shift);
-            z.l = (z.l << shift);
-            z.h = (z.h << shift) | carry;
+            const uint64_t carry = z.m_lo >> static_cast<size_t>(64 - shift);
+            z.m_lo = (z.m_lo << shift);
+            z.m_hi = (z.m_hi << shift) | carry;
          }
 
          return z;
       }
 
-      constexpr friend uint64_t operator&(const donna128& x, uint64_t mask) { return x.l & mask; }
+      constexpr friend uint64_t operator&(const donna128& x, uint64_t mask) { return x.m_lo & mask; }
 
       constexpr uint64_t operator&=(uint64_t mask) {
-         h = 0;
-         l &= mask;
-         return l;
+         m_hi = 0;
+         m_lo &= mask;
+         return m_lo;
       }
 
       constexpr donna128& operator+=(const donna128& x) {
-         l += x.l;
-         h += x.h;
+         m_lo += x.m_lo;
+         m_hi += x.m_hi;
 
-         const uint64_t carry = CT::Mask<uint64_t>::is_lt(l, x.l).if_set_return(1);
-         h += carry;
+         const uint64_t carry = CT::Mask<uint64_t>::is_lt(m_lo, x.m_lo).if_set_return(1);
+         m_hi += carry;
          return *this;
       }
 
       constexpr donna128& operator+=(uint64_t x) {
-         l += x;
-         const uint64_t carry = CT::Mask<uint64_t>::is_lt(l, x).if_set_return(1);
-         h += carry;
+         m_lo += x;
+         const uint64_t carry = CT::Mask<uint64_t>::is_lt(m_lo, x).if_set_return(1);
+         m_hi += carry;
          return *this;
       }
 
-      constexpr uint64_t lo() const { return l; }
+      constexpr uint64_t lo() const { return m_lo; }
 
-      constexpr uint64_t hi() const { return h; }
+      constexpr uint64_t hi() const { return m_hi; }
 
-      constexpr operator uint64_t() const { return l; }
+      constexpr explicit operator uint64_t() const { return lo(); }
 
    private:
-      uint64_t h = 0, l = 0;
+      uint64_t m_lo = 0;
+      uint64_t m_hi = 0;
 };
 
-template <std::unsigned_integral T>
+template <std::integral T>
 constexpr inline donna128 operator*(const donna128& x, T y) {
    BOTAN_ARG_CHECK(x.hi() == 0, "High 64 bits of donna128 set to zero during multiply");
 
-   uint64_t lo = 0, hi = 0;
+   uint64_t lo = 0;
+   uint64_t hi = 0;
    mul64x64_128(x.lo(), static_cast<uint64_t>(y), &lo, &hi);
    return donna128(lo, hi);
 }
 
-template <std::unsigned_integral T>
+template <std::integral T>
 constexpr inline donna128 operator*(T y, const donna128& x) {
    return x * y;
 }
