@@ -15,6 +15,7 @@
 #include <botan/strong_type.h>
 #include <botan/types.h>
 #include <botan/internal/bswap.h>
+#include <bit>
 
 /**
  * @file loadstor.h
@@ -55,6 +56,9 @@
 
 namespace Botan {
 
+static_assert(std::endian::native == std::endian::big || std::endian::native == std::endian::little,
+              "Mixed endian systems are not supported");
+
 /**
 * Byte extraction
 * @param byte_num which byte to extract, 0 == highest byte
@@ -123,48 +127,20 @@ inline constexpr uint64_t make_uint64(
 
 namespace detail {
 
-enum class Endianness : bool {
-   Big,
-   Little,
-};
-
 /**
- * @warning This function may return false if the native endianness is unknown
- * @returns true iff the native endianness matches the given endianness
+ * @returns the opposite endianness of the specified endianness
+ *
+ * Note this assumes that there are only two endian orderings; we
+ * do not supported mixed endian systems
  */
-constexpr bool is_native(Endianness endianness) {
-#if defined(BOTAN_TARGET_CPU_IS_BIG_ENDIAN)
-   return endianness == Endianness::Big;
-#elif defined(BOTAN_TARGET_CPU_IS_LITTLE_ENDIAN)
-   return endianness == Endianness::Little;
-#else
-   BOTAN_UNUSED(endianness);
-   return false;
-#endif
-}
-
-/**
- * @warning This function may return false if the native endianness is unknown
- * @returns true iff the native endianness does not match the given endianness
- */
-constexpr bool is_opposite(Endianness endianness) {
-#if defined(BOTAN_TARGET_CPU_IS_BIG_ENDIAN)
-   return endianness == Endianness::Little;
-#elif defined(BOTAN_TARGET_CPU_IS_LITTLE_ENDIAN)
-   return endianness == Endianness::Big;
-#else
-   BOTAN_UNUSED(endianness);
-   return false;
-#endif
-}
-
-template <Endianness endianness>
-constexpr bool native_endianness_is_unknown() {
-#if defined(BOTAN_TARGET_CPU_IS_BIG_ENDIAN) || defined(BOTAN_TARGET_CPU_IS_LITTLE_ENDIAN)
-   return false;
-#else
-   return true;
-#endif
+consteval std::endian opposite(std::endian endianness) {
+   if(endianness == std::endian::big) {
+      return std::endian::little;
+   } else {
+      // We already verified via static assert earlier in this file that we are
+      // running on either a big endian or little endian system
+      return std::endian::big;
+   }
 }
 
 /**
@@ -231,19 +207,19 @@ constexpr auto wrap_strong_type_or_enum(T t) {
 
 /**
  * Manually load a word from a range in either big or little endian byte order.
- * This will be used only if the endianness of the target platform is unknown at
- * compile time.
+ *
+ * This is only used at compile time.
  */
-template <Endianness endianness, std::unsigned_integral OutT, ranges::contiguous_range<uint8_t> InR>
-inline constexpr OutT fallback_load_any(InR&& in_range) {
+template <std::endian endianness, std::unsigned_integral OutT, ranges::contiguous_range<uint8_t> InR>
+inline constexpr OutT fallback_load_any(const InR& in_range) {
    std::span in{in_range};
    // clang-format off
-   if constexpr(endianness == Endianness::Big) {
+   if constexpr(endianness == std::endian::big) {
       return [&]<size_t... i>(std::index_sequence<i...>) {
          return static_cast<OutT>(((static_cast<OutT>(in[i]) << ((sizeof(OutT) - i - 1) * 8)) | ...));
       } (std::make_index_sequence<sizeof(OutT)>());
    } else {
-      static_assert(endianness == Endianness::Little);
+      static_assert(endianness == std::endian::little);
       return [&]<size_t... i>(std::index_sequence<i...>) {
          return static_cast<OutT>(((static_cast<OutT>(in[i]) << (i * 8)) | ...));
       } (std::make_index_sequence<sizeof(OutT)>());
@@ -253,19 +229,19 @@ inline constexpr OutT fallback_load_any(InR&& in_range) {
 
 /**
  * Manually store a word into a range in either big or little endian byte order.
- * This will be used only if the endianness of the target platform is unknown at
- * compile time.
+ *
+ * This will be used only at compile time.
  */
-template <Endianness endianness, std::unsigned_integral InT, ranges::contiguous_output_range<uint8_t> OutR>
-inline constexpr void fallback_store_any(InT in, OutR&& out_range) {
+template <std::endian endianness, std::unsigned_integral InT, ranges::contiguous_output_range<uint8_t> OutR>
+inline constexpr void fallback_store_any(InT in, OutR&& out_range /* NOLINT(*-std-forward) */) {
    std::span out{out_range};
    // clang-format off
-   if constexpr(endianness == Endianness::Big) {
+   if constexpr(endianness == std::endian::big) {
       [&]<size_t... i>(std::index_sequence<i...>) {
          ((out[i] = get_byte<i>(in)), ...);
       } (std::make_index_sequence<sizeof(InT)>());
    } else {
-      static_assert(endianness == Endianness::Little);
+      static_assert(endianness == std::endian::little);
       [&]<size_t... i>(std::index_sequence<i...>) {
          ((out[i] = get_byte<sizeof(InT) - i - 1>(in)), ...);
       } (std::make_index_sequence<sizeof(InT)>());
@@ -281,7 +257,7 @@ inline constexpr void fallback_store_any(InT in, OutR&& out_range) {
  *
  * Template arguments of all overloads of load_any() share the same semantics:
  *
- *   1.  Endianness      Either `Endianness::Big` or `Endianness::Little`, that
+ *   1.  std::endian     Either `std::endian::big` or `std::endian::little`, that
  *                       will eventually select the byte order translation mode
  *                       implemented in this base function.
  *
@@ -297,7 +273,7 @@ inline constexpr void fallback_store_any(InT in, OutR&& out_range) {
  * @param in_range a fixed-length byte range
  * @return T loaded from @p in_range, as a big-endian value
  */
-template <Endianness endianness, unsigned_integralish WrappedOutT, ranges::contiguous_range<uint8_t> InR>
+template <std::endian endianness, unsigned_integralish WrappedOutT, ranges::contiguous_range<uint8_t> InR>
    requires(!custom_loadable<strong_type_wrapped_type<WrappedOutT>>)
 inline constexpr WrappedOutT load_any(InR&& in_range) {
    using OutT = detail::wrapped_type<WrappedOutT>;
@@ -313,13 +289,11 @@ inline constexpr WrappedOutT load_any(InR&& in_range) {
          std::span in{in_range};
          if constexpr(sizeof(OutT) == 1) {
             return static_cast<OutT>(in[0]);
-         } else if constexpr(is_native(endianness)) {
+         } else if constexpr(endianness == std::endian::native) {
             return typecast_copy<OutT>(in);
-         } else if constexpr(is_opposite(endianness)) {
-            return reverse_bytes(typecast_copy<OutT>(in));
          } else {
-            static_assert(native_endianness_is_unknown<endianness>());
-            return fallback_load_any<endianness, OutT>(std::forward<InR>(in_range));
+            static_assert(opposite(endianness) == std::endian::native);
+            return reverse_bytes(typecast_copy<OutT>(in));
          }
       }
    }());
@@ -334,13 +308,13 @@ inline constexpr WrappedOutT load_any(InR&& in_range) {
  * @param in_range a fixed-length byte range
  * @return T loaded from @p in_range, as a big-endian value
  */
-template <Endianness endianness, unsigned_integralish WrappedOutT, ranges::contiguous_range<uint8_t> InR>
+template <std::endian endianness, unsigned_integralish WrappedOutT, ranges::contiguous_range<uint8_t> InR>
    requires(custom_loadable<strong_type_wrapped_type<WrappedOutT>>)
-inline constexpr WrappedOutT load_any(InR&& in_range) {
+inline constexpr WrappedOutT load_any(const InR& in_range) {
    using OutT = detail::wrapped_type<WrappedOutT>;
    ranges::assert_exact_byte_length<sizeof(OutT)>(in_range);
    std::span<const uint8_t, sizeof(OutT)> ins{in_range};
-   if constexpr(endianness == Endianness::Big) {
+   if constexpr(endianness == std::endian::big) {
       return wrap_strong_type<WrappedOutT>(OutT::load_be(ins));
    } else {
       return wrap_strong_type<WrappedOutT>(OutT::load_le(ins));
@@ -352,10 +326,10 @@ inline constexpr WrappedOutT load_any(InR&& in_range) {
  * @param in   a fixed-length span to some bytes
  * @param outs a arbitrary-length parameter list of unsigned integers to be loaded
  */
-template <Endianness endianness, typename OutT, ranges::contiguous_range<uint8_t> InR, unsigned_integralish... Ts>
+template <std::endian endianness, typename OutT, ranges::contiguous_range<uint8_t> InR, unsigned_integralish... Ts>
    requires(sizeof...(Ts) > 0) && ((std::same_as<AutoDetect, OutT> && all_same_v<Ts...>) ||
                                    (unsigned_integralish<OutT> && all_same_v<OutT, Ts...>))
-inline constexpr void load_any(InR&& in, Ts&... outs) {
+inline constexpr void load_any(const InR& in, Ts&... outs) {
    ranges::assert_exact_byte_length<(sizeof(Ts) + ...)>(in);
    auto load_one = [off = 0]<typename T>(auto i, T& o) mutable {
       o = load_any<endianness, T>(i.subspan(off).template first<sizeof(T)>());
@@ -372,13 +346,13 @@ inline constexpr void load_any(InR&& in, Ts&... outs) {
  * @param out the output range of words
  * @param in the input range of bytes
  */
-template <Endianness endianness,
+template <std::endian endianness,
           typename OutT,
           ranges::contiguous_output_range OutR,
           ranges::contiguous_range<uint8_t> InR>
    requires(unsigned_integralish<std::ranges::range_value_t<OutR>> &&
             (std::same_as<AutoDetect, OutT> || std::same_as<OutT, std::ranges::range_value_t<OutR>>))
-inline constexpr void load_any(OutR&& out, InR&& in) {
+inline constexpr void load_any(OutR&& out /* NOLINT(*-std-forward) */, const InR& in) {
    ranges::assert_equal_byte_lengths(out, in);
    using element_type = std::ranges::range_value_t<OutR>;
 
@@ -397,7 +371,7 @@ inline constexpr void load_any(OutR&& out, InR&& in) {
    if(std::is_constant_evaluated()) /* TODO: C++23: if consteval {} */ {
       load_elementwise();
    } else {
-      if constexpr(is_native(endianness) && !custom_loadable<element_type>) {
+      if constexpr(endianness == std::endian::native && !custom_loadable<element_type>) {
          typecast_copy(out, in);
       } else {
          load_elementwise();
@@ -416,7 +390,7 @@ inline constexpr void load_any(OutR&& out, InR&& in) {
  * @param in_range a statically-sized range with some bytes
  * @return T loaded from in
  */
-template <Endianness endianness, typename OutT, ranges::contiguous_range<uint8_t> InR>
+template <std::endian endianness, typename OutT, ranges::contiguous_range<uint8_t> InR>
    requires(std::same_as<AutoDetect, OutT> ||
             ((ranges::statically_spanable_range<OutT> || concepts::resizable_container<OutT>) &&
              unsigned_integralish<typename OutT::value_type>))
@@ -476,7 +450,7 @@ inline constexpr auto load_any(InR&& in_range) {
  * @param off an offset into the array
  * @return off'th T of in, as a big-endian value
  */
-template <Endianness endianness, unsigned_integralish OutT>
+template <std::endian endianness, unsigned_integralish OutT>
 inline constexpr OutT load_any(const uint8_t in[], size_t off) {
    // asserts that *in points to enough bytes to read at offset off
    constexpr size_t out_size = sizeof(OutT);
@@ -488,7 +462,7 @@ inline constexpr OutT load_any(const uint8_t in[], size_t off) {
  * @param in   a pointer to some bytes
  * @param outs a arbitrary-length parameter list of unsigned integers to be loaded
  */
-template <Endianness endianness, typename OutT, unsigned_integralish... Ts>
+template <std::endian endianness, typename OutT, unsigned_integralish... Ts>
    requires(sizeof...(Ts) > 0 && all_same_v<Ts...> &&
             ((std::same_as<AutoDetect, OutT> && all_same_v<Ts...>) ||
              (unsigned_integralish<OutT> && all_same_v<OutT, Ts...>)))
@@ -504,7 +478,7 @@ inline constexpr void load_any(const uint8_t in[], Ts&... outs) {
  * @param in the input array of bytes
  * @param count how many words are in in
  */
-template <Endianness endianness, typename OutT, unsigned_integralish T>
+template <std::endian endianness, typename OutT, unsigned_integralish T>
    requires(std::same_as<AutoDetect, OutT> || std::same_as<T, OutT>)
 inline constexpr void load_any(T out[], const uint8_t in[], size_t count) {
    // asserts that *in and *out point to the correct amount of memory
@@ -519,7 +493,7 @@ inline constexpr void load_any(T out[], const uint8_t in[], size_t count) {
  */
 template <typename OutT = detail::AutoDetect, typename... ParamTs>
 inline constexpr auto load_le(ParamTs&&... params) {
-   return detail::load_any<detail::Endianness::Little, OutT>(std::forward<ParamTs>(params)...);
+   return detail::load_any<std::endian::little, OutT>(std::forward<ParamTs>(params)...);
 }
 
 /**
@@ -528,7 +502,7 @@ inline constexpr auto load_le(ParamTs&&... params) {
  */
 template <typename OutT = detail::AutoDetect, typename... ParamTs>
 inline constexpr auto load_be(ParamTs&&... params) {
-   return detail::load_any<detail::Endianness::Big, OutT>(std::forward<ParamTs>(params)...);
+   return detail::load_any<std::endian::big, OutT>(std::forward<ParamTs>(params)...);
 }
 
 namespace detail {
@@ -546,7 +520,7 @@ namespace detail {
  * @param wrapped_in an unsigned integral to be stored
  * @param out_range  a byte range to store the word into
  */
-template <Endianness endianness, unsigned_integralish WrappedInT, ranges::contiguous_output_range<uint8_t> OutR>
+template <std::endian endianness, unsigned_integralish WrappedInT, ranges::contiguous_output_range<uint8_t> OutR>
    requires(!custom_storable<strong_type_wrapped_type<WrappedInT>>)
 inline constexpr void store_any(WrappedInT wrapped_in, OutR&& out_range) {
    const auto in = detail::unwrap_strong_type_or_enum(wrapped_in);
@@ -562,13 +536,11 @@ inline constexpr void store_any(WrappedInT wrapped_in, OutR&& out_range) {
    } else {
       if constexpr(sizeof(InT) == 1) {
          out[0] = static_cast<uint8_t>(in);
-      } else if constexpr(is_native(endianness)) {
+      } else if constexpr(endianness == std::endian::native) {
          typecast_copy(out, in);
-      } else if constexpr(is_opposite(endianness)) {
-         typecast_copy(out, reverse_bytes(in));
       } else {
-         static_assert(native_endianness_is_unknown<endianness>());
-         return fallback_store_any<endianness, InT>(in, std::forward<OutR>(out_range));
+         static_assert(opposite(endianness) == std::endian::native);
+         typecast_copy(out, reverse_bytes(in));
       }
    }
 }
@@ -582,14 +554,14 @@ inline constexpr void store_any(WrappedInT wrapped_in, OutR&& out_range) {
  * @param wrapped_in a custom object to be stored
  * @param out_range  a byte range to store the word into
  */
-template <Endianness endianness, unsigned_integralish WrappedInT, ranges::contiguous_output_range<uint8_t> OutR>
+template <std::endian endianness, unsigned_integralish WrappedInT, ranges::contiguous_output_range<uint8_t> OutR>
    requires(custom_storable<strong_type_wrapped_type<WrappedInT>>)
-inline constexpr void store_any(WrappedInT wrapped_in, OutR&& out_range) {
+inline constexpr void store_any(WrappedInT wrapped_in, const OutR& out_range) {
    const auto in = detail::unwrap_strong_type_or_enum(wrapped_in);
    using InT = decltype(in);
    ranges::assert_exact_byte_length<sizeof(in)>(out_range);
    std::span<uint8_t, sizeof(InT)> outs{out_range};
-   if constexpr(endianness == Endianness::Big) {
+   if constexpr(endianness == std::endian::big) {
       in.store_be(outs);
    } else {
       in.store_le(outs);
@@ -601,13 +573,13 @@ inline constexpr void store_any(WrappedInT wrapped_in, OutR&& out_range) {
  * @param out a sized range of some bytes
  * @param ins a arbitrary-length parameter list of unsigned integers to be stored
  */
-template <Endianness endianness,
+template <std::endian endianness,
           typename InT,
           ranges::contiguous_output_range<uint8_t> OutR,
           unsigned_integralish... Ts>
    requires(sizeof...(Ts) > 0) && ((std::same_as<AutoDetect, InT> && all_same_v<Ts...>) ||
                                    (unsigned_integralish<InT> && all_same_v<InT, Ts...>))
-inline constexpr void store_any(OutR&& out, Ts... ins) {
+inline constexpr void store_any(OutR&& out /* NOLINT(*-std-forward) */, Ts... ins) {
    ranges::assert_exact_byte_length<(sizeof(Ts) + ...)>(out);
    auto store_one = [off = 0]<typename T>(auto o, T i) mutable {
       store_any<endianness, T>(i, o.subspan(off).template first<sizeof(T)>());
@@ -623,12 +595,12 @@ inline constexpr void store_any(OutR&& out, Ts... ins) {
  * @param out the output range of bytes
  * @param in the input range of words
  */
-template <Endianness endianness,
+template <std::endian endianness,
           typename InT,
           ranges::contiguous_output_range<uint8_t> OutR,
           ranges::spanable_range InR>
    requires(std::same_as<AutoDetect, InT> || std::same_as<InT, std::ranges::range_value_t<InR>>)
-inline constexpr void store_any(OutR&& out, InR&& in) {
+inline constexpr void store_any(OutR&& out /* NOLINT(*-std-forward) */, const InR& in) {
    ranges::assert_equal_byte_lengths(out, in);
    using element_type = std::ranges::range_value_t<InR>;
 
@@ -647,7 +619,7 @@ inline constexpr void store_any(OutR&& out, InR&& in) {
    if(std::is_constant_evaluated()) /* TODO: C++23: if consteval {} */ {
       store_elementwise();
    } else {
-      if constexpr(is_native(endianness) && !custom_storable<element_type>) {
+      if constexpr(endianness == std::endian::native && !custom_storable<element_type>) {
          typecast_copy(out, in);
       } else {
          store_elementwise();
@@ -669,7 +641,7 @@ inline constexpr void store_any(OutR&& out, InR&& in) {
  * @param in an unsigned integer to be stored
  * @param out_range a range of bytes to store the word into
  */
-template <Endianness endianness, typename InT, unsigned_integralish T, ranges::contiguous_output_range<uint8_t> OutR>
+template <std::endian endianness, typename InT, unsigned_integralish T, ranges::contiguous_output_range<uint8_t> OutR>
    requires std::same_as<AutoDetect, InT>
 inline constexpr void store_any(T in, OutR&& out_range) {
    store_any<endianness, T>(in, std::forward<OutR>(out_range));
@@ -684,7 +656,7 @@ inline constexpr void store_any(T in, OutR&& out_range) {
  * @param in_range a range of words that should be stored
  * @return a container of bytes that contains the stored words
  */
-template <Endianness endianness, typename OutR, ranges::spanable_range InR>
+template <std::endian endianness, typename OutR, ranges::spanable_range InR>
    requires(std::same_as<AutoDetect, OutR> ||
             (ranges::statically_spanable_range<OutR> && std::default_initializable<OutR>) ||
             concepts::resizable_byte_buffer<OutR>)
@@ -719,7 +691,7 @@ inline constexpr auto store_any(InR&& in_range) {
  * @param ins some words that should be stored
  * @return a container of bytes that contains the stored words
  */
-template <Endianness endianness, typename OutR, unsigned_integralish... Ts>
+template <std::endian endianness, typename OutR, unsigned_integralish... Ts>
    requires all_same_v<Ts...>
 inline constexpr auto store_any(Ts... ins) {
    return store_any<endianness, OutR>(std::array{ins...});
@@ -734,7 +706,7 @@ inline constexpr auto store_any(Ts... ins) {
  * @param in the input unsigned integer
  * @param out the byte array to write to
  */
-template <Endianness endianness, typename InT, unsigned_integralish T>
+template <std::endian endianness, typename InT, unsigned_integralish T>
    requires(std::same_as<AutoDetect, InT> || std::same_as<T, InT>)
 inline constexpr void store_any(T in, uint8_t out[]) {
    // asserts that *out points to enough bytes to write into
@@ -746,7 +718,7 @@ inline constexpr void store_any(T in, uint8_t out[]) {
  * @param ins a arbitrary-length parameter list of unsigned integers to be stored
  * @param out the byte array to write to
  */
-template <Endianness endianness, typename InT, unsigned_integralish T0, unsigned_integralish... Ts>
+template <std::endian endianness, typename InT, unsigned_integralish T0, unsigned_integralish... Ts>
    requires(std::same_as<AutoDetect, InT> || std::same_as<T0, InT>) && all_same_v<T0, Ts...>
 inline constexpr void store_any(uint8_t out[], T0 in0, Ts... ins) {
    constexpr auto bytes = sizeof(in0) + (sizeof(ins) + ... + 0);
@@ -762,7 +734,7 @@ inline constexpr void store_any(uint8_t out[], T0 in0, Ts... ins) {
  */
 template <typename ModifierT = detail::AutoDetect, typename... ParamTs>
 inline constexpr auto store_le(ParamTs&&... params) {
-   return detail::store_any<detail::Endianness::Little, ModifierT>(std::forward<ParamTs>(params)...);
+   return detail::store_any<std::endian::little, ModifierT>(std::forward<ParamTs>(params)...);
 }
 
 /**
@@ -771,12 +743,12 @@ inline constexpr auto store_le(ParamTs&&... params) {
  */
 template <typename ModifierT = detail::AutoDetect, typename... ParamTs>
 inline constexpr auto store_be(ParamTs&&... params) {
-   return detail::store_any<detail::Endianness::Big, ModifierT>(std::forward<ParamTs>(params)...);
+   return detail::store_any<std::endian::big, ModifierT>(std::forward<ParamTs>(params)...);
 }
 
 namespace detail {
 
-template <Endianness endianness, unsigned_integralish T>
+template <std::endian endianness, unsigned_integralish T>
 inline size_t copy_out_any_word_aligned_portion(std::span<uint8_t>& out, std::span<const T>& in) {
    const size_t full_words = out.size() / sizeof(T);
    const size_t full_word_bytes = full_words * sizeof(T);
@@ -798,10 +770,10 @@ inline size_t copy_out_any_word_aligned_portion(std::span<uint8_t>& out, std::sp
  * byte order.
  */
 template <ranges::spanable_range InR>
-inline void copy_out_be(std::span<uint8_t> out, InR&& in) {
+inline void copy_out_be(std::span<uint8_t> out, const InR& in) {
    using T = std::ranges::range_value_t<InR>;
    std::span<const T> in_s{in};
-   const auto remaining_bytes = detail::copy_out_any_word_aligned_portion<detail::Endianness::Big>(out, in_s);
+   const auto remaining_bytes = detail::copy_out_any_word_aligned_portion<std::endian::big>(out, in_s);
 
    // copy remaining bytes as a partial word
    for(size_t i = 0; i < remaining_bytes; ++i) {
@@ -814,10 +786,10 @@ inline void copy_out_be(std::span<uint8_t> out, InR&& in) {
  * byte order.
  */
 template <ranges::spanable_range InR>
-inline void copy_out_le(std::span<uint8_t> out, InR&& in) {
+inline void copy_out_le(std::span<uint8_t> out, const InR& in) {
    using T = std::ranges::range_value_t<InR>;
    std::span<const T> in_s{in};
-   const auto remaining_bytes = detail::copy_out_any_word_aligned_portion<detail::Endianness::Little>(out, in_s);
+   const auto remaining_bytes = detail::copy_out_any_word_aligned_portion<std::endian::little>(out, in_s);
 
    // copy remaining bytes as a partial word
    for(size_t i = 0; i < remaining_bytes; ++i) {
