@@ -6,8 +6,13 @@
 
 #include <botan/mem_ops.h>
 
+#include <botan/internal/target_info.h>
 #include <cstring>
 
+#if defined(BOTAN_TARGET_OS_HAS_EXPLICIT_BZERO)
+   #include <string.h>
+#endif
+
 #if defined(BOTAN_TARGET_OS_HAS_RTLSECUREZEROMEMORY)
    #define NOMINMAX 1
    #define _WINSOCKAPI_  // stop windows.h including winsock.h
@@ -26,22 +31,25 @@ void secure_scrub_memory(void* ptr, size_t n) {
 #elif defined(BOTAN_TARGET_OS_HAS_EXPLICIT_MEMSET)
    (void)::explicit_memset(ptr, 0, n);
 
-#elif defined(BOTAN_USE_VOLATILE_MEMSET_FOR_ZERO) && (BOTAN_USE_VOLATILE_MEMSET_FOR_ZERO == 1)
+#else
    /*
-   Call memset through a static volatile pointer, which the compiler
-   should not elide. This construct should be safe in conforming
-   compilers, but who knows. I did confirm that on x86-64 GCC 6.1 and
-   Clang 3.8 both create code that saves the memset address in the
-   data segment and unconditionally loads and jumps to that address.
+   * Call memset through a static volatile pointer, which the compiler should
+   * not elide. This construct should be safe in conforming compilers, but who
+   * knows. This has been checked to generate the expected code, which saves the
+   * memset address in the data segment and unconditionally loads and jumps to
+   * that address, with the following targets:
+   *
+   * x86-64: Clang 19, GCC 6, 11, 13, 14
+   * riscv64: GCC 14
+   * aarch64: GCC 14
+   * armv7: GCC 14
+   *
+   * Actually all of them generated the expected jump even without marking the
+   * function pointer as volatile. However this seems worth including as an
+   * additional precaution.
    */
    static void* (*const volatile memset_ptr)(void*, int, size_t) = std::memset;
    (memset_ptr)(ptr, 0, n);
-#else
-
-   volatile uint8_t* p = reinterpret_cast<volatile uint8_t*>(ptr);
-
-   for(size_t i = 0; i != n; ++i)
-      p[i] = 0;
 #endif
 }
 
