@@ -176,6 +176,8 @@ uint64_t OS::get_cpu_cycle_counter() {
 
 #elif defined(BOTAN_USE_GCC_INLINE_ASM)
 
+   // NOLINTBEGIN(*-no-assembler)
+
    #if defined(BOTAN_TARGET_ARCH_IS_X86_64)
 
    uint32_t rtc_low = 0;
@@ -211,8 +213,8 @@ uint64_t OS::get_cpu_cycle_counter() {
    #elif defined(BOTAN_TARGET_ARCH_IS_ALPHA)
    asm volatile("rpcc %0" : "=r"(rtc));
 
-      // OpenBSD does not trap access to the %tick register
    #elif defined(BOTAN_TARGET_ARCH_IS_SPARC64) && !defined(BOTAN_TARGET_OS_IS_OPENBSD)
+   // OpenBSD does not trap access to the %tick register so we avoid it there
    asm volatile("rd %%tick, %0" : "=r"(rtc));
 
    #elif defined(BOTAN_TARGET_ARCH_IS_IA64)
@@ -228,6 +230,8 @@ uint64_t OS::get_cpu_cycle_counter() {
       //#warning "OS::get_cpu_cycle_counter not implemented"
    #endif
 
+   // NOLINTEND(*-no-assembler)
+
 #endif
 
    return rtc;
@@ -449,7 +453,8 @@ bool OS::read_env_variable(std::string& value_out, std::string_view name_view) {
       return false;
    }
 
-#if defined(BOTAN_TARGET_OS_HAS_WIN32) && defined(BOTAN_BUILD_COMPILER_IS_MSVC)
+#if defined(BOTAN_TARGET_OS_HAS_WIN32) && \
+   (defined(BOTAN_BUILD_COMPILER_IS_MSVC) || defined(BOTAN_BUILD_COMPILER_IS_CLANGCL))
    const std::string name(name_view);
    char val[128] = {0};
    size_t req_size = 0;
@@ -592,7 +597,7 @@ std::vector<void*> OS::allocate_locked_pages(size_t count) {
 
       // Attempts to name the data page
       page_named(ptr, 3 * page_size);
-      // Make guard page preceeding the data page
+      // Make guard page preceding the data page
       page_prohibit_access(static_cast<uint8_t*>(ptr));
       // Make guard page following the data page
       page_prohibit_access(static_cast<uint8_t*>(ptr) + 2 * page_size);
