@@ -8,6 +8,7 @@
 #define BOTAN_PREFETCH_UTILS_H_
 
 #include <botan/types.h>
+#include <concepts>
 #include <type_traits>
 
 namespace Botan {
@@ -30,10 +31,8 @@ uint64_t prefetch_array_raw(size_t bytes, const void* array) noexcept;
 * to not elide otherwise "useless" reads. The return value will always
 * be zero.
 */
-template <typename T, size_t... Ns>
-T prefetch_arrays(T (&... arr)[Ns]) noexcept
-   requires std::is_integral<T>::value
-{
+template <std::unsigned_integral T, size_t... Ns>
+T prefetch_arrays(T (&... arr)[Ns]) noexcept {
    return (static_cast<T>(prefetch_array_raw(sizeof(T) * Ns, arr)) & ...);
 }
 
