@@ -274,10 +274,10 @@ class SIMD_4x32 final {
 #if BOTAN_COMPILER_HAS_BUILTIN(__builtin_crypto_vshasigmaw) && defined(_ARCH_PWR8)
          return SIMD_4x32(__builtin_crypto_vshasigmaw(raw(), 1, 0));
 #else
-         const SIMD_4x32 rot1 = this->rotr<2>();
-         const SIMD_4x32 rot2 = this->rotr<13>();
-         const SIMD_4x32 rot3 = this->rotr<22>();
-         return (rot1 ^ rot2 ^ rot3);
+         const SIMD_4x32 r1 = this->rotr<2>();
+         const SIMD_4x32 r2 = this->rotr<13>();
+         const SIMD_4x32 r3 = this->rotr<22>();
+         return (r1 ^ r2 ^ r3);
 #endif
       }
 
@@ -288,10 +288,10 @@ class SIMD_4x32 final {
 #if BOTAN_COMPILER_HAS_BUILTIN(__builtin_crypto_vshasigmaw) && defined(_ARCH_PWR8)
          return SIMD_4x32(__builtin_crypto_vshasigmaw(raw(), 1, 0xF));
 #else
-         const SIMD_4x32 rot1 = this->rotr<6>();
-         const SIMD_4x32 rot2 = this->rotr<11>();
-         const SIMD_4x32 rot3 = this->rotr<25>();
-         return (rot1 ^ rot2 ^ rot3);
+         const SIMD_4x32 r1 = this->rotr<6>();
+         const SIMD_4x32 r2 = this->rotr<11>();
+         const SIMD_4x32 r3 = this->rotr<25>();
+         return (r1 ^ r2 ^ r3);
 #endif
       }
 
