@@ -8,6 +8,7 @@
 
 #include <botan/certstor.h>
 
+#include <botan/assert.h>
 #include <botan/data_src.h>
 #include <botan/hash.h>
 #include <botan/pkix_types.h>
@@ -99,7 +100,7 @@ std::optional<X509_Certificate> Certificate_Store_In_Memory::find_cert_by_pubkey
       throw Invalid_Argument("Certificate_Store_In_Memory::find_cert_by_pubkey_sha1 invalid hash");
    }
 
-   auto hash = HashFunction::create("SHA-1");
+   auto hash = HashFunction::create_or_throw("SHA-1");
 
    for(const auto& cert : m_certs) {
       hash->update(cert.subject_public_key_bitstring());
@@ -117,7 +118,7 @@ std::optional<X509_Certificate> Certificate_Store_In_Memory::find_cert_by_raw_su
       throw Invalid_Argument("Certificate_Store_In_Memory::find_cert_by_raw_subject_dn_sha256 invalid hash");
    }
 
-   auto hash = HashFunction::create("SHA-256");
+   auto hash = HashFunction::create_or_throw("SHA-256");
 
    for(const auto& cert : m_certs) {
       hash->update(cert.raw_subject_dn());
@@ -129,6 +130,17 @@ std::optional<X509_Certificate> Certificate_Store_In_Memory::find_cert_by_raw_su
    return std::nullopt;
 }
 
+std::optional<X509_Certificate> Certificate_Store_In_Memory::find_cert_by_issuer_dn_and_serial_number(
+   const X509_DN& issuer_dn, std::span<const uint8_t> serial_number) const {
+   for(const auto& cert : m_certs) {
+      if(cert.issuer_dn() == issuer_dn && std::ranges::equal(cert.serial_number(), serial_number)) {
+         return cert;
+      }
+   }
+
+   return std::nullopt;
+}
+
 void Certificate_Store_In_Memory::add_crl(const X509_CRL& crl) {
    const X509_DN& crl_issuer = crl.issuer_dn();
 
@@ -171,6 +183,11 @@ Certificate_Store_In_Memory::Certificate_Store_In_Memory(const X509_Certificate&
    add_certificate(cert);
 }
 
+Certificate_Store_In_Memory::Certificate_Store_In_Memory(const X509_Certificate& cert, const X509_CRL& crl) {
+   add_certificate(cert);
+   add_crl(crl);
+}
+
 #if defined(BOTAN_TARGET_OS_HAS_FILESYSTEM)
 Certificate_Store_In_Memory::Certificate_Store_In_Memory(std::string_view dir) {
    if(dir.empty()) {
