@@ -9,9 +9,11 @@
 
 #include <botan/certstor_windows.h>
 
+#include <botan/assert.h>
 #include <botan/ber_dec.h>
 #include <botan/hash.h>
 #include <botan/pkix_types.h>
+#include <algorithm>
 #include <array>
 #include <functional>
 #include <vector>
@@ -217,6 +219,26 @@ std::optional<X509_Certificate> Certificate_Store_Windows::find_cert_by_raw_subj
    throw Not_Implemented("Certificate_Store_Windows::find_cert_by_raw_subject_dn_sha256");
 }
 
+std::optional<X509_Certificate> Certificate_Store_Windows::find_cert_by_issuer_dn_and_serial_number(
+   const X509_DN& issuer_dn, std::span<const uint8_t> serial_number) const {
+   std::vector<uint8_t> dn_data = issuer_dn.BER_encode();
+
+   _CRYPTOAPI_BLOB blob;
+   blob.cbData = static_cast<DWORD>(dn_data.size());
+   blob.pbData = reinterpret_cast<BYTE*>(dn_data.data());
+
+   auto filter = [&](const std::vector<X509_Certificate>& certs, const X509_Certificate& cert) {
+      return !already_contains_certificate(certs, cert) && std::ranges::equal(cert.serial_number(), serial_number);
+   };
+
+   const auto certs = search_cert_stores(blob, CERT_FIND_ISSUER_NAME, filter, true);
+   if(certs.empty()) {
+      return std::nullopt;
+   }
+
+   return certs.front();
+}
+
 std::optional<X509_CRL> Certificate_Store_Windows::find_crl_for(const X509_Certificate& subject) const {
    // TODO: this could be implemented by using the CertFindCRLInStore function
    BOTAN_UNUSED(subject);
