@@ -9,16 +9,15 @@
 
 #include <botan/internal/cshake_xof.h>
 
-#include <botan/exceptn.h>
-#include <botan/mem_ops.h>
 #include <botan/internal/keccak_helpers.h>
-#include <botan/internal/loadstor.h>
 #include <botan/internal/mem_utils.h>
 
 namespace Botan {
 
 cSHAKE_XOF::cSHAKE_XOF(size_t capacity, std::vector<uint8_t> function_name) :
-      m_keccak(capacity, 0b00, 2), m_function_name(std::move(function_name)), m_output_generated(false) {
+      m_keccak({.capacity_bits = capacity, .padding = KeccakPadding::cshake()}),
+      m_function_name(std::move(function_name)),
+      m_output_generated(false) {
    BOTAN_ASSERT_NOMSG(capacity == 256 || capacity == 512);
 }
 
