@@ -72,6 +72,8 @@ def known_targets():
         'sde',
         'shared',
         'static',
+        'strubbing',
+        'typos',
         'valgrind',
         'valgrind-full',
         'valgrind-ct',
@@ -109,9 +111,9 @@ class LoggingGroup:
             print("> Running '%s' took %d seconds" % (self.group_title, time_taken))
 
 def build_targets(target, target_os):
-    if target in ['shared', 'minimized', 'examples'] or target.startswith('policy-'):
+    if target in ['shared', 'minimized', 'examples', 'limbo'] or target.startswith('policy-'):
         yield 'shared'
-    elif target in ['static', 'fuzzers', 'cross-arm32-baremetal', 'emscripten']:
+    elif target in ['static', 'fuzzers', 'cross-arm32-baremetal', 'emscripten', 'strubbing']:
         yield 'static'
     elif target_os in ['windows']:
         yield 'shared'
@@ -121,10 +123,10 @@ def build_targets(target, target_os):
         yield 'shared'
         yield 'static'
 
-    if target not in ['examples']:
+    if target not in ['examples', 'limbo']:
         yield 'cli'
 
-    if target not in ['examples', 'limbo']:
+    if target not in ['examples', 'limbo', 'hybrid-tls13-interop-test', 'strubbing']:
         yield 'tests'
 
     if target in ['coverage']:
@@ -136,6 +138,16 @@ def build_targets(target, target_os):
     if target in ['valgrind', 'valgrind-full', 'valgrind-ct', 'valgrind-ct-full']:
         yield 'ct_selftest'
 
+def make_targets(target, target_os):
+    # The result of build_targets() is for ./configure.py --build-targets='...'.
+    # make_targets() go into `make/ninja ...` and they are mostly equal. Except
+    # for 'libs' which is an umbrella target for 'static' and 'shared'.
+    tgts = [tgt if tgt not in ['static', 'shared'] else 'libs' for tgt in build_targets(target, target_os)]
+    if target in ['coverage', 'fuzzers']:
+        # These are special targets not found in ./configure.py --build-targets=
+        tgts += ['fuzzers', 'fuzzer_corpus_zip']
+    return list(set(tgts))
+
 def determine_flags(target, target_os, target_cpu, target_cc, cc_bin, ccache,
                     root_dir, build_dir, test_results_dir, pkcs11_lib, use_gdb,
                     disable_werror, extra_cxxflags, custom_optimization_flags, disabled_tests):
@@ -220,7 +232,7 @@ def determine_flags(target, target_os, target_cpu, target_cc, cc_bin, ccache,
         flags += ['--extra-cxxflags=/D_DISABLE_CONSTEXPR_MUTEX_CONSTRUCTOR']
 
     if target in ['minimized']:
-        flags += ['--minimized-build', '--enable-modules=system_rng,sha2_32,sha2_64,aes']
+        flags += ['--minimized-build', '--enable-modules=system_rng,sha2*,aes']
 
     if target in ['no_pcurves']:
         flags += ['--disable-modules=pcurves_impl']
@@ -257,8 +269,14 @@ def determine_flags(target, target_os, target_cpu, target_cc, cc_bin, ccache,
     if target in ['coverage', 'valgrind', 'valgrind-full', 'valgrind-ct', 'valgrind-ct-full']:
         flags += ['--with-debug-info']
 
+    if target in ['strubbing']:
+        # Stack scrubbing tests are based on scripted gdb runs and won't work on
+        # an optimized build unfortunately.
+        flags += ['--debug-mode']
+        test_cmd = None
+
     if target in ['coverage', 'sanitizer', 'fuzzers']:
-        flags += ['--unsafe-terminate-on-asserts']
+        flags += ['--unsafe-terminate-on-asserts', '--enable-modules=tls_null']
 
     if target in ['sde']:
         test_prefix = ['sde', '-future', '--']
@@ -294,6 +312,13 @@ def determine_flags(target, target_os, target_cpu, target_cc, cc_bin, ccache,
         # need to find a way to run the wasm-compiled tests w/o a browser
         test_cmd = None
 
+    if target in ['sanitizer', 'strubbing'] and target_cc in ['gcc']:
+        # Stack scrubbing is supported on GCC 14 and newer, only. This is newer
+        # than the current default compiler on GHA's Linux image (ubuntu 24.04).
+        # The CI setup has to ensure that we are configured to use a recent
+        # compiler for these targets, otherwise `./configure.py` will fail.
+        flags += ['--enable-stack-scrubbing']
+
     if is_cross_target:
         if target_os == 'ios':
             make_prefix = ['xcrun', '--sdk', 'iphoneos']
@@ -676,12 +701,17 @@ def main(args=None):
     if options.cc_bin is None:
         if options.cc == 'gcc':
             options.cc_bin = 'g++'
+        elif options.cc == 'gcc-14':
+            options.cc = 'gcc' # Hack: 'gcc-14' is not a valid compiler identifier for ``./configure.py --cc``
+            options.cc_bin = 'g++-14'
         elif options.cc == 'clang':
             options.cc_bin = 'clang++'
         elif options.cc == 'xcode':
             options.cc_bin = 'clang++'
         elif options.cc == 'msvc':
             options.cc_bin = 'cl'
+        elif options.cc == 'clangcl':
+            options.cc_bin = 'clang-cl'
         elif options.cc == "emcc":
             options.cc_bin = "em++"
         else:
@@ -719,6 +749,7 @@ def main(args=None):
 
         pylint_rc = '--rcfile=%s' % (os.path.join(root_dir, 'src/configs/pylint.rc'))
         pylint_flags = [pylint_rc, '--reports=no']
+        pylint_flags += ['--ignored-modules=gdb'] # 'import gdb' is not available outside gdb...
 
         if is_running_in_github_actions():
             pylint_flags += ["--msg-template='::warning file={path},line={line},endLine={end_line}::Pylint ({category}): {msg_id} {msg} ({symbol})'"]
@@ -738,6 +769,7 @@ def main(args=None):
             'src/scripts/website.py',
             'src/scripts/bench.py',
             'src/scripts/test_python.py',
+            'src/scripts/test_strubbed_symbols.py',
             'src/scripts/test_fuzzers.py',
             'src/scripts/test_cli.py',
             'src/scripts/repo_config.py',
@@ -745,16 +777,25 @@ def main(args=None):
             'src/scripts/python_unittests_unix.py',
             'src/scripts/dev_tools/run_clang_format.py',
             'src/scripts/dev_tools/run_clang_tidy.py',
+            'src/scripts/gdb/strubtest.py',
             'src/editors/vscode/scripts/bogo.py',
             'src/editors/vscode/scripts/common.py',
             'src/editors/vscode/scripts/test.py',
             'src/ct_selftest/ct_selftest.py']
 
-        # This has to run in the repository root to generate the correct
+        # These commands have to run in the repository root to generate the correct
         # relative paths in the output. Otherwise GitHub Actions will not
         # be able to annotate the correct files.
         cmds.append(["indir:%s" % root_dir, py_interp, '-m', 'pylint'] + pylint_flags + py_scripts)
 
+        ruff_flags = []
+        if is_running_in_github_actions():
+            ruff_flags += ["--output-format=github"]
+
+        cmds.append(["indir:%s" % (root_dir), "ruff", "check"] + ruff_flags + ["."])
+
+    elif target == 'typos':
+        cmds.append(['indir:%s' % (root_dir), 'typos', '-c', 'src/configs/typos.toml', '.'])
     elif target == 'format':
         cmds.append([py_interp,
                      os.path.join(root_dir, 'src/scripts/dev_tools/run_clang_format.py'),
@@ -789,21 +830,7 @@ def main(args=None):
             if options.compiler_cache is not None:
                 cmds.append([options.compiler_cache, '--show-stats'])
 
-            make_targets = ['libs', 'tests', 'cli']
-
-            if target in ['coverage', 'fuzzers']:
-                make_targets += ['fuzzer_corpus_zip', 'fuzzers']
-
-            if target in ['examples', 'amalgamation']:
-                make_targets += ['examples']
-
-            if target in ['valgrind', 'valgrind-full', 'valgrind-ct', 'valgrind-ct-full']:
-                make_targets += ['ct_selftest']
-
-            if target in ['coverage', 'sanitizer'] and options.os not in ['windows']:
-                make_targets += ['bogo_shim']
-
-            cmds.append(make_prefix + make_cmd + make_targets)
+            cmds.append(make_prefix + make_cmd + make_targets(target, options.os))
 
             if target in ['examples'] and options.cc in ['clang', 'gcc']:
                 cmds.append([options.cc, '-Wall', '-Wextra', '-std=c89',
@@ -855,6 +882,11 @@ def main(args=None):
                 slow_tests += [f"ml_dsa_kat_{mode}_{rand}" for mode in ('6x5', '8x7') for rand in ('Deterministic', 'Randomized')]
 
                 valgrind_script_options.append('--skip-tests=%s' % (','.join(slow_tests)))
+            elif target == 'valgrind-ct-full' and options.cc == 'clang' and '-Os' in options.custom_optimization_flags:
+                # Clang 18 (only) with -Os seems to have a problem with std::optional which flags certain
+                # uses as touching an uninitialized stack variable. This affects the x509_rpki tests
+                # TODO(26.04) We can remove this once we have a new version of Clang to use
+                valgrind_script_options.append('--skip-tests=x509_rpki')
 
             cmds.append(['indir:%s' % (root_dir),
                          'src/scripts/run_tests_under_valgrind.py'] +
@@ -895,6 +927,10 @@ def main(args=None):
                 cmds.append([py_interp, os.path.join(root_dir, 'src/scripts', script)] +
                             args + test_data_arg + [botan_exe])
 
+        if target in ['strubbing']:
+            cmds.append([py_interp, os.path.join(root_dir, 'src/scripts/test_strubbed_symbols.py'),
+                         '--botan-cli', os.path.join(build_dir, 'botan')])
+
         if target in ['hybrid-tls13-interop-test']:
             cmds.append([py_interp, os.path.join(root_dir, 'src/scripts/test_cli.py'),
                          '--run-online-tests', os.path.join(build_dir, 'botan'), 'pqc_hybrid_tests'])
