@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # coding=utf8
 
 """
@@ -6,6 +6,7 @@ Botan CI check installation script
 This script is used to validate the results of `make install`
 
 (C) 2020 Jack Lloyd, René Meusel, Hannes Rantzsch
+(C) 2023 René Meusel
 
 Botan is released under the Simplified BSD License (see license.txt)
 """
@@ -14,6 +15,7 @@ import os
 import sys
 import json
 import re
+import subprocess
 
 def verify_library(build_config):
     lib_dir = build_config['libdir']
@@ -25,8 +27,8 @@ def verify_library(build_config):
 
     major_version = int(build_config["version_major"])
 
-    if build_config['compiler'] == 'msvc':
-        expected_lib_format = r'^botan\.(dll|lib)$'
+    if build_config['compiler'] in ['msvc', 'clangcl']:
+        expected_lib_format = r'^botan-%d\.(dll|lib)$' % (major_version)
     elif build_config['os'] == 'macos':
         expected_lib_format = r'^libbotan-%d\.(a|dylib)$' % (major_version)
     else:
@@ -75,6 +77,40 @@ def verify_includes(build_config):
 
     return True
 
+def verify_cmake_package(build_config):
+    if build_config['os'] not in ['windows', 'linux', 'macos']:
+        return True # skip (e.g. for mingw)
+
+    cmake_build_dir = os.path.join(build_config['abs_root_dir'], build_config['build_dir'], 'cmake_test')
+    cmake_test_dir = os.path.join(build_config['abs_root_dir'], "src", "scripts", "ci", "cmake_tests")
+
+    def cmake_preset():
+        if build_config['os'] == 'windows':
+            return 'windows_x86_64' if build_config['arch'] == 'x86_64' else 'windows_x86'
+        return 'unix'
+
+    def test_target():
+        return 'test' if build_config['os'] != 'windows' else 'RUN_TESTS'
+
+    disabled_module = build_config['disabled_mod_list'][0] if build_config['disabled_mod_list'] else None
+    if not disabled_module:
+        print("Not a single disabled module in this build to use for testing.") # just for good measure
+        return False
+
+    try:
+        subprocess.run(["cmake", "--preset", cmake_preset(),
+                                 "-B", cmake_build_dir,
+                                 "-S", cmake_test_dir,
+                                 "-DCMAKE_PREFIX_PATH=%s" % build_config['prefix'],
+                                 "-DBOTAN_DISABLED_MODULE=%s" % disabled_module], check=True)
+        subprocess.run(["cmake", "--build", cmake_build_dir, "--config", "Release"], check=True)
+        subprocess.run(["cmake", "--build", cmake_build_dir, "--config", "Release", "--target", test_target()], check=True)
+    except RuntimeError as e:
+        print("Using the CMake package failed: %s" % str(e))
+        return False
+
+    return True
+
 def main(args=None):
     if args is None:
         args = sys.argv
@@ -83,7 +119,7 @@ def main(args=None):
         print("Usage: %s <build_config.json>" % args[0])
         return 1
 
-    with open(os.path.join(args[1])) as f:
+    with open(os.path.join(args[1]), encoding='utf8') as f:
         build_config = json.load(f)
 
     install_prefix = build_config['prefix']
@@ -98,6 +134,10 @@ def main(args=None):
     if not verify_library(build_config):
         return 1
 
+    has_cmake = 'botan_cmake_config' in build_config and 'botan_cmake_version_config' in build_config
+    if has_cmake and not verify_cmake_package(build_config):
+        return 1
+
     return 0
 
 if __name__ == '__main__':
