@@ -9,7 +9,6 @@
 
 #if defined(BOTAN_HAS_AEAD_MODES)
    #include <botan/aead.h>
-   #include <botan/mem_ops.h>
 #endif
 
 namespace Botan_Tests {
@@ -40,17 +39,23 @@ class AEAD_Tests final : public Text_Based_Test {
          result.confirm("AEAD name is not empty", !enc->name().empty());
          result.confirm("AEAD default nonce size is accepted", enc->valid_nonce_length(enc->default_nonce_length()));
 
-         Botan::secure_vector<uint8_t> garbage = rng.random_vec(enc->update_granularity());
+         auto get_garbage = [&] { return rng.random_vec(enc->update_granularity()); };
 
-         if(is_siv == false) {
-            result.test_throws("Unkeyed object throws for encrypt", [&]() { enc->update(garbage); });
+         if(!is_siv) {
+            result.test_throws<Botan::Invalid_State>("Unkeyed object throws for encrypt", [&]() {
+               auto garbage = get_garbage();
+               enc->update(garbage);
+            });
          }
 
-         result.test_throws("Unkeyed object throws for encrypt", [&]() { enc->finish(garbage); });
+         result.test_throws<Botan::Invalid_State>("Unkeyed object throws for encrypt", [&]() {
+            auto garbage = get_garbage();
+            enc->finish(garbage);
+         });
 
          if(enc->associated_data_requires_key()) {
-            result.test_throws("Unkeyed object throws for set AD",
-                               [&]() { enc->set_associated_data(ad.data(), ad.size()); });
+            result.test_throws<Botan::Invalid_State>("Unkeyed object throws for set AD",
+                                                     [&]() { enc->set_associated_data(ad.data(), ad.size()); });
          }
 
          result.test_eq("key is not set", enc->has_keying_material(), false);
@@ -60,17 +65,25 @@ class AEAD_Tests final : public Text_Based_Test {
          enc->set_key(key);
          result.test_eq("key is set", enc->has_keying_material(), true);
 
-         if(is_siv == false) {
-            result.test_throws("Cannot process data until nonce is set (enc)", [&]() { enc->update(garbage); });
-            result.test_throws("Cannot process data until nonce is set (enc)", [&]() { enc->finish(garbage); });
+         if(!is_siv) {
+            result.test_throws<Botan::Invalid_State>("Cannot process data until nonce is set (enc)", [&]() {
+               auto garbage = get_garbage();
+               enc->update(garbage);
+            });
+            result.test_throws<Botan::Invalid_State>("Cannot process data until nonce is set (enc)", [&]() {
+               auto garbage = get_garbage();
+               enc->finish(garbage);
+            });
          }
 
          enc->set_associated_data(mutate_vec(ad, rng));
          enc->start(mutate_vec(nonce, rng));
+
+         auto garbage = get_garbage();
          enc->update(garbage);
 
          // reset message specific state
-         enc->reset();
+         enc->reset();  // NOLINT(*-ambiguous-smartptr-reset-call)
 
          /*
          Now try to set the AD *after* setting the nonce
@@ -82,7 +95,7 @@ class AEAD_Tests final : public Text_Based_Test {
             enc->set_associated_data(ad);
          } catch(Botan::Invalid_State&) {
             // ad after setting nonce rejected, in this case we need to reset
-            enc->reset();
+            enc->reset();  // NOLINT(*-ambiguous-smartptr-reset-call)
             enc->set_associated_data(ad);
             enc->start(nonce);
          }
@@ -102,7 +115,7 @@ class AEAD_Tests final : public Text_Based_Test {
             const size_t update_granularity = enc->update_granularity();
             if(input.size() > update_granularity) {
                // reset state first
-               enc->reset();
+               enc->reset();  // NOLINT(*-ambiguous-smartptr-reset-call)
 
                enc->set_associated_data(ad);
                enc->start(nonce);
@@ -135,7 +148,7 @@ class AEAD_Tests final : public Text_Based_Test {
             size_t min_final_bytes = enc->minimum_final_size();
             if(input.size() > (update_granularity + min_final_bytes)) {
                // again reset state first
-               enc->reset();
+               enc->reset();  // NOLINT(*-ambiguous-smartptr-reset-call)
 
                enc->set_associated_data(ad);
                enc->start(nonce);
@@ -170,11 +183,12 @@ class AEAD_Tests final : public Text_Based_Test {
          enc->clear();
          result.test_eq("key is not set", enc->has_keying_material(), false);
 
-         result.test_throws("Unkeyed object throws for encrypt after clear", [&]() { enc->finish(buf); });
+         result.test_throws<Botan::Invalid_State>("Unkeyed object throws for encrypt after clear",
+                                                  [&]() { enc->finish(buf); });
 
          if(enc->associated_data_requires_key()) {
-            result.test_throws("Unkeyed object throws for set AD after clear",
-                               [&]() { enc->set_associated_data(ad.data(), ad.size()); });
+            result.test_throws<Botan::Invalid_State>("Unkeyed object throws for set AD after clear",
+                                                     [&]() { enc->set_associated_data(ad.data(), ad.size()); });
          }
 
          return result;
@@ -195,17 +209,24 @@ class AEAD_Tests final : public Text_Based_Test {
 
          result.test_eq("AEAD decrypt output_length is correct", dec->output_length(input.size()), expected.size());
 
-         Botan::secure_vector<uint8_t> garbage = rng.random_vec(dec->update_granularity());
+         auto get_garbage = [&] { return rng.random_vec(dec->update_granularity()); };
+         auto get_ultimate_garbage = [&] { return rng.random_vec(dec->minimum_final_size()); };
 
-         if(is_siv == false) {
-            result.test_throws("Unkeyed object throws for decrypt", [&]() { dec->update(garbage); });
+         if(!is_siv) {
+            result.test_throws<Botan::Invalid_State>("Unkeyed object throws for decrypt", [&]() {
+               auto garbage = get_garbage();
+               dec->update(garbage);
+            });
          }
 
-         result.test_throws("Unkeyed object throws for decrypt", [&]() { dec->finish(garbage); });
+         result.test_throws<Botan::Invalid_State>("Unkeyed object throws for decrypt", [&]() {
+            auto garbage = get_ultimate_garbage();
+            dec->finish(garbage);
+         });
 
          if(dec->associated_data_requires_key()) {
-            result.test_throws("Unkeyed object throws for set AD",
-                               [&]() { dec->set_associated_data(ad.data(), ad.size()); });
+            result.test_throws<Botan::Invalid_State>("Unkeyed object throws for set AD",
+                                                     [&]() { dec->set_associated_data(ad.data(), ad.size()); });
          }
 
          // First some tests for reset() to make sure it resets what we need it to
@@ -215,17 +236,23 @@ class AEAD_Tests final : public Text_Based_Test {
          result.test_eq("key is set", dec->has_keying_material(), true);
          dec->set_associated_data(mutate_vec(ad, rng));
 
-         if(is_siv == false) {
-            result.test_throws("Cannot process data until nonce is set (dec)", [&]() { dec->update(garbage); });
-            result.test_throws("Cannot process data until nonce is set (dec)", [&]() { dec->finish(garbage); });
+         if(!is_siv) {
+            result.test_throws<Botan::Invalid_State>("Cannot process data until nonce is set (dec)", [&]() {
+               auto garbage = get_garbage();
+               dec->update(garbage);
+            });
+            result.test_throws<Botan::Invalid_State>("Cannot process data until nonce is set (dec)", [&]() {
+               auto garbage = get_ultimate_garbage();
+               dec->finish(garbage);
+            });
          }
 
          dec->start(mutate_vec(nonce, rng));
-
+         auto garbage = get_garbage();
          dec->update(garbage);
 
          // reset message specific state
-         dec->reset();
+         dec->reset();  // NOLINT(*-ambiguous-smartptr-reset-call)
 
          Botan::secure_vector<uint8_t> buf(input.begin(), input.end());
          try {
@@ -236,7 +263,7 @@ class AEAD_Tests final : public Text_Based_Test {
                dec->set_associated_data(ad);
             } catch(Botan::Invalid_State&) {
                // ad after setting nonce rejected, in this case we need to reset
-               dec->reset();
+               dec->reset();  // NOLINT(*-ambiguous-smartptr-reset-call)
                dec->set_associated_data(ad);
                dec->start(nonce);
             }
@@ -249,7 +276,7 @@ class AEAD_Tests final : public Text_Based_Test {
             const size_t update_granularity = dec->update_granularity();
             if(input.size() > update_granularity) {
                // reset state first
-               dec->reset();
+               dec->reset();  // NOLINT(*-ambiguous-smartptr-reset-call)
 
                dec->set_associated_data(ad);
                dec->start(nonce);
@@ -281,7 +308,7 @@ class AEAD_Tests final : public Text_Based_Test {
             const size_t min_final_size = dec->minimum_final_size();
             if(input.size() > (update_granularity + min_final_size)) {
                // again reset state first
-               dec->reset();
+               dec->reset();  // NOLINT(*-ambiguous-smartptr-reset-call)
 
                dec->set_associated_data(ad);
                dec->start(nonce);
@@ -318,7 +345,7 @@ class AEAD_Tests final : public Text_Based_Test {
          const std::vector<uint8_t> mutated_input = mutate_vec(input, rng, true);
          buf.assign(mutated_input.begin(), mutated_input.end());
 
-         dec->reset();
+         dec->reset();  // NOLINT(*-ambiguous-smartptr-reset-call)
 
          dec->set_associated_data(ad);
          dec->start(nonce);
@@ -337,7 +364,7 @@ class AEAD_Tests final : public Text_Based_Test {
             buf.assign(input.begin(), input.end());
             std::vector<uint8_t> bad_nonce = mutate_vec(nonce, rng);
 
-            dec->reset();
+            dec->reset();  // NOLINT(*-ambiguous-smartptr-reset-call)
             dec->set_associated_data(ad);
             dec->start(bad_nonce);
 
@@ -354,7 +381,7 @@ class AEAD_Tests final : public Text_Based_Test {
          // test decryption with modified associated_data
          const std::vector<uint8_t> bad_ad = mutate_vec(ad, rng, true);
 
-         dec->reset();
+         dec->reset();  // NOLINT(*-ambiguous-smartptr-reset-call)
          dec->set_associated_data(bad_ad);
 
          dec->start(nonce);
@@ -374,11 +401,11 @@ class AEAD_Tests final : public Text_Based_Test {
          dec->clear();
          result.test_eq("key is not set", dec->has_keying_material(), false);
 
-         result.test_throws("Unkeyed object throws for decrypt", [&]() { dec->finish(buf); });
+         result.test_throws<Botan::Invalid_State>("Unkeyed object throws for decrypt", [&]() { dec->finish(buf); });
 
          if(dec->associated_data_requires_key()) {
-            result.test_throws("Unkeyed object throws for set AD",
-                               [&]() { dec->set_associated_data(ad.data(), ad.size()); });
+            result.test_throws<Botan::Invalid_State>("Unkeyed object throws for set AD",
+                                                     [&]() { dec->set_associated_data(ad.data(), ad.size()); });
          }
 
          return result;
@@ -431,6 +458,7 @@ class AEAD_Tests final : public Text_Based_Test {
          result.merge(test_enc(key, nonce, input, expected, ad, algo, this->rng()));
 
          // test dec
+         // NOLINTNEXTLINE(*-suspicious-call-argument) Yes we are swapping ptext and ctext arguments here
          result.merge(test_dec(key, nonce, expected, input, ad, algo, this->rng()));
 
          return result;
