@@ -11,12 +11,11 @@
    #include "test_rng.h"
    #include <botan/bigint.h>
    #include <botan/numthry.h>
-   #include <botan/reducer.h>
+   #include <botan/internal/barrett.h>
    #include <botan/internal/ct_utils.h>
    #include <botan/internal/divide.h>
    #include <botan/internal/fmt.h>
    #include <botan/internal/mod_inv.h>
-   #include <botan/internal/mp_core.h>
    #include <botan/internal/parsing.h>
    #include <botan/internal/primality.h>
    #include <botan/internal/stl_util.h>
@@ -379,18 +378,19 @@ class BigInt_Div_Test final : public Text_Based_Test {
          e /= b;
          result.test_eq("a /= b", e, c);
 
-         if(b.sig_words() == 1) {
+         if(b.sig_words() == 1 && b.is_positive()) {
             const Botan::word bw = b.word_at(0);
-            result.test_eq("bw ok", Botan::BigInt::from_word(bw), b);
+            result.test_eq("Low word correct", Botan::BigInt::from_word(bw), b);
 
             Botan::BigInt ct_q;
-            Botan::word ct_r;
+            Botan::word ct_r = 0;
             Botan::ct_divide_word(a, bw, ct_q, ct_r);
             result.test_eq("ct_divide_word q", ct_q, c);
             result.test_eq("ct_divide_word r", ct_q * b + ct_r, a);
          }
 
-         Botan::BigInt ct_q, ct_r;
+         Botan::BigInt ct_q;
+         Botan::BigInt ct_r;
          Botan::ct_divide(a, b, ct_q, ct_r);
          result.test_eq("ct_divide q", ct_q, c);
          result.test_eq("ct_divide r", ct_q * b + ct_r, a);
@@ -404,17 +404,12 @@ BOTAN_REGISTER_TEST("math", "bn_div", BigInt_Div_Test);
 class BigInt_DivPow2k_Test final : public Test {
    public:
       std::vector<Test::Result> run() override {
-         Test::Result result("BigInt ct_divide_pow2k");
+         Test::Result result("BigInt divide pow2k");
 
          for(size_t k = 2; k != 128; ++k) {
-            auto div1 = Botan::ct_divide_pow2k(k, 1);
-            result.test_eq("ct_divide_pow2k div 1", div1, Botan::BigInt::power_of_2(k));
-
-            auto div2 = Botan::ct_divide_pow2k(k, 2);
-            result.test_eq("ct_divide_pow2k div 2", div2, Botan::BigInt::power_of_2(k - 1));
-
-            auto div4 = Botan::ct_divide_pow2k(k, 4);
-            result.test_eq("ct_divide_pow2k div 4", div4, Botan::BigInt::power_of_2(k - 2));
+            testcase(k, 1, result);
+            testcase(k, 2, result);
+            testcase(k, 4, result);
          }
 
          for(size_t k = 4; k != 512; ++k) {
@@ -425,15 +420,23 @@ class BigInt_DivPow2k_Test final : public Test {
                if(y.is_zero()) {
                   continue;
                }
-               const BigInt ct_pow2k = ct_divide_pow2k(k, y);
-               const BigInt ref = BigInt::power_of_2(k) / y;
 
-               result.test_eq("ct_divide_pow2k matches Knuth division", ct_pow2k, ref);
+               testcase(k, y, result);
             }
          }
 
          return {result};
       }
+
+   private:
+      static void testcase(size_t k, const BigInt& y, Test::Result& result) {
+         const BigInt ct_pow2k = ct_divide_pow2k(k, y);
+         const BigInt vt_pow2k = vartime_divide_pow2k(k, y);
+         const BigInt ref = BigInt::power_of_2(k) / y;
+
+         result.test_eq("ct_divide_pow2k matches Knuth division", ct_pow2k, ref);
+         result.test_eq("vartime_divide_pow2k matches Knuth division", vt_pow2k, ref);
+      }
 };
 
 BOTAN_REGISTER_TEST("math", "bn_div_pow2k", BigInt_DivPow2k_Test);
@@ -455,11 +458,13 @@ class BigInt_Mod_Test final : public Text_Based_Test {
          e %= b;
          result.test_eq("a %= b", e, expected);
 
-         auto mod_b_pub = Botan::Modular_Reducer::for_public_modulus(b);
-         result.test_eq("Barrett public", mod_b_pub.reduce(a), expected);
+         if(a.is_positive() && a < (b * b)) {
+            auto mod_b_pub = Botan::Barrett_Reduction::for_public_modulus(b);
+            result.test_eq("Barrett public", mod_b_pub.reduce(a), expected);
 
-         auto mod_b_sec = Botan::Modular_Reducer::for_secret_modulus(b);
-         result.test_eq("Barrett secret", mod_b_sec.reduce(a), expected);
+            auto mod_b_sec = Botan::Barrett_Reduction::for_secret_modulus(b);
+            result.test_eq("Barrett secret", mod_b_sec.reduce(a), expected);
+         }
 
          // if b fits into a Botan::word test %= operator for words
          if(b.sig_words() == 1) {
@@ -472,12 +477,13 @@ class BigInt_Mod_Test final : public Text_Based_Test {
             result.test_eq("a % b (as word)", a % b_word, expected);
 
             Botan::BigInt ct_q;
-            Botan::word ct_r;
+            Botan::word ct_r = 0;
             Botan::ct_divide_word(a, b.word_at(0), ct_q, ct_r);
             result.test_eq("ct_divide_u8 r", ct_r, expected);
          }
 
-         Botan::BigInt ct_q, ct_r;
+         Botan::BigInt ct_q;
+         Botan::BigInt ct_r;
          Botan::ct_divide(a, b, ct_q, ct_r);
          result.test_eq("ct_divide r", ct_r, expected);
 
@@ -487,6 +493,55 @@ class BigInt_Mod_Test final : public Text_Based_Test {
 
 BOTAN_REGISTER_TEST("math", "bn_mod", BigInt_Mod_Test);
 
+class Barrett_Redc_Test final : public Test {
+   public:
+      std::vector<Test::Result> run() override {
+         Test::Result result("Barrett reduction");
+
+         for(size_t t = 0; t != 10000; ++t) {
+            const auto mod = [&]() {
+               if(t <= 16) {
+                  return BigInt::from_u64(t) + 1;
+               } else {
+                  const size_t bits = (t / 4) + 2;
+
+                  if(t % 4 == 0) {
+                     return BigInt::power_of_2(bits);
+                  } else if(t % 4 == 1) {
+                     return BigInt::power_of_2(bits) - 1;
+                  } else if(t % 4 == 2) {
+                     return BigInt::power_of_2(bits) + 1;
+                  } else {
+                     Botan::BigInt b;
+                     b.randomize(rng(), bits, true);
+                     return b;
+                  }
+               }
+            }();
+
+            const size_t mod_bits = mod.bits();
+            auto barrett = Botan::Barrett_Reduction::for_public_modulus(mod);
+
+            for(size_t i = 0; i != 10; ++i) {
+               const auto input = [&]() {
+                  Botan::BigInt b;
+                  b.randomize(rng(), 2 * mod_bits, false);
+                  return b;
+               }();
+
+               const auto reduced_ref = input % mod;
+               const auto reduced_barrett = barrett.reduce(input);
+
+               result.test_eq("Barrett reduction matches variable time division", reduced_barrett, reduced_ref);
+            }
+         }
+
+         return {result};
+      }
+};
+
+BOTAN_REGISTER_TEST("math", "barrett_redc", Barrett_Redc_Test);
+
 class BigInt_GCD_Test final : public Text_Based_Test {
    public:
       BigInt_GCD_Test() : Text_Based_Test("bn/gcd.vec", "X,Y,GCD") {}
@@ -593,7 +648,7 @@ Test::Result test_const_time_left_shift() {
 
    Botan::BigInt a = Botan::BigInt::with_capacity(bits / sizeof(Botan::word));
    for(size_t i = 0; i < bits; ++i) {
-      if(rng->next_byte() & 1) {
+      if(rng->next_byte() % 2 == 1) {
          a.set_bit(i);
       }
    }
@@ -757,7 +812,7 @@ BOTAN_REGISTER_TEST("math", "bn_rand", BigInt_Rand_Test);
 class Lucas_Primality_Test final : public Test {
    public:
       std::vector<Test::Result> run() override {
-         const uint32_t lucas_max = (Test::run_long_tests() ? 100000 : 6000);
+         const uint32_t lucas_max = (Test::run_long_tests() ? 100000 : 10000) + 1;
 
          // OEIS A217120
          std::set<uint32_t> lucas_pp{
@@ -770,7 +825,7 @@ class Lucas_Primality_Test final : public Test {
          Test::Result result("Lucas primality test");
 
          for(uint32_t i = 3; i <= lucas_max; i += 2) {
-            auto mod_i = Botan::Modular_Reducer::for_public_modulus(i);
+            auto mod_i = Botan::Barrett_Reduction::for_public_modulus(i);
             const bool passes_lucas = Botan::is_lucas_probable_prime(i, mod_i);
             const bool is_prime = Botan::is_prime(i, this->rng());
 
@@ -830,9 +885,9 @@ class RSA_Compute_Exp_Test : public Test {
 
             auto d = Botan::compute_rsa_secret_exponent(e, phi_n, p, q);
 
-            auto one = (e * d) % phi_n;
+            auto ed_mod_phi_n = (e * d) % phi_n;
 
-            result.test_eq("compute_rsa_secret_exponent returned inverse", (e * d) % phi_n, Botan::BigInt::one());
+            result.test_eq("compute_rsa_secret_exponent returned inverse", ed_mod_phi_n, Botan::BigInt::one());
          }
 
          return {result};
@@ -864,7 +919,8 @@ class DSA_ParamGen_Test final : public Text_Based_Test {
          Test::Result result("DSA Parameter Generation");
 
          try {
-            Botan::BigInt gen_P, gen_Q;
+            Botan::BigInt gen_P;
+            Botan::BigInt gen_Q;
             if(Botan::generate_dsa_primes(this->rng(), gen_P, gen_Q, p_bits, q_bits, seed, offset)) {
                result.test_eq("P", gen_P, exp_P);
                result.test_eq("Q", gen_Q, exp_Q);
