@@ -11,7 +11,6 @@
 #if defined(BOTAN_HAS_PQCRYSTALS)
    #include <botan/hex.h>
 
-   #include <botan/internal/fmt.h>
    #include <botan/internal/pqcrystals.h>
    #include <botan/internal/pqcrystals_encoding.h>
    #include <botan/internal/pqcrystals_helpers.h>
@@ -159,7 +158,7 @@ std::vector<Test::Result> test_polynomial_basics() {
                }
             }),
 
-      CHECK("cloned polynomials always manage their storge",
+      CHECK("cloned polynomials always manage their storage",
             [](Test::Result& res) {
                Kyberish_Poly<Domain::Normal> p;
                auto p2 = p.clone();
