@@ -15,8 +15,8 @@
    #include <botan/hex.h>
    #include <botan/numthry.h>
    #include <botan/pk_keys.h>
-   #include <botan/reducer.h>
    #include <botan/x509_key.h>
+   #include <botan/internal/barrett.h>
    #include <botan/internal/ec_inner_data.h>
 #endif
 
@@ -80,7 +80,7 @@ Botan::BigInt test_integer(Botan::RandomNumberGenerator& rng, size_t bits, const
 
 Botan::EC_Point create_random_point(Botan::RandomNumberGenerator& rng, const Botan::EC_Group& group) {
    const Botan::BigInt& p = group.get_p();
-   auto mod_p = Botan::Modular_Reducer::for_public_modulus(p);
+   auto mod_p = Botan::Barrett_Reduction::for_public_modulus(p);
 
    for(;;) {
       const Botan::BigInt x = Botan::BigInt::random_integer(rng, 1, p);
@@ -112,9 +112,8 @@ std::vector<Test::Result> ECC_Randomized_Tests::run() {
 
       const Botan::EC_Point pt = create_random_point(this->rng(), group);
 
-      std::vector<Botan::BigInt> blind_ws;
-
       try {
+         std::vector<Botan::BigInt> blind_ws;
          const size_t trials = (Test::run_long_tests() ? 10 : 3);
          for(size_t i = 0; i < trials; ++i) {
             const Botan::BigInt a = test_integer(rng(), group.get_order_bits(), group.get_order());
@@ -183,7 +182,7 @@ class EC_Group_Tests : public Test {
 
             result.confirm("EC_Group is known", group.get_curve_oid().has_value());
             result.confirm("EC_Group is considered valid", group.verify_group(this->rng(), true));
-            result.confirm("EC_Group is not considered explict encoding", !group.used_explicit_encoding());
+            result.confirm("EC_Group is not considered explicit encoding", !group.used_explicit_encoding());
 
             result.test_eq("EC_Group has correct bit size", group.get_p().bits(), group.get_p_bits());
             result.test_eq("EC_Group has byte size", group.get_p().bytes(), group.get_p_bytes());
@@ -211,12 +210,12 @@ class EC_Group_Tests : public Test {
 
             const auto group_der_oid = group.DER_encode();
             const Botan::EC_Group group_via_oid(group_der_oid);
-            result.confirm("EC_Group via OID is not considered explict encoding",
+            result.confirm("EC_Group via OID is not considered explicit encoding",
                            !group_via_oid.used_explicit_encoding());
 
             const auto group_der_explicit = group.DER_encode(Botan::EC_Group_Encoding::Explicit);
             const Botan::EC_Group group_via_explicit(group_der_explicit);
-            result.confirm("EC_Group via explicit DER is considered explict encoding",
+            result.confirm("EC_Group via explicit DER is considered explicit encoding",
                            group_via_explicit.used_explicit_encoding());
 
             if(group.a_is_minus_3()) {
@@ -277,8 +276,17 @@ class EC_Group_Tests : public Test {
          for(auto scheme : {Botan::EC_Point_Format::Uncompressed,
                             Botan::EC_Point_Format::Compressed,
                             Botan::EC_Point_Format::Hybrid}) {
-            result.test_eq("encoded/decode rt works", group.OS2ECP(pt.encode(scheme)), pt);
-            result.test_eq("encoded/decode rt works", group.OS2ECP(zero.encode(scheme)), zero);
+            try {
+               result.test_eq("encoded/decode rt works", group.OS2ECP(pt.encode(scheme)), pt);
+            } catch(Botan::Exception& e) {
+               result.test_failure("Failed to round trip encode a random point", e.what());
+            }
+
+            try {
+               result.test_eq("encoded/decode rt works", group.OS2ECP(zero.encode(scheme)), zero);
+            } catch(Botan::Exception& e) {
+               result.test_failure("Failed to round trip encode a random point", e.what());
+            }
          }
       }
 
@@ -400,163 +408,6 @@ Test::Result test_mixed_points() {
    return result;
 }
 
-Test::Result test_ecc_registration() {
-   Test::Result result("ECC registration");
-
-   // numsp256d1
-   const Botan::BigInt p("0xFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF43");
-   const Botan::BigInt a("0xFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF40");
-   const Botan::BigInt b("0x25581");
-   const Botan::BigInt order("0xFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE43C8275EA265C6020AB20294751A825");
-
-   const Botan::BigInt g_x("0x01");
-   const Botan::BigInt g_y("0x696F1853C1E466D7FC82C96CCEEEDD6BD02C2F9375894EC10BF46306C2B56C77");
-
-   const Botan::OID oid("1.3.6.1.4.1.25258.4.1");
-
-   // Creating this object implicitly registers the curve for future use ...
-   Botan::EC_Group reg_group(oid, p, a, b, g_x, g_y, order);
-
-   auto group = Botan::EC_Group::from_OID(oid);
-
-   result.test_eq("Group registration worked", group.get_p(), p);
-
-   // TODO(Botan4) this could change to == Generic
-   result.confirm("Group is not pcurve", group.engine() != Botan::EC_Group_Engine::Optimized);
-
-   return result;
-}
-
-Test::Result test_ec_group_from_params() {
-   Test::Result result("EC_Group from params");
-
-   Botan::EC_Group::clear_registered_curve_data();
-
-   // secp256r1
-   const Botan::BigInt p("0xFFFFFFFF00000001000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF");
-   const Botan::BigInt a("0xFFFFFFFF00000001000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFC");
-   const Botan::BigInt b("0x5AC635D8AA3A93E7B3EBBD55769886BC651D06B0CC53B0F63BCE3C3E27D2604B");
-
-   const Botan::BigInt g_x("0x6B17D1F2E12C4247F8BCE6E563A440F277037D812DEB33A0F4A13945D898C296");
-   const Botan::BigInt g_y("0x4FE342E2FE1A7F9B8EE7EB4A7C0F9E162BCE33576B315ECECBB6406837BF51F5");
-   const Botan::BigInt order("0xFFFFFFFF00000000FFFFFFFFFFFFFFFFBCE6FAADA7179E84F3B9CAC2FC632551");
-
-   const Botan::OID oid("1.2.840.10045.3.1.7");
-
-   // This uses the deprecated constructor to verify we dedup even without an OID
-   // This whole test can be removed once explicit curve support is removed
-   Botan::EC_Group reg_group(p, a, b, g_x, g_y, order, 1);
-   result.confirm("Group has correct OID", reg_group.get_curve_oid() == oid);
-
-   return result;
-}
-
-Test::Result test_ec_group_bad_registration() {
-   Test::Result result("EC_Group registering non-match");
-
-   Botan::EC_Group::clear_registered_curve_data();
-
-   // secp256r1 params except with a bad B param
-   const Botan::BigInt p("0xFFFFFFFF00000001000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF");
-   const Botan::BigInt a("0xFFFFFFFF00000001000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFC");
-   const Botan::BigInt b("0x5AC635D8AA3A93E7B3EBBD55769886BC651D06B0CC53B0F63BCE3C3E27D2604C");
-
-   const Botan::BigInt g_x("0x6B17D1F2E12C4247F8BCE6E563A440F277037D812DEB33A0F4A13945D898C296");
-   const Botan::BigInt g_y("0x4FE342E2FE1A7F9B8EE7EB4A7C0F9E162BCE33576B315ECECBB6406837BF51F5");
-   const Botan::BigInt order("0xFFFFFFFF00000000FFFFFFFFFFFFFFFFBCE6FAADA7179E84F3B9CAC2FC632551");
-
-   const Botan::OID oid("1.2.840.10045.3.1.7");
-
-   try {
-      Botan::EC_Group reg_group(oid, p, a, b, g_x, g_y, order);
-      result.test_failure("Should have failed");
-   } catch(Botan::Invalid_Argument&) {
-      result.test_success("Got expected exception");
-   }
-
-   return result;
-}
-
-Test::Result test_ec_group_duplicate_orders() {
-   Test::Result result("EC_Group with duplicate group order");
-
-   Botan::EC_Group::clear_registered_curve_data();
-
-   // secp256r1
-   const Botan::BigInt p("0xFFFFFFFF00000001000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF");
-   const Botan::BigInt a("0xFFFFFFFF00000001000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFC");
-   const Botan::BigInt b("0x5AC635D8AA3A93E7B3EBBD55769886BC651D06B0CC53B0F63BCE3C3E27D2604B");
-
-   const Botan::BigInt g_x("0x6B17D1F2E12C4247F8BCE6E563A440F277037D812DEB33A0F4A13945D898C296");
-   const Botan::BigInt g_y("0x4FE342E2FE1A7F9B8EE7EB4A7C0F9E162BCE33576B315ECECBB6406837BF51F5");
-   const Botan::BigInt order("0xFFFFFFFF00000000FFFFFFFFFFFFFFFFBCE6FAADA7179E84F3B9CAC2FC632551");
-
-   const Botan::OID oid("1.3.6.1.4.1.25258.100.0");  // some other random OID
-
-   Botan::EC_Group reg_group(oid, p, a, b, g_x, g_y, order);
-   result.test_success("Registration success");
-   result.confirm("Group has correct OID", reg_group.get_curve_oid() == oid);
-
-   // We can now get it by OID:
-   const auto hc_group = Botan::EC_Group::from_OID(oid);
-   result.confirm("Group has correct OID", hc_group.get_curve_oid() == oid);
-
-   // Existing secp256r1 unmodified:
-   const Botan::OID secp160r1("1.2.840.10045.3.1.7");
-   const auto other_group = Botan::EC_Group::from_OID(secp160r1);
-   result.confirm("Group has correct OID", other_group.get_curve_oid() == secp160r1);
-
-   return result;
-}
-
-Test::Result test_ec_group_registration_with_custom_oid() {
-   Test::Result result("EC_Group registration of standard group with custom OID");
-
-   Botan::EC_Group::clear_registered_curve_data();
-
-   const Botan::OID secp256r1_oid("1.2.840.10045.3.1.7");
-   const auto secp256r1 = Botan::EC_Group::from_OID(secp256r1_oid);
-   result.confirm("Group has correct OID", secp256r1.get_curve_oid() == secp256r1_oid);
-
-   const Botan::OID custom_oid("1.3.6.1.4.1.25258.100.99");  // some other random OID
-
-   Botan::OID::register_oid(custom_oid, "secp256r1");
-
-   Botan::EC_Group reg_group(custom_oid,
-                             secp256r1.get_p(),
-                             secp256r1.get_a(),
-                             secp256r1.get_b(),
-                             secp256r1.get_g_x(),
-                             secp256r1.get_g_y(),
-                             secp256r1.get_order());
-
-   result.test_success("Registration success");
-   result.confirm("Group has correct OID", reg_group.get_curve_oid() == custom_oid);
-
-   // We can now get it by OID:
-   result.confirm("Group has correct OID", Botan::EC_Group::from_OID(custom_oid).get_curve_oid() == custom_oid);
-
-   // In the current data model of EC_Group there is a 1:1 OID:group, so these
-   // have distinct underlying data
-   result.confirm("Groups have different inner data pointers", reg_group._data() != secp256r1._data());
-
-   #if defined(BOTAN_HAS_PCURVES_SECP256R1)
-   // However we should have gotten a pcurves out of the deal *and* it
-   // should be the exact same shared_ptr as the official curve
-
-   result.confirm("Group is pcurves based", reg_group.engine() == Botan::EC_Group_Engine::Optimized);
-
-   try {
-      const auto& pcurve = reg_group._data()->pcurve();
-      result.confirm("Group with custom OID got the same pcurve pointer", &pcurve == &secp256r1._data()->pcurve());
-   } catch(...) {
-      result.test_failure("Group with custom OID did not get a pcurve pointer");
-   }
-   #endif
-
-   return result;
-}
-
 class ECC_Unit_Tests final : public Test {
    public:
       std::vector<Test::Result> run() override {
@@ -565,6 +416,17 @@ class ECC_Unit_Tests final : public Test {
          results.push_back(test_decoding_with_seed());
          results.push_back(test_mixed_points());
 
+         return results;
+      }
+};
+
+BOTAN_REGISTER_TEST("pubkey", "ecc_unit", ECC_Unit_Tests);
+
+class EC_Group_Registration_Tests final : public Test {
+   public:
+      std::vector<Test::Result> run() override {
+         std::vector<Test::Result> results;
+
          if(Botan::EC_Group::supports_application_specific_group()) {
             results.push_back(test_ecc_registration());
             results.push_back(test_ec_group_from_params());
@@ -575,9 +437,168 @@ class ECC_Unit_Tests final : public Test {
 
          return results;
       }
+
+   private:
+      Test::Result test_ecc_registration() {
+         Test::Result result("ECC registration");
+
+         // numsp256d1
+         const Botan::BigInt p("0xFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF43");
+         const Botan::BigInt a("0xFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF40");
+         const Botan::BigInt b("0x25581");
+         const Botan::BigInt order("0xFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE43C8275EA265C6020AB20294751A825");
+
+         const Botan::BigInt g_x("0x01");
+         const Botan::BigInt g_y("0x696F1853C1E466D7FC82C96CCEEEDD6BD02C2F9375894EC10BF46306C2B56C77");
+
+         const Botan::OID oid("1.3.6.1.4.1.25258.4.1");
+
+         // Creating this object implicitly registers the curve for future use ...
+         Botan::EC_Group reg_group(oid, p, a, b, g_x, g_y, order);
+
+         auto group = Botan::EC_Group::from_OID(oid);
+
+         result.test_eq("Group registration worked", group.get_p(), p);
+
+         // TODO(Botan4) this could change to == Generic
+         result.confirm("Group is not pcurve", group.engine() != Botan::EC_Group_Engine::Optimized);
+
+         return result;
+      }
+
+      Test::Result test_ec_group_from_params() {
+         Test::Result result("EC_Group from params");
+
+         Botan::EC_Group::clear_registered_curve_data();
+
+         // secp256r1
+         const Botan::BigInt p("0xFFFFFFFF00000001000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF");
+         const Botan::BigInt a("0xFFFFFFFF00000001000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFC");
+         const Botan::BigInt b("0x5AC635D8AA3A93E7B3EBBD55769886BC651D06B0CC53B0F63BCE3C3E27D2604B");
+
+         const Botan::BigInt g_x("0x6B17D1F2E12C4247F8BCE6E563A440F277037D812DEB33A0F4A13945D898C296");
+         const Botan::BigInt g_y("0x4FE342E2FE1A7F9B8EE7EB4A7C0F9E162BCE33576B315ECECBB6406837BF51F5");
+         const Botan::BigInt order("0xFFFFFFFF00000000FFFFFFFFFFFFFFFFBCE6FAADA7179E84F3B9CAC2FC632551");
+
+         const Botan::OID oid("1.2.840.10045.3.1.7");
+
+         // This uses the deprecated constructor to verify we dedup even without an OID
+         // This whole test can be removed once explicit curve support is removed
+         Botan::EC_Group reg_group(p, a, b, g_x, g_y, order, 1);
+         result.confirm("Group has correct OID", reg_group.get_curve_oid() == oid);
+
+         return result;
+      }
+
+      Test::Result test_ec_group_bad_registration() {
+         Test::Result result("EC_Group registering non-match");
+
+         Botan::EC_Group::clear_registered_curve_data();
+
+         // secp256r1 params except with a bad B param
+         const Botan::BigInt p("0xFFFFFFFF00000001000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF");
+         const Botan::BigInt a("0xFFFFFFFF00000001000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFC");
+         const Botan::BigInt b("0x5AC635D8AA3A93E7B3EBBD55769886BC651D06B0CC53B0F63BCE3C3E27D2604C");
+
+         const Botan::BigInt g_x("0x6B17D1F2E12C4247F8BCE6E563A440F277037D812DEB33A0F4A13945D898C296");
+         const Botan::BigInt g_y("0x4FE342E2FE1A7F9B8EE7EB4A7C0F9E162BCE33576B315ECECBB6406837BF51F5");
+         const Botan::BigInt order("0xFFFFFFFF00000000FFFFFFFFFFFFFFFFBCE6FAADA7179E84F3B9CAC2FC632551");
+
+         const Botan::OID oid("1.2.840.10045.3.1.7");
+
+         try {
+            Botan::EC_Group reg_group(oid, p, a, b, g_x, g_y, order);
+            result.test_failure("Should have failed");
+         } catch(Botan::Invalid_Argument&) {
+            result.test_success("Got expected exception");
+         }
+
+         return result;
+      }
+
+      Test::Result test_ec_group_duplicate_orders() {
+         Test::Result result("EC_Group with duplicate group order");
+
+         Botan::EC_Group::clear_registered_curve_data();
+
+         // secp256r1
+         const Botan::BigInt p("0xFFFFFFFF00000001000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF");
+         const Botan::BigInt a("0xFFFFFFFF00000001000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFC");
+         const Botan::BigInt b("0x5AC635D8AA3A93E7B3EBBD55769886BC651D06B0CC53B0F63BCE3C3E27D2604B");
+
+         const Botan::BigInt g_x("0x6B17D1F2E12C4247F8BCE6E563A440F277037D812DEB33A0F4A13945D898C296");
+         const Botan::BigInt g_y("0x4FE342E2FE1A7F9B8EE7EB4A7C0F9E162BCE33576B315ECECBB6406837BF51F5");
+         const Botan::BigInt order("0xFFFFFFFF00000000FFFFFFFFFFFFFFFFBCE6FAADA7179E84F3B9CAC2FC632551");
+
+         const Botan::OID oid("1.3.6.1.4.1.25258.100.0");  // some other random OID
+
+         Botan::EC_Group reg_group(oid, p, a, b, g_x, g_y, order);
+         result.test_success("Registration success");
+         result.confirm("Group has correct OID", reg_group.get_curve_oid() == oid);
+
+         // We can now get it by OID:
+         const auto hc_group = Botan::EC_Group::from_OID(oid);
+         result.confirm("Group has correct OID", hc_group.get_curve_oid() == oid);
+
+         // Existing secp256r1 unmodified:
+         const Botan::OID secp160r1("1.2.840.10045.3.1.7");
+         const auto other_group = Botan::EC_Group::from_OID(secp160r1);
+         result.confirm("Group has correct OID", other_group.get_curve_oid() == secp160r1);
+
+         return result;
+      }
+
+      Test::Result test_ec_group_registration_with_custom_oid() {
+         Test::Result result("EC_Group registration of standard group with custom OID");
+
+         Botan::EC_Group::clear_registered_curve_data();
+
+         const Botan::OID secp256r1_oid("1.2.840.10045.3.1.7");
+         const auto secp256r1 = Botan::EC_Group::from_OID(secp256r1_oid);
+         result.confirm("Group has correct OID", secp256r1.get_curve_oid() == secp256r1_oid);
+
+         const Botan::OID custom_oid("1.3.6.1.4.1.25258.100.99");  // some other random OID
+
+         Botan::OID::register_oid(custom_oid, "secp256r1");
+
+         Botan::EC_Group reg_group(custom_oid,
+                                   secp256r1.get_p(),
+                                   secp256r1.get_a(),
+                                   secp256r1.get_b(),
+                                   secp256r1.get_g_x(),
+                                   secp256r1.get_g_y(),
+                                   secp256r1.get_order());
+
+         result.test_success("Registration success");
+         result.confirm("Group has correct OID", reg_group.get_curve_oid() == custom_oid);
+
+         // We can now get it by OID:
+         result.confirm("Group has correct OID", Botan::EC_Group::from_OID(custom_oid).get_curve_oid() == custom_oid);
+
+         // In the current data model of EC_Group there is a 1:1 OID:group, so these
+         // have distinct underlying data
+         result.confirm("Groups have different inner data pointers", reg_group._data() != secp256r1._data());
+
+   #if defined(BOTAN_HAS_PCURVES_SECP256R1)
+         // However we should have gotten a pcurves out of the deal *and* it
+         // should be the exact same shared_ptr as the official curve
+
+         result.confirm("Group is pcurves based", reg_group.engine() == Botan::EC_Group_Engine::Optimized);
+
+         try {
+            const auto& pcurve = reg_group._data()->pcurve();
+            result.confirm("Group with custom OID got the same pcurve pointer",
+                           &pcurve == &secp256r1._data()->pcurve());
+         } catch(...) {
+            result.test_failure("Group with custom OID did not get a pcurve pointer");
+         }
+   #endif
+
+         return result;
+      }
 };
 
-BOTAN_REGISTER_SERIALIZED_TEST("pubkey", "ecc_unit", ECC_Unit_Tests);
+BOTAN_REGISTER_SERIALIZED_TEST("pubkey", "ec_group_registration", EC_Group_Registration_Tests);
 
 class EC_PointEnc_Tests final : public Test {
    public:
@@ -593,11 +614,9 @@ class EC_PointEnc_Tests final : public Test {
 
             result.start_timer();
 
-            std::vector<Botan::BigInt> ws;
-
             for(size_t trial = 0; trial != 100; ++trial) {
                const auto scalar = Botan::EC_Scalar::random(group, rng);
-               const auto pt = Botan::EC_AffinePoint::g_mul(scalar, rng, ws);
+               const auto pt = Botan::EC_AffinePoint::g_mul(scalar, rng);
 
                const auto pt_u = pt.serialize_uncompressed();
                result.test_eq("Expected uncompressed header", static_cast<size_t>(pt_u[0]), 0x04);
@@ -658,8 +677,6 @@ class EC_Point_Arithmetic_Tests final : public Test {
 
          auto& rng = Test::rng();
 
-         std::vector<Botan::BigInt> ws;
-
          for(const auto& group_id : Botan::EC_Group::known_named_groups()) {
             const auto group = Botan::EC_Group::from_name(group_id);
 
@@ -668,17 +685,17 @@ class EC_Point_Arithmetic_Tests final : public Test {
             result.start_timer();
 
             const auto one = Botan::EC_Scalar::one(group);
-            const auto zero = one - one;
+            const auto zero = one - one;  // NOLINT(*-redundant-expression)
             const auto g = Botan::EC_AffinePoint::generator(group);
             const auto g_bytes = g.serialize_uncompressed();
 
-            const auto id = Botan::EC_AffinePoint::g_mul(zero, rng, ws);
+            const auto id = Botan::EC_AffinePoint::g_mul(zero, rng);
             result.confirm("g*zero is point at identity", id.is_identity());
 
             const auto id2 = id.add(id);
             result.confirm("identity plus itself is identity", id2.is_identity());
 
-            const auto g_one = Botan::EC_AffinePoint::g_mul(one, rng, ws);
+            const auto g_one = Botan::EC_AffinePoint::g_mul(one, rng);
             result.test_eq("g*one == generator", g_one.serialize_uncompressed(), g_bytes);
 
             const auto g_plus_id = g_one.add(id);
@@ -687,19 +704,19 @@ class EC_Point_Arithmetic_Tests final : public Test {
             const auto id_plus_g = id.add(g_one);
             result.test_eq("id + g == g", id_plus_g.serialize_uncompressed(), g_bytes);
 
-            const auto g_neg_one = Botan::EC_AffinePoint::g_mul(one.negate(), rng, ws);
+            const auto g_neg_one = Botan::EC_AffinePoint::g_mul(one.negate(), rng);
 
             const auto id_from_g = g_one.add(g_neg_one);
             result.confirm("g - g is identity", id_from_g.is_identity());
 
-            const auto g_two = Botan::EC_AffinePoint::g_mul(one + one, rng, ws);
+            const auto g_two = Botan::EC_AffinePoint::g_mul(one + one, rng);
             const auto g_plus_g = g_one.add(g_one);
             result.test_eq("2*g == g+g", g_two.serialize_uncompressed(), g_plus_g.serialize_uncompressed());
 
             result.confirm("Scalar::zero is zero", zero.is_zero());
             result.confirm("(zero+zero) is zero", (zero + zero).is_zero());
             result.confirm("(zero*zero) is zero", (zero * zero).is_zero());
-            result.confirm("(zero-zero) is zero", (zero - zero).is_zero());
+            result.confirm("(zero-zero) is zero", (zero - zero).is_zero());  // NOLINT(*-redundant-expression)
 
             const auto neg_zero = zero.negate();
             result.confirm("zero.negate() is zero", neg_zero.is_zero());
@@ -709,20 +726,20 @@ class EC_Point_Arithmetic_Tests final : public Test {
             result.confirm("(nz+zero) is zero", (neg_zero + zero).is_zero());
 
             result.confirm("Scalar::one is not zero", !one.is_zero());
-            result.confirm("(one-one) is zero", (one - one).is_zero());
+            result.confirm("(one-one) is zero", (one - one).is_zero());  // NOLINT(*-redundant-expression)
             result.confirm("(one+one.negate()) is zero", (one + one.negate()).is_zero());
             result.confirm("(one.negate()+one) is zero", (one.negate() + one).is_zero());
 
             for(size_t i = 0; i != 16; ++i) {
-               const auto pt = Botan::EC_AffinePoint::g_mul(Botan::EC_Scalar::random(group, rng), rng, ws);
+               const auto pt = Botan::EC_AffinePoint::g_mul(Botan::EC_Scalar::random(group, rng), rng);
 
                const auto a = Botan::EC_Scalar::random(group, rng);
                const auto b = Botan::EC_Scalar::random(group, rng);
                const auto c = a + b;
 
-               const auto Pa = pt.mul(a, rng, ws);
-               const auto Pb = pt.mul(b, rng, ws);
-               const auto Pc = pt.mul(c, rng, ws);
+               const auto Pa = pt.mul(a, rng);
+               const auto Pb = pt.mul(b, rng);
+               const auto Pc = pt.mul(c, rng);
 
                const auto Pc_bytes = Pc.serialize_uncompressed();
 
@@ -753,7 +770,7 @@ class EC_Point_Arithmetic_Tests final : public Test {
                         return Botan::EC_Scalar::random(group, rng);
                      }
                   }();
-                  auto x = Botan::EC_AffinePoint::g_mul(s, rng, ws);
+                  auto x = Botan::EC_AffinePoint::g_mul(s, rng);
                   return x;
                }();
 
@@ -762,7 +779,7 @@ class EC_Point_Arithmetic_Tests final : public Test {
 
                const Botan::EC_Group::Mul2Table mul2_table(h);
 
-               const auto ref = Botan::EC_AffinePoint::g_mul(s1, rng, ws).add(h.mul(s2, rng, ws));
+               const auto ref = Botan::EC_AffinePoint::g_mul(s1, rng).add(h.mul(s2, rng));
 
                if(auto mul2pt = mul2_table.mul2_vartime(s1, s2)) {
                   result.test_eq("ref == mul2t", ref.serialize_uncompressed(), mul2pt->serialize_uncompressed());
