@@ -7,13 +7,12 @@
 
 #include "tests.h"
 
-#include "test_rng.h"
-
 #if defined(BOTAN_HAS_ECDSA)
    #include "test_pubkey.h"
    #include <botan/ecdsa.h>
    #include <botan/hash.h>
    #include <botan/pk_algs.h>
+   #include <botan/pkcs8.h>
 #endif
 
 namespace Botan_Tests {
@@ -29,7 +28,7 @@ class ECDSA_Verification_Tests final : public PK_Signature_Verification_Test {
 
       bool clear_between_callbacks() const override { return false; }
 
-      bool skip_this_test(const std::string&, const VarMap& vars) override {
+      bool skip_this_test(const std::string& /*header*/, const VarMap& vars) override {
          return !Botan::EC_Group::supports_named_group(vars.get_req_str("Group"));
       }
 
@@ -59,7 +58,7 @@ class ECDSA_Wycheproof_Verification_Tests final : public PK_Signature_Verificati
 
       bool test_random_invalid_sigs() const override { return false; }
 
-      bool skip_this_test(const std::string&, const VarMap& vars) override {
+      bool skip_this_test(const std::string& /*header*/, const VarMap& vars) override {
          return !Botan::EC_Group::supports_named_group(vars.get_req_str("Group"));
       }
 
@@ -93,7 +92,7 @@ class ECDSA_Signature_KAT_Tests final : public PK_Signature_Generation_Test {
 
       bool clear_between_callbacks() const override { return false; }
 
-      bool skip_this_test(const std::string&, const VarMap& vars) override {
+      bool skip_this_test(const std::string& /*header*/, const VarMap& vars) override {
          return !Botan::EC_Group::supports_named_group(vars.get_req_str("Group"));
       }
 
@@ -132,7 +131,7 @@ class ECDSA_KAT_Verification_Tests final : public PK_Signature_Verification_Test
 
       bool clear_between_callbacks() const override { return false; }
 
-      bool skip_this_test(const std::string&, const VarMap& vars) override {
+      bool skip_this_test(const std::string& /*header*/, const VarMap& vars) override {
          return !Botan::EC_Group::supports_named_group(vars.get_req_str("Group"));
       }
 
@@ -161,7 +160,7 @@ class ECDSA_Sign_Verify_DER_Test final : public PK_Sign_Verify_DER_Test {
 class ECDSA_Keygen_Tests final : public PK_Key_Generation_Test {
    public:
       std::vector<std::string> keygen_params() const override {
-         auto grp = Botan::EC_Group::known_named_groups();
+         const auto& grp = Botan::EC_Group::known_named_groups();
          return std::vector<std::string>(grp.begin(), grp.end());
       }
 
@@ -187,7 +186,7 @@ class ECDSA_Key_Recovery_Tests final : public Text_Based_Test {
    public:
       ECDSA_Key_Recovery_Tests() : Text_Based_Test("pubkey/ecdsa_key_recovery.vec", "Group,Msg,R,S,V,Pubkey") {}
 
-      bool skip_this_test(const std::string&, const VarMap& vars) override {
+      bool skip_this_test(const std::string& /*header*/, const VarMap& vars) override {
          return !Botan::EC_Group::supports_named_group(vars.get_req_str("Group"));
       }
 
@@ -233,7 +232,7 @@ class ECDSA_Invalid_Key_Tests final : public Text_Based_Test {
 
       bool clear_between_callbacks() const override { return false; }
 
-      bool skip_this_test(const std::string&, const VarMap& vars) override {
+      bool skip_this_test(const std::string& /*header*/, const VarMap& vars) override {
          return !Botan::EC_Group::supports_named_group(vars.get_req_str("Group"));
       }
 
@@ -308,6 +307,43 @@ class ECDSA_AllGroups_Test : public Test {
       }
 };
 
+class ECDSA_ExplicitCurveKey_Test : public Text_Based_Test {
+   public:
+      ECDSA_ExplicitCurveKey_Test() : Text_Based_Test("pubkey/ecdsa_explicit.vec", "Key") {}
+
+      bool clear_between_callbacks() const override { return false; }
+
+      bool skip_this_test(const std::string& group, const VarMap& /*vars*/) override {
+         return !Botan::EC_Group::supports_named_group(group);
+      }
+
+      Test::Result run_one_test(const std::string& group_name, const VarMap& vars) override {
+         Test::Result result("ECDSA explicit key " + group_name);
+
+         const auto key_bytes = vars.get_req_bin("Key");
+
+         try {
+            const auto expected_oid = Botan::OID::from_name(group_name).value();
+
+            auto key = Botan::PKCS8::load_key(key_bytes);
+            const auto* ecdsa = dynamic_cast<const Botan::ECDSA_PrivateKey*>(key.get());
+            if(ecdsa != nullptr) {
+               result.test_success("Returned key was ECDSA");
+
+               const auto& group = ecdsa->domain();
+               result.test_eq("Key is marked as explicit encoding", group.used_explicit_encoding(), true);
+               result.confirm("Group has expected OID", group.get_curve_oid() == expected_oid);
+            } else {
+               result.test_failure("Returned key was some other type");
+            }
+         } catch(Botan::Exception& e) {
+            result.test_failure("Failed to parse key", e.what());
+         }
+
+         return result;
+      }
+};
+
 BOTAN_REGISTER_TEST("pubkey", "ecdsa_verify", ECDSA_Verification_Tests);
 BOTAN_REGISTER_TEST("pubkey", "ecdsa_verify_wycheproof", ECDSA_Wycheproof_Verification_Tests);
 BOTAN_REGISTER_TEST("pubkey", "ecdsa_sign", ECDSA_Signature_KAT_Tests);
@@ -317,6 +353,7 @@ BOTAN_REGISTER_TEST("pubkey", "ecdsa_keygen", ECDSA_Keygen_Tests);
 BOTAN_REGISTER_TEST("pubkey", "ecdsa_keygen_stability", ECDSA_Keygen_Stability_Tests);
 BOTAN_REGISTER_TEST("pubkey", "ecdsa_invalid", ECDSA_Invalid_Key_Tests);
 BOTAN_REGISTER_TEST("pubkey", "ecdsa_all_groups", ECDSA_AllGroups_Test);
+BOTAN_REGISTER_TEST("pubkey", "ecdsa_explicit_curve_key", ECDSA_ExplicitCurveKey_Test);
 
 #endif
 
