@@ -1,7 +1,7 @@
 /*
  * Tests for FrodoKEM ("You SHALL Pass")
  * - KAT tests using the KAT vectors from
- *   https://github.com/microsoft/PQCrypto-LWEKE/tree/master/KAT
+ *   https://github.com/microsoft/PQCrypto-LWEKE/tree/master
  *
  * (C) 2023 Jack Lloyd
  * (C) 2023 René Meusel and Amos Treiber, Rohde & Schwarz Cybersecurity
@@ -13,7 +13,6 @@
 #include "test_rng.h"
 #include "tests.h"
 
-#include <iterator>
 #include <memory>
 
 #if defined(BOTAN_HAS_FRODOKEM)
@@ -22,7 +21,6 @@
    #include <botan/frodokem.h>
    #include <botan/pubkey.h>
    #include <botan/xof.h>
-   #include <botan/internal/fmt.h>
    #include <botan/internal/frodo_constants.h>
 #endif
 
