@@ -7,7 +7,7 @@
 #include "tests.h"
 
 #if defined(BOTAN_HAS_MCELIECE)
-   #include <botan/gf2m_small_m.h>
+   #include <botan/internal/gf2m_small_m.h>
 #endif
 
 namespace Botan_Tests {
@@ -16,33 +16,28 @@ namespace {
 
 #if defined(BOTAN_HAS_MCELIECE)
 
-class GF2m_Tests final : public Test
-   {
+class GF2m_Tests final : public Test {
    public:
-      std::vector<Test::Result> run() override
-         {
+      std::vector<Test::Result> run() override {
          std::vector<Test::Result> results;
 
          results.push_back(test_gf_overflow());
 
          return results;
-         }
+      }
 
    private:
-      Test::Result test_gf_overflow()
-         {
+      static Test::Result test_gf_overflow() {
          Test::Result result("GF2m");
 
          /*
          * This is testing one specific case where an overflow
          * occurred. It should be extended to test more of the interface.
          */
-         for(size_t degree = 2; degree <= 15; ++degree)
-            {
+         for(size_t degree = 2; degree <= 15; ++degree) {
             Botan::GF2m_Field field(degree);
 
-            for(size_t i = 0; i <= field.gf_ord(); ++i)
-               {
+            for(size_t i = 0; i <= field.gf_ord(); ++i) {
                Botan::gf2m a = static_cast<Botan::gf2m>(i);
 
                result.test_eq("square vs multiply",
@@ -52,24 +47,24 @@ class GF2m_Tests final : public Test
                /*
                * This sequence is from the start of gf2m_decomp_rootfind_state::calc_Fxj_j_neq_0
                */
-                  {
+               {
                   const Botan::gf2m jl_gray = field.gf_l_from_n(a);
                   const Botan::gf2m xl_j_tt_5 = field.gf_square_rr(jl_gray);
                   const Botan::gf2m xl_gray_tt_3 = field.gf_mul_rrr(xl_j_tt_5, jl_gray);
                   Botan::gf2m s = field.gf_mul_nrr(xl_gray_tt_3, field.gf_ord());
 
                   result.test_gte("Value less than order", field.gf_ord(), s);
-                  }
                }
             }
-         return result;
          }
-   };
+         return result;
+      }
+};
 
 BOTAN_REGISTER_TEST("pubkey", "gf2m", GF2m_Tests);
 
 #endif
 
-}
+}  // namespace
 
-}
+}  // namespace Botan_Tests
