@@ -28,9 +28,9 @@ class PK_Test : public Text_Based_Test {
       std::string algo_name() const { return m_algo; }
 
    protected:
-      std::vector<std::string> possible_providers(const std::string& params) override;
+      std::vector<std::string> possible_providers(const std::string& algo_name) override;
 
-      virtual std::string default_padding(const VarMap&) const {
+      virtual std::string default_padding(const VarMap& /*vars*/) const {
          throw Test_Error("No default padding scheme set for " + algo_name());
       }
 
@@ -55,7 +55,7 @@ class PK_Signature_Generation_Test : public PK_Test {
       }
 
    private:
-      Test::Result run_one_test(const std::string&, const VarMap& vars) final;
+      Test::Result run_one_test(const std::string& pad_hdr, const VarMap& vars) final;
 };
 
 class PK_Signature_Verification_Test : public PK_Test {
@@ -73,7 +73,7 @@ class PK_Signature_Verification_Test : public PK_Test {
       virtual std::unique_ptr<Botan::Public_Key> load_public_key(const VarMap& vars) = 0;
 
    private:
-      Test::Result run_one_test(const std::string& header, const VarMap& vars) final;
+      Test::Result run_one_test(const std::string& pad_hdr, const VarMap& vars) final;
 };
 
 class PK_Signature_NonVerification_Test : public PK_Test {
@@ -89,7 +89,7 @@ class PK_Signature_NonVerification_Test : public PK_Test {
       virtual std::unique_ptr<Botan::Public_Key> load_public_key(const VarMap& vars) = 0;
 
    private:
-      Test::Result run_one_test(const std::string& header, const VarMap& vars) final;
+      Test::Result run_one_test(const std::string& pad_hdr, const VarMap& vars) final;
 };
 
 class PK_Sign_Verify_DER_Test : public Test {
@@ -105,7 +105,7 @@ class PK_Sign_Verify_DER_Test : public Test {
 
       virtual bool test_random_invalid_sigs() const { return true; }
 
-      std::vector<std::string> possible_providers(const std::string& params) override;
+      std::vector<std::string> possible_providers(const std::string& algo_name) override;
 
    private:
       std::string m_algo;
@@ -122,14 +122,14 @@ class PK_Encryption_Decryption_Test : public PK_Test {
 
       virtual std::unique_ptr<Botan::Private_Key> load_private_key(const VarMap& vars) = 0;
 
-      std::string default_padding(const VarMap&) const override { return "Raw"; }
+      std::string default_padding(const VarMap& /*vars*/) const override { return "Raw"; }
 
       virtual std::unique_ptr<Botan::RandomNumberGenerator> test_rng(const std::vector<uint8_t>& nonce) const {
          return std::make_unique<Fixed_Output_RNG>(nonce);
       }
 
    private:
-      Test::Result run_one_test(const std::string& header, const VarMap& vars) final;
+      Test::Result run_one_test(const std::string& pad_hdr, const VarMap& vars) final;
 };
 
 class PK_Decryption_Test : public PK_Test {
@@ -142,10 +142,10 @@ class PK_Decryption_Test : public PK_Test {
 
       virtual std::unique_ptr<Botan::Private_Key> load_private_key(const VarMap& vars) = 0;
 
-      std::string default_padding(const VarMap&) const override { return "Raw"; }
+      std::string default_padding(const VarMap& /*vars*/) const override { return "Raw"; }
 
    private:
-      Test::Result run_one_test(const std::string& header, const VarMap& vars) final;
+      Test::Result run_one_test(const std::string& pad_hdr, const VarMap& vars) final;
 };
 
 class PK_Key_Agreement_Test : public PK_Test {
@@ -165,7 +165,7 @@ class PK_Key_Agreement_Test : public PK_Test {
 
       virtual std::vector<uint8_t> load_their_key(const std::string& header, const VarMap& vars) = 0;
 
-      virtual std::string default_kdf(const VarMap&) const { return "Raw"; }
+      virtual std::string default_kdf(const VarMap& /*vars*/) const { return "Raw"; }
 
    private:
       Test::Result run_one_test(const std::string& header, const VarMap& vars) final;
@@ -207,7 +207,7 @@ class PK_Key_Generation_Test : public Test {
                                                                      std::string_view provider,
                                                                      std::span<const uint8_t> raw_key_bits) const = 0;
 
-      std::vector<std::string> possible_providers(const std::string& params) override;
+      std::vector<std::string> possible_providers(const std::string& algo_name) override;
 };
 
 class PK_Key_Generation_Stability_Test : public PK_Test {
