@@ -8,6 +8,8 @@
 #include "test_rng.h"
 #include "tests.h"
 
+#include <botan/internal/target_info.h>
+
 #if defined(BOTAN_HAS_STATEFUL_RNG)
    #include <botan/stateful_rng.h>
 #endif
@@ -277,7 +279,8 @@ class Stateful_RNG_Tests : public Test {
 
          // fork and request from parent and child, both should output different sequences
          size_t count = counting_rng.randomize_count();
-         Botan::secure_vector<uint8_t> parent_bytes(16), child_bytes(16);
+         Botan::secure_vector<uint8_t> parent_bytes(16);
+         Botan::secure_vector<uint8_t> child_bytes(16);
          int fd[2];
          int rc = ::pipe(fd);
          if(rc != 0) {
@@ -306,7 +309,7 @@ class Stateful_RNG_Tests : public Test {
             }
 
             parent_bytes = rng->random_vec(16);
-            got = ::read(fd[0], &child_bytes[0], child_bytes.size());
+            got = ::read(fd[0], child_bytes.data(), child_bytes.size());
 
             if(got > 0) {
                result.test_eq("expected bytes from child", got, child_bytes.size());
@@ -322,16 +325,16 @@ class Stateful_RNG_Tests : public Test {
          } else {
             // child process, send randomize_count and first output sequence back to parent
             ::close(fd[0]);  // close read end in child
-            rng->randomize(&child_bytes[0], child_bytes.size());
+            rng->randomize(child_bytes.data(), child_bytes.size());
             count = counting_rng.randomize_count();
             ssize_t written = ::write(fd[1], &count, sizeof(count));
             BOTAN_UNUSED(written);
             try {
-               rng->randomize(&child_bytes[0], child_bytes.size());
+               rng->randomize(child_bytes.data(), child_bytes.size());
             } catch(std::exception& e) {
-               static_cast<void>(fprintf(stderr, "%s", e.what()));
+               static_cast<void>(fprintf(stderr, "%s", e.what()));  // NOLINT(*-vararg)
             }
-            written = ::write(fd[1], &child_bytes[0], child_bytes.size());
+            written = ::write(fd[1], child_bytes.data(), child_bytes.size());
             BOTAN_UNUSED(written);
             ::close(fd[1]);  // close write end in child
 
@@ -340,8 +343,8 @@ class Stateful_RNG_Tests : public Test {
             * We can't call _exit because it makes valgrind think we leaked memory.
             * So instead we execute something that will return 0 for us.
             */
-            ::execl("/bin/true", "true", NULL);
-            ::_exit(0);  // just in case /bin/true isn't available (sandbox?)
+            ::execl("/bin/true", "true", NULL);  // NOLINT(*-vararg)
+            ::_exit(0);                          // just in case /bin/true isn't available (sandbox?)
          }
    #endif
          return result;
@@ -411,11 +414,11 @@ class HMAC_DRBG_Unit_Tests final : public Stateful_RNG_Tests {
          std::unique_ptr<Botan::MessageAuthenticationCode> mac =
             Botan::MessageAuthenticationCode::create("HMAC(SHA-256)");
 
-         if(underlying_rng && underlying_es) {
+         if(underlying_rng != nullptr && underlying_es != nullptr) {
             return std::make_unique<Botan::HMAC_DRBG>(std::move(mac), *underlying_rng, *underlying_es, reseed_interval);
-         } else if(underlying_rng) {
+         } else if(underlying_rng != nullptr) {
             return std::make_unique<Botan::HMAC_DRBG>(std::move(mac), *underlying_rng, reseed_interval);
-         } else if(underlying_es) {
+         } else if(underlying_es != nullptr) {
             return std::make_unique<Botan::HMAC_DRBG>(std::move(mac), *underlying_es, reseed_interval);
          } else if(reseed_interval == 0) {
             return std::make_unique<Botan::HMAC_DRBG>(std::move(mac));
@@ -602,7 +605,7 @@ std::vector<Test::Result> hmac_drbg_multiple_requests() {
 }
 
 BOTAN_REGISTER_TEST("rng", "hmac_drbg_unit", HMAC_DRBG_Unit_Tests);
-BOTAN_REGISTER_TEST_FN("rng", "hmac_drbg_multi_requst", hmac_drbg_multiple_requests);
+BOTAN_REGISTER_TEST_FN("rng", "hmac_drbg_multi_request", hmac_drbg_multiple_requests);
 
 #endif
 
@@ -615,11 +618,11 @@ class ChaCha_RNG_Unit_Tests final : public Stateful_RNG_Tests {
       std::unique_ptr<Botan::Stateful_RNG> create_rng(Botan::RandomNumberGenerator* underlying_rng,
                                                       Botan::Entropy_Sources* underlying_es,
                                                       size_t reseed_interval) override {
-         if(underlying_rng && underlying_es) {
+         if(underlying_rng != nullptr && underlying_es != nullptr) {
             return std::make_unique<Botan::ChaCha_RNG>(*underlying_rng, *underlying_es, reseed_interval);
-         } else if(underlying_rng) {
+         } else if(underlying_rng != nullptr) {
             return std::make_unique<Botan::ChaCha_RNG>(*underlying_rng, reseed_interval);
-         } else if(underlying_es) {
+         } else if(underlying_es != nullptr) {
             return std::make_unique<Botan::ChaCha_RNG>(*underlying_es, reseed_interval);
          } else if(reseed_interval == 0) {
             return std::make_unique<Botan::ChaCha_RNG>();
@@ -800,7 +803,7 @@ class System_RNG_Tests final : public Test {
 
             std::vector<uint8_t> check_buf(checkSize, 0xFE);
 
-            result.confirm("System RNG failed to write after 4GB boundry",
+            result.confirm("System RNG failed to write after 4GB boundary",
                            std::memcmp(large_buf.data() + size32BitsMax, check_buf.data(), checkSize) != 0);
          }
 
