@@ -99,14 +99,14 @@ std::vector<Test::Result> test_container_strong_type() {
       CHECK("behaves like a standard container",
             [](auto& result) {
                auto base_nonce = Botan::hex_decode("DEADBEEF");
-               auto dataptr = base_nonce.data();
+               auto* dataptr = base_nonce.data();
                auto nonce = Test_Nonce(std::move(base_nonce));
 
                result.test_is_eq("size()", nonce.size(), size_t(4));
                result.confirm("empty()", !nonce.empty());
                result.test_is_eq("data()", nonce.data(), dataptr);
 
-               for(auto& c : nonce) {
+               for(const auto& c : nonce) {
                   result.confirm("iteration", c > 0);
                }
             }),
@@ -144,10 +144,10 @@ std::vector<Test::Result> test_container_strong_type() {
 
       CHECK("std::string container",
             [](auto& result) {
-               Test_Hash_Name thn("SHA-1");
+               Test_Hash_Name name("SHA-1");
 
                std::stringstream stream;
-               stream << thn;
+               stream << name;
                result.test_eq("strong types are streamable", stream.str(), std::string("SHA-1"));
             }),
 
@@ -157,8 +157,7 @@ std::vector<Test::Result> test_container_strong_type() {
 
                Test_Length_List hashes({Test_Length(3), Test_Length(1), Test_Length(4), Test_Length(2)});
 
-               // TODO: C++20 - std::ranges::sort
-               std::sort(hashes.begin(), hashes.end());
+               std::ranges::sort(hashes);
 
                result.test_eq("1", hashes.get().at(0).get(), size_t(1));
                result.test_eq("2", hashes.get().at(1).get(), size_t(2));
@@ -454,6 +453,7 @@ std::vector<Test::Result> test_wrapping_unwrapping() {
                // implicit conversion from a raw pointer of its wrapped type.
                auto rval_ptr = std::make_unique<std::string>("rvalue creation from ptr");
                auto stt_implicit_ptr =
+                  // NOLINTNEXTLINE(*-owning-memory)
                   Botan::wrap_strong_type<Strong_Unique>(new std::string("implicit creation from ptr"));
                auto stt_rvalue_ptr = Botan::wrap_strong_type<Strong_Unique>(std::move(rval_ptr));
 
@@ -566,7 +566,7 @@ std::vector<Test::Result> test_wrapping_unwrapping() {
                const Strong_String const_stt("wrapped const lvalue");
 
                auto& unwrapped_stt = Botan::unwrap_strong_type(stt);
-               auto& unwrapped_const_stt = Botan::unwrap_strong_type(const_stt);
+               const auto& unwrapped_const_stt = Botan::unwrap_strong_type(const_stt);
                auto unwrapped_rvalue = Botan::unwrap_strong_type(std::move(stt_move));
                auto unwrapped_rvalue2 = Botan::unwrap_strong_type(Strong_String("wrapped rvalue"));
 
@@ -595,7 +595,7 @@ std::vector<Test::Result> test_wrapping_unwrapping() {
                const std::string const_stt("wrapped const lvalue");
 
                auto& unwrapped_stt = Botan::unwrap_strong_type(stt);
-               auto& unwrapped_const_stt = Botan::unwrap_strong_type(const_stt);
+               const auto& unwrapped_const_stt = Botan::unwrap_strong_type(const_stt);
                auto unwrapped_rvalue = Botan::unwrap_strong_type(std::move(stt_move));
                auto unwrapped_rvalue2 = Botan::unwrap_strong_type(std::string("wrapped rvalue"));
 
