@@ -11,18 +11,22 @@
 #include <botan/internal/bit_ops.h>
 #include <botan/internal/calendar.h>
 #include <botan/internal/charset.h>
-#include <botan/internal/cpuid.h>
 #include <botan/internal/fmt.h>
 #include <botan/internal/int_utils.h>
 #include <botan/internal/loadstor.h>
 #include <botan/internal/parsing.h>
 #include <botan/internal/rounding.h>
 #include <botan/internal/stl_util.h>
+#include <botan/internal/target_info.h>
 
 #include <bit>
 #include <ctime>
 #include <functional>
 
+#if defined(BOTAN_HAS_CPUID)
+   #include <botan/internal/cpuid.h>
+#endif
+
 #if defined(BOTAN_HAS_POLY_DBL)
    #include <botan/internal/poly_dbl.h>
 #endif
@@ -277,8 +281,11 @@ class Utility_Function_Tests final : public Test {
             result.test_is_eq<uint8_t>(out[7], 0xAB);
          }
 
-         std::array<uint8_t, 8> outarr;
-         uint16_t i0, i1, i2, i3;
+         std::array<uint8_t, 8> outarr{};
+         uint16_t i0 = 0;
+         uint16_t i1 = 0;
+         uint16_t i2 = 0;
+         uint16_t i3 = 0;
          Botan::store_be(in64, outarr);
 
          Botan::load_be(outarr, i0, i1, i2, i3);
@@ -391,7 +398,7 @@ class Utility_Function_Tests final : public Test {
          result.test_is_eq(Botan::store_be<std::vector<uint8_t>>(in16_vector), Botan::hex_decode("0A0B0C0D"));
          result.test_is_eq(Botan::store_le<std::vector<uint8_t>>(in16_vector), Botan::hex_decode("0B0A0D0C"));
 
-         std::array<uint8_t, 4> out_array;
+         std::array<uint8_t, 4> out_array{};
          Botan::store_be(out_array, in16_array);
          result.test_is_eq(out_array, std::array<uint8_t, 4>{0x0A, 0x0B, 0x0C, 0x0D});
          Botan::store_le(out_array, in16_array);
@@ -472,25 +479,25 @@ class Utility_Function_Tests final : public Test {
 
       template <std::unsigned_integral T>
       static T fb_load_be(std::array<const uint8_t, sizeof(T)> in) {
-         return Botan::detail::fallback_load_any<Botan::detail::Endianness::Big, T>(in);
+         return Botan::detail::fallback_load_any<std::endian::big, T>(in);
       }
 
       template <std::unsigned_integral T>
       static T fb_load_le(std::array<const uint8_t, sizeof(T)> in) {
-         return Botan::detail::fallback_load_any<Botan::detail::Endianness::Little, T>(in);
+         return Botan::detail::fallback_load_any<std::endian::little, T>(in);
       }
 
       template <std::unsigned_integral T>
       static decltype(auto) fb_store_be(const T in) {
-         std::array<uint8_t, sizeof(T)> out;
-         Botan::detail::fallback_store_any<Botan::detail::Endianness::Big, T>(in, out);
+         std::array<uint8_t, sizeof(T)> out{};
+         Botan::detail::fallback_store_any<std::endian::big, T>(in, out);
          return out;
       }
 
       template <std::unsigned_integral T>
       static decltype(auto) fb_store_le(const T in) {
-         std::array<uint8_t, sizeof(T)> out;
-         Botan::detail::fallback_store_any<Botan::detail::Endianness::Little, T>(in, out);
+         std::array<uint8_t, sizeof(T)> out{};
+         Botan::detail::fallback_store_any<std::endian::little, T>(in, out);
          return out;
       }
 
@@ -967,15 +974,11 @@ class Version_Tests final : public Test {
          std::string sversion_str = Botan::short_version_string();
          result.test_eq("Same short version string", sversion_str, std::string(sversion_cstr));
 
-         std::string expected_sversion = std::to_string(BOTAN_VERSION_MAJOR) + "." +
-                                         std::to_string(BOTAN_VERSION_MINOR) + "." +
-                                         std::to_string(BOTAN_VERSION_PATCH);
+         const auto expected_sversion =
+            Botan::fmt("{}.{}.{}", BOTAN_VERSION_MAJOR, BOTAN_VERSION_MINOR, BOTAN_VERSION_PATCH);
 
-#if defined(BOTAN_VERSION_SUFFIX)
-         expected_sversion += BOTAN_VERSION_SUFFIX_STR;
-#endif
-
-         result.test_eq("Short version string has expected format", sversion_str, expected_sversion);
+         // May have a suffix eg 4.0.0-rc2
+         result.confirm("Short version string has expected format", sversion_str.starts_with(expected_sversion));
 
          const std::string version_check_ok =
             Botan::runtime_version_check(BOTAN_VERSION_MAJOR, BOTAN_VERSION_MINOR, BOTAN_VERSION_PATCH);
@@ -1111,6 +1114,39 @@ class Hostname_Tests final : public Text_Based_Test {
 
 BOTAN_REGISTER_TEST("utils", "hostname", Hostname_Tests);
 
+class DNS_Check_Tests final : public Text_Based_Test {
+   public:
+      DNS_Check_Tests() : Text_Based_Test("utils/dns.vec", "DNS") {}
+
+      Test::Result run_one_test(const std::string& type, const VarMap& vars) override {
+         Test::Result result("DNS name validation");
+
+         const std::string name = vars.get_req_str("DNS");
+         const bool valid = (type == "Invalid") ? false : true;
+
+         try {
+            const auto canonicalized = Botan::check_and_canonicalize_dns_name(name);
+            BOTAN_UNUSED(canonicalized);
+
+            if(valid) {
+               result.test_success("Accepted valid name");
+            } else {
+               result.test_failure("Accepted invalid name");
+            }
+         } catch(Botan::Decoding_Error&) {
+            if(valid) {
+               result.test_failure("Rejected valid name");
+            } else {
+               result.test_success("Rejected invalid name");
+            }
+         }
+
+         return result;
+      }
+};
+
+BOTAN_REGISTER_TEST("utils", "dns_check", DNS_Check_Tests);
+
 class IPv4_Parsing_Tests final : public Text_Based_Test {
    public:
       IPv4_Parsing_Tests() : Text_Based_Test("utils/ipv4.vec", "IPv4") {}
@@ -1165,12 +1201,12 @@ class ReadKV_Tests final : public Text_Based_Test {
          }
 
          std::string substr;
-         for(auto i = str.begin(); i != str.end(); ++i) {
-            if(*i == '|') {
+         for(char c : str) {
+            if(c == '|') {
                elems.push_back(substr);
                substr.clear();
             } else {
-               substr += *i;
+               substr += c;
             }
          }
 
@@ -1201,36 +1237,56 @@ class ReadKV_Tests final : public Text_Based_Test {
 
 BOTAN_REGISTER_TEST("utils", "util_read_kv", ReadKV_Tests);
 
+#if defined(BOTAN_HAS_CPUID)
+
 class CPUID_Tests final : public Test {
    public:
       std::vector<Test::Result> run() override {
          Test::Result result("CPUID");
 
-         result.confirm("Endian is either little or big",
-                        Botan::CPUID::is_big_endian() || Botan::CPUID::is_little_endian());
-
-         if(Botan::CPUID::is_little_endian()) {
-            result.test_eq("If endian is little, it is not also big endian", Botan::CPUID::is_big_endian(), false);
-         } else {
-            result.test_eq("If endian is big, it is not also little endian", Botan::CPUID::is_little_endian(), false);
-         }
-
          const std::string cpuid_string = Botan::CPUID::to_string();
          result.test_success("CPUID::to_string doesn't crash");
 
-#if defined(BOTAN_TARGET_CPU_IS_X86_FAMILY)
+         for(size_t b = 0; b != 32; ++b) {
+            try {
+               const auto bit = static_cast<uint32_t>(1) << b;
+               // NOLINTNEXTLINE(clang-analyzer-optin.core.EnumCastOutOfRange)
+               const auto feat = Botan::CPUID::Feature(static_cast<Botan::CPUID::Feature::Bit>(bit));
 
-         if(Botan::CPUID::has_sse2()) {
+               const std::string feat_str = feat.to_string();
+
+               result.confirm("Feature string is not empty", !feat_str.empty());
+
+               if(auto from_str = Botan::CPUID::Feature::from_string(feat_str)) {
+                  result.test_int_eq("Feature::from_string returns expected bit", from_str->as_u32(), bit);
+               } else {
+                  result.test_failure(
+                     Botan::fmt("Feature::from_string didn't recognize its own output ({})", feat_str));
+               }
+            } catch(Botan::Invalid_State&) {
+               // This will thrown if the bit is not a valid one
+            }
+         }
+
+   #if defined(BOTAN_TARGET_ARCH_IS_X86_FAMILY)
+
+         const auto bit = Botan::CPUID::Feature::SSE2;
+
+         if(Botan::CPUID::has(bit)) {
             result.confirm("Output string includes sse2", cpuid_string.find("sse2") != std::string::npos);
 
-            Botan::CPUID::clear_cpuid_bit(Botan::CPUID::CPUID_SSE2_BIT);
+            Botan::CPUID::clear_cpuid_bit(bit);
 
-            result.test_eq("After clearing cpuid bit, has_sse2 returns false", Botan::CPUID::has_sse2(), false);
+            result.test_eq(
+               "After clearing cpuid bit, CPUID::has for SSE2 returns false", Botan::CPUID::has(bit), false);
 
             Botan::CPUID::initialize();  // reset state
-            result.test_eq("After reinitializing, has_sse2 returns true", Botan::CPUID::has_sse2(), true);
+            result.test_eq(
+               "After reinitializing, CPUID::has for SSE2 returns true again", Botan::CPUID::has(bit), true);
          }
-#endif
+   #else
+         BOTAN_UNUSED(cpuid_string);
+   #endif
 
          return {result};
       }
@@ -1238,6 +1294,8 @@ class CPUID_Tests final : public Test {
 
 BOTAN_REGISTER_SERIALIZED_TEST("utils", "cpuid", CPUID_Tests);
 
+#endif
+
 #if defined(BOTAN_HAS_UUID)
 
 class UUID_Tests : public Test {
@@ -1274,9 +1332,7 @@ class UUID_Tests : public Test {
                explicit AllSame_RNG(uint8_t b) : m_val(b) {}
 
                void fill_bytes_with_input(std::span<uint8_t> output, std::span<const uint8_t> /* ignored */) override {
-                  for(auto& byte : output) {
-                     byte = m_val;
-                  }
+                  std::fill(output.begin(), output.end(), m_val);
                }
 
                std::string name() const override { return "zeros"; }
