@@ -173,6 +173,8 @@ Test::Result test_cert_status_strings() {
       Botan::Certificate_Status_Code::CERT_CHAIN_TOO_LONG,
       Botan::Certificate_Status_Code::CA_CERT_NOT_FOR_CERT_ISSUER,
       Botan::Certificate_Status_Code::NAME_CONSTRAINT_ERROR,
+      Botan::Certificate_Status_Code::IPADDR_BLOCKS_ERROR,
+      Botan::Certificate_Status_Code::AS_BLOCKS_ERROR,
       Botan::Certificate_Status_Code::CA_CERT_NOT_FOR_CRL_ISSUER,
       Botan::Certificate_Status_Code::OCSP_CERT_NOT_LISTED,
       Botan::Certificate_Status_Code::OCSP_BAD_STATUS,
@@ -421,12 +423,12 @@ Test::Result test_x509_dates() {
 Test::Result test_x509_encode_authority_info_access_extension() {
    Test::Result result("X509 with encoded PKIX.AuthorityInformationAccess extension");
 
-   #if defined(BOTAN_HAS_RSA)
+   #if defined(BOTAN_HAS_RSA) && defined(BOTAN_HAS_EMSA_PKCS1)
    auto rng = Test::new_rng(__func__);
 
    const std::string sig_algo{"RSA"};
    const std::string hash_fn{"SHA-256"};
-   const std::string padding_method{"EMSA3(SHA-256)"};
+   const std::string padding_method{"PKCS1v15(SHA-256)"};
 
    // CA Issuer information
    const std::vector<std::string> ca_issuers = {
@@ -655,7 +657,7 @@ Test::Result test_x509_authority_info_access_extension() {
    const auto ca_issuers = aia_cert.ca_issuers();
 
    result.test_eq("number of ca_issuers URLs", ca_issuers.size(), 1);
-   if(result.tests_failed()) {
+   if(result.tests_failed() > 0) {
       return result;
    }
 
@@ -669,7 +671,7 @@ Test::Result test_x509_authority_info_access_extension() {
    const auto ca_issuers2 = aia_cert_2ca.ca_issuers();
 
    result.test_eq("number of ca_issuers URLs", ca_issuers2.size(), 2);
-   if(result.tests_failed()) {
+   if(result.tests_failed() > 0) {
       return result;
    }
 
@@ -725,14 +727,13 @@ Test::Result test_verify_gost2012_cert() {
    return result;
 }
 
-      /*
- * @brief checks the configurability of the EMSA4(RSA-PSS) signature scheme
+   /*
+ * @brief checks the configurability of the RSA-PSS signature scheme
  *
  * For the other algorithms than RSA, only one padding is supported right now.
  */
       #if defined(BOTAN_HAS_EMSA_PKCS1) && defined(BOTAN_HAS_EMSA_PSSR) && defined(BOTAN_HAS_RSA)
 Test::Result test_padding_config() {
-   // Throughout the test, some synonyms for EMSA4 are used, e.g. PSSR, EMSA-PSS
    Test::Result test_result("X509 Padding Config");
 
    auto rng = Test::new_rng(__func__);
@@ -740,8 +741,8 @@ Test::Result test_padding_config() {
    Botan::DataSource_Stream key_stream(Test::data_file("x509/misc/rsa_key.pem"));
    auto sk = Botan::PKCS8::load_key(key_stream);
 
-   // Create X509 CA certificate; EMSA3 is used for signing by default
-   Botan::X509_Cert_Options opt("TESTCA");
+   // Create X509 CA certificate; PKCS1v15 is used for signing by default
+   Botan::X509_Cert_Options opt("TEST CA");
    opt.CA_key();
 
    Botan::X509_Certificate ca_cert_def = Botan::X509::create_self_signed_cert(opt, (*sk), "SHA-512", *rng);
@@ -758,7 +759,7 @@ Test::Result test_padding_config() {
 
          #if defined(BOTAN_HAS_EMSA_X931)
    // Try to set a padding scheme that is not supported for signing with the given key type
-   opt.set_padding_scheme("EMSA2");
+   opt.set_padding_scheme("X9.31");
    try {
       Botan::X509_Certificate ca_cert_wrong = Botan::X509::create_self_signed_cert(opt, (*sk), "SHA-512", *rng);
       test_result.test_failure("Could build CA cert with invalid encoding scheme X9.31 for key type " +
@@ -779,42 +780,41 @@ Test::Result test_padding_config() {
 
    // Prepare a signing request for the end certificate
    Botan::X509_Cert_Options req_opt("endpoint");
-   req_opt.set_padding_scheme("EMSA4(SHA-512,MGF1,64)");
+   req_opt.set_padding_scheme("PSS(SHA-512,MGF1,64)");
    Botan::PKCS10_Request end_req = Botan::X509::create_cert_req(req_opt, (*sk), "SHA-512", *rng);
    test_result.test_eq(
       "Certificate request signature algorithm", end_req.signature_algorithm().oid().to_formatted_string(), "RSA/PSS");
 
    // Create X509 CA object: will fail as the chosen hash functions differ
    try {
-      Botan::X509_CA ca_fail(ca_cert_exp, (*sk), "SHA-512", "EMSA4(SHA-256)", *rng);
+      Botan::X509_CA ca_fail(ca_cert_exp, (*sk), "SHA-512", "PSS(SHA-256)", *rng);
       test_result.test_failure("Configured conflicting hash functions for CA");
    } catch(const Botan::Invalid_Argument& e) {
       test_result.test_eq(
          "Configured conflicting hash functions for CA",
          e.what(),
-         "Specified hash function SHA-512 is incompatible with RSA chose hash function SHA-256 with user specified padding EMSA4(SHA-256)");
+         "Specified hash function SHA-512 is incompatible with RSA chose hash function SHA-256 with user specified padding PSS(SHA-256)");
    }
 
-   // Create X509 CA object: its signer will use the padding scheme from the CA certificate, i.e. EMSA3
+   // Create X509 CA object: its signer will use the padding scheme from the CA certificate, i.e. PKCS1v15
    Botan::X509_CA ca_def(ca_cert_def, (*sk), "SHA-512", *rng);
-   Botan::X509_Certificate end_cert_emsa3 = ca_def.sign_request(end_req, *rng, not_before, not_after);
+   Botan::X509_Certificate end_cert_pkcs1 = ca_def.sign_request(end_req, *rng, not_before, not_after);
    test_result.test_eq("End certificate signature algorithm",
-                       end_cert_emsa3.signature_algorithm().oid().to_formatted_string(),
+                       end_cert_pkcs1.signature_algorithm().oid().to_formatted_string(),
                        "RSA/PKCS1v15(SHA-512)");
 
    // Create X509 CA object: its signer will use the explicitly configured padding scheme, which is different from the CA certificate's scheme
-   Botan::X509_CA ca_diff(ca_cert_def, (*sk), "SHA-512", "EMSA-PSS", *rng);
-   Botan::X509_Certificate end_cert_diff_emsa4 = ca_diff.sign_request(end_req, *rng, not_before, not_after);
+   Botan::X509_CA ca_diff(ca_cert_def, (*sk), "SHA-512", "PSS", *rng);
+   Botan::X509_Certificate end_cert_diff_pss = ca_diff.sign_request(end_req, *rng, not_before, not_after);
    test_result.test_eq("End certificate signature algorithm",
-                       end_cert_diff_emsa4.signature_algorithm().oid().to_formatted_string(),
+                       end_cert_diff_pss.signature_algorithm().oid().to_formatted_string(),
                        "RSA/PSS");
 
    // Create X509 CA object: its signer will use the explicitly configured padding scheme, which is identical to the CA certificate's scheme
-   Botan::X509_CA ca_exp(ca_cert_exp, (*sk), "SHA-512", "EMSA4(SHA-512,MGF1,64)", *rng);
-   Botan::X509_Certificate end_cert_emsa4 = ca_exp.sign_request(end_req, *rng, not_before, not_after);
-   test_result.test_eq("End certificate signature algorithm",
-                       end_cert_emsa4.signature_algorithm().oid().to_formatted_string(),
-                       "RSA/PSS");
+   Botan::X509_CA ca_exp(ca_cert_exp, (*sk), "SHA-512", "PSS(SHA-512,MGF1,64)", *rng);
+   Botan::X509_Certificate end_cert_pss = ca_exp.sign_request(end_req, *rng, not_before, not_after);
+   test_result.test_eq(
+      "End certificate signature algorithm", end_cert_pss.signature_algorithm().oid().to_formatted_string(), "RSA/PSS");
 
    // Check CRL signature algorithm
    Botan::X509_CRL crl = ca_exp.new_crl(*rng);
@@ -824,8 +824,8 @@ Test::Result test_padding_config() {
    const Botan::Certificate_Store_In_Memory trusted(ca_exp.ca_certificate());
    const Botan::Path_Validation_Restrictions restrictions(false, 80);
    const Botan::Path_Validation_Result validation_result =
-      Botan::x509_path_validate(end_cert_emsa4, restrictions, trusted);
-   test_result.confirm("EMSA4-signed certificate validates", validation_result.successful_validation());
+      Botan::x509_path_validate(end_cert_pss, restrictions, trusted);
+   test_result.confirm("PSS signed certificate validates", validation_result.successful_validation());
 
    return test_result;
 }
@@ -912,7 +912,7 @@ Test::Result test_x509_cert(const Botan::Private_Key& ca_key,
    /* Create the CA object */
    Botan::X509_CA ca(ca_cert, ca_key, hash_fn, sig_padding, rng);
 
-   const BigInt user1_serial = 99;
+   const BigInt user1_serial(99);
 
    /* Sign the requests to create the certs */
    Botan::X509_Certificate user1_cert =
@@ -922,6 +922,7 @@ Test::Result test_x509_cert(const Botan::Private_Key& ca_key,
    result.test_eq("User1 serial matches expected", user1_cert.serial_number().at(0), size_t(99));
 
    Botan::X509_Certificate user2_cert = ca.sign_request(user2_req, rng, from_date(-1, 01, 01), from_date(2, 01, 01));
+   result.test_eq("extended key usage is set", user2_cert.has_ex_constraint("PKIX.EmailProtection"), true);
 
    Botan::X509_Certificate user3_cert = ca.sign_request(user3_req, rng, from_date(-1, 01, 01), from_date(2, 01, 01));
 
@@ -1004,7 +1005,7 @@ Test::Result test_x509_cert(const Botan::Private_Key& ca_key,
 
    std::vector<Botan::CRL_Entry> revoked;
    revoked.push_back(Botan::CRL_Entry(user1_cert, Botan::CRL_Code::CessationOfOperation));
-   revoked.push_back(user2_cert);
+   revoked.push_back(Botan::CRL_Entry(user2_cert));
 
    const Botan::X509_CRL crl2 = ca.update_crl(crl1, revoked, rng);
 
@@ -1434,7 +1435,7 @@ Test::Result test_x509_extensions(const Botan::Private_Key& ca_key,
    }
 
    // check if CDPs are present in the self-signed cert
-   auto cert_cdps =
+   const auto* cert_cdps =
       self_signed_cert.v3_extensions().get_extension_object_as<Botan::Cert_Extension::CRL_Distribution_Points>();
 
    if(result.confirm("CRL Distribution Points extension present in self-signed certificate",
@@ -1561,9 +1562,9 @@ Test::Result test_x509_tn_auth_list_extension_decode() {
 
    using Botan::Cert_Extension::TNAuthList;
 
-   auto tn_auth_list = cert.v3_extensions().get_extension_object_as<TNAuthList>();
+   const auto* tn_auth_list = cert.v3_extensions().get_extension_object_as<TNAuthList>();
 
-   auto& tn_entries = tn_auth_list->entries();
+   const auto& tn_entries = tn_auth_list->entries();
 
    result.confirm("cert has TNAuthList extension", tn_auth_list != nullptr, true);
 
@@ -1578,7 +1579,7 @@ Test::Result test_x509_tn_auth_list_extension_decode() {
    result.test_eq("spc entry data", tn_entries[0].service_provider_code(), "1001");
 
    result.test_eq("range entry type", tn_entries[1].type() == TNAuthList::Entry::TelephoneNumberRange, true);
-   auto& range = tn_entries[1].telephone_number_range();
+   const auto& range = tn_entries[1].telephone_number_range();
    result.test_eq("range entries count", range.size(), 2);
    result.test_eq("range entry 0 start data", range[0].start.value(), "111");
    result.test_eq("range entry 0 count data", range[0].count, 128);
@@ -1596,7 +1597,14 @@ Test::Result test_x509_tn_auth_list_extension_decode() {
 
 std::vector<std::string> get_sig_paddings(const std::string& sig_algo, const std::string& hash) {
    if(sig_algo == "RSA") {
-      return {"EMSA3(" + hash + ")", "EMSA4(" + hash + ")"};
+      return {
+   #if defined(BOTAN_HAS_EMSA_PKCS1)
+         "PKCS1v15(" + hash + ")",
+   #endif
+   #if defined(BOTAN_HAS_EMSA_PSS)
+            "PSS(" + hash + ")",
+   #endif
+      };
    } else if(sig_algo == "DSA" || sig_algo == "ECDSA" || sig_algo == "ECGDSA" || sig_algo == "ECKCDSA" ||
              sig_algo == "GOST-34.10") {
       return {hash};
